@@ -1,16 +1,7 @@
-/***************************************************************************
-   copyright            : (C) 2006 by David Nolden
-   email                : david.nolden.kdevelop@art-master.de
-***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2006 David Nolden <david.nolden.kdevelop@art-master.de>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "hashedstring.h"
 #include <kdatastream.h>
@@ -179,8 +170,12 @@ void HashedStringSet::makeDataPrivate()
         m_data = new HashedStringSetData();
         return ;
     }
+#if QT_VERSION >= 0x050000
+    m_data.detach();
+#else
     if (m_data.count() != 1)
         m_data = new HashedStringSetData(*m_data);
+#endif
 }
 
 bool HashedStringSet::operator[] (const HashedString& rhs) const
