@@ -1,15 +1,8 @@
-/***************************************************************************
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   copyright (C) 2014                                                    *
- *   Umbrello UML Modeller Authors <umbrello-devel@kde.org>                *
- *                                                                         *
- *   @author Ralf Habacker <ralf.habacker@freenet.de>                      *
- *                                                                         *
- ***************************************************************************/
+/*
+    SPDX-License-Identifier: GPL-2.0-or-later
+    SPDX-FileCopyrightText: 2014-2020 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
+    SPDX-FileCopyrightText: 2014-2020 Ralf Habacker <ralf.habacker@freenet.de>
+*/
 
 #include "shared.h"
 
@@ -48,7 +41,7 @@ QStringList XMILanguagesAttributes()
 }
 
 /**
- * Extract language related XML attributs from XMI file
+ * Extract language related XML attributes from XMI file
 
  * @param fileName file to extract attributes from
  * @param attributes List with attribute names to extract
@@ -67,7 +60,7 @@ bool extractAttributesFromXMI(const char *fileName, const QStringList &attribute
     xmlReader.setDevice(&file);
     while (!xmlReader.atEnd()) {
         QXmlStreamReader::TokenType type = xmlReader.readNext();
-        if (!type == QXmlStreamReader::StartElement)
+        if (type != QXmlStreamReader::StartElement)
             continue;
 
         foreach(const QString &attributeName, attributes) {
@@ -225,7 +218,7 @@ bool applyTranslationToXMIFile(const char *fileName, const QStringList &attribut
     QXmlStreamWriter writer(&outFile);
     writer.setAutoFormatting (true);
     writer.setAutoFormattingIndent(1);
-    writer.setCodec(reader.documentEncoding().toAscii().constData());
+    writer.setCodec(reader.documentEncoding().toLatin1().constData());
 
     while (!reader.atEnd())
     {
@@ -252,10 +245,11 @@ bool applyTranslationToXMIFile(const char *fileName, const QStringList &attribut
                 QXmlStreamNamespaceDeclaration ns = reader.namespaceDeclarations().first();
                 writer.writeNamespace(ns.namespaceUri().toString(), ns.prefix().toString());
             }
+            const QXmlStreamAttributes& readerAttributes = reader.attributes();
             QXmlStreamAttributes writerAttributes;
-            for(int index = 0; index < reader.attributes().size(); index++)
+            for(int index = 0; index < readerAttributes.size(); index++)
             {
-                QXmlStreamAttribute attr = reader.attributes()[index];
+                QXmlStreamAttribute attr = readerAttributes[index];
                 QString name = attr.qualifiedName().toString();
                 if (!attributes.contains(name)) {
                     writerAttributes.append(attr);
