@@ -1,6 +1,6 @@
 /*
     SPDX-License-Identifier: GPL-2.0-or-later
-    SPDX-FileCopyrightText: 2002-2020 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
+    SPDX-FileCopyrightText: 2002-2022 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
 */
 
 #include "cmdremovewidget.h"
@@ -10,6 +10,7 @@
 #include "debug_utils.h"
 #include "umlscene.h"
 #include "umlwidget.h"
+#include "uml.h"  // Only needed for log{Warn,Error}
 
 // kde includes
 #include <KLocalizedString>
@@ -31,7 +32,7 @@ namespace Uml
             QString xmi;
             QXmlStreamWriter kidStream(&xmi);
             kidStream.writeStartElement(QLatin1String("child"));
-            child->saveToXMI1(kidStream);
+            child->saveToXMI(kidStream);
             kidStream.writeEndElement();  // child
             QString error;
             int line;
@@ -39,11 +40,12 @@ namespace Uml
             if (domDoc.setContent(xmi, &error, &line)) {
                 QDomElement domElem = domDoc.firstChild().firstChild().toElement();
                 if (domElem.isNull())
-                    uWarning() << "child QDomElement is null";
+                    logWarn1("CmdRemoveWidget(%1): child QDomElement is null", widget->name());
                 else
                     m_children.append(domElem);
             } else {
-                uWarning() << "Cannot set content:" << error << " line:" << line;
+                logWarn3("CmdRemoveWidget(%1): Cannot set child content. Error %2 line %3",
+                         widget->name(), error, line);
             }
         }
 
@@ -51,7 +53,7 @@ namespace Uml
         QString xmi;
         QXmlStreamWriter stream(&xmi);
         stream.writeStartElement(QLatin1String("widget"));
-        widget->saveToXMI1(stream);
+        widget->saveToXMI(stream);
         stream.writeEndElement();  // widget
         QString error;
         int line;
@@ -59,9 +61,10 @@ namespace Uml
         if (doc.setContent(xmi, &error, &line)) {
             m_element = doc.firstChild().firstChild().toElement();
             if (m_element.isNull())
-                uWarning() << "widget QDomElement is null";
+                logWarn0("widget QDomElement is null");
         } else {
-            uWarning() << "Cannot set content:" << error << " line:" << line;
+            logWarn3("CmdRemoveWidget(%1): Cannot set content. Error %2 line %3",
+                     widget->name(), error, line);
         }
     }
 
@@ -77,7 +80,7 @@ namespace Uml
         QString xmi;
         QXmlStreamWriter stream(&xmi);
         stream.writeStartElement(QLatin1String("widget"));
-        widget->saveToXMI1(stream);
+        widget->saveToXMI(stream);
         stream.writeEndElement();  // widget
         QString error;
         int line;
@@ -85,9 +88,10 @@ namespace Uml
         if (doc.setContent(xmi, &error, &line)) {
             m_element = doc.firstChild().firstChild().toElement();
             if (m_element.isNull())
-                uWarning() << "widget QDomElement is null";
+                logWarn1("CmdRemoveWidget(%1): widget QDomElement is null", widget->name());
         } else {
-            uWarning() << "Cannot set content:" << error << " line:" << line;
+            logWarn3("CmdRemoveWidget(%1): Cannot set content. Error %2 line %3",
+                     widget->name(), error, line);
         }
     }
 
@@ -136,7 +140,7 @@ namespace Uml
                 // widget back from the saved XMI state.
                 QDomElement widgetElement = m_element.firstChild().toElement();
                 widget = AssociationWidget::create(scene());
-                if (widget->loadFromXMI1(widgetElement)) {
+                if (widget->loadFromXMI(widgetElement)) {
                     addWidgetToScene(widget);
                     m_assocWidget = widget;
                     m_widgetId = widget->id();
