@@ -2,7 +2,7 @@
     SPDX-License-Identifier: GPL-2.0-or-later
 
     SPDX-FileCopyrightText: 2003 Brian Thomas <thomas@mail630.gsfc.nasa.gov>
-    SPDX-FileCopyrightText: 2004-2020 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
+    SPDX-FileCopyrightText: 2004-2022 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
 */
 
 // own header
@@ -70,9 +70,9 @@ CodeClassField::~CodeClassField ()
  */
 void CodeClassField::setParentUMLObject (UMLObject * obj)
 {
-    UMLRole *role = obj->asUMLRole();
+    const UMLRole *role = obj->asUMLRole();
     if(role) {
-        UMLAssociation * parentAssoc = role->parentAssociation();
+        const UMLAssociation * parentAssoc = role->parentAssociation();
         Uml::AssociationType::Enum atype = parentAssoc->getAssocType();
         m_parentIsAttribute = false;
 
@@ -110,7 +110,7 @@ QString CodeClassField::getListObjectType()
 {
     if (!parentIsAttribute())
     {
-        UMLRole * role = getParentObject()->asUMLRole();
+        const UMLRole * role = getParentObject()->asUMLRole();
         if (role)
             return getUMLObjectName(role->object());
     }
@@ -223,7 +223,7 @@ CodeClassFieldDeclarationBlock * CodeClassField::getDeclarationCodeBlock()
 /**
  * Load params from the appropriate XMI element node.
  */
-void CodeClassField::loadFromXMI1 (QDomElement & root)
+void CodeClassField::loadFromXMI (QDomElement & root)
 {
     setAttributesFromNode(root);
 }
@@ -244,12 +244,12 @@ void CodeClassField::setAttributesOnNode (QXmlStreamWriter& writer)
                                                                                  : QLatin1String("false"));
     // record tag on declaration codeblock
     // which we will store in its own separate child node block
-    m_declCodeBlock->saveToXMI1(writer);
+    m_declCodeBlock->saveToXMI(writer);
 
     // now record the tags on our accessormethods
     Q_FOREACH(CodeAccessorMethod *method, m_methodVector)
     {
-        method->saveToXMI1(writer);
+        method->saveToXMI(writer);
     }
 }
 
@@ -283,22 +283,22 @@ void CodeClassField::setAttributesFromNode (QDomElement & root)
     while (!element.isNull()) {
         QString tag = element.tagName();
         if (tag == QLatin1String("ccfdeclarationcodeblock")) {
-            m_declCodeBlock->loadFromXMI1(element);
+            m_declCodeBlock->loadFromXMI(element);
         } else
             if (tag == QLatin1String("codeaccessormethod")) {
                 int type = element.attribute(QLatin1String("accessType"), QLatin1String("0")).toInt();
                 int role_id = element.attribute(QLatin1String("role_id"), QLatin1String("-1")).toInt();
                 CodeAccessorMethod * method = findMethodByType((CodeAccessorMethod::AccessorType) type, role_id);
                 if (method)
-                    method->loadFromXMI1(element);
+                    method->loadFromXMI(element);
                 else
-                    uError()<<"Cannot load code accessor method for type:"<<type<<" which does not exist in this codeclassfield. Is XMI out-dated or corrupt?";
+                    logError1("Cannot load code accessor method for type %1 which does not exist in this codeclassfield. Is XMI out-dated or corrupt?", type);
 
             } else
                 if (tag == QLatin1String("header")) {
                     // this is treated in parent.. skip over here
                 } else
-                    uWarning()<<"ERROR: bad savefile? code classfield loadFromXMI1 got child element with unknown tag:"<<tag<<" ignoring node.";
+                    logWarn1("bad savefile? code classfield loadFromXMI got child element with unknown tag %1, ignoring node.", tag);
 
         node = element.nextSibling();
         element = node.toElement();
@@ -308,7 +308,7 @@ void CodeClassField::setAttributesFromNode (QDomElement & root)
 /**
  * Save the XMI representation of this object.
  */
-void CodeClassField::saveToXMI1(QXmlStreamWriter& writer)
+void CodeClassField::saveToXMI(QXmlStreamWriter& writer)
 {
     writer.writeStartElement(QLatin1String("codeclassfield"));
 
@@ -327,9 +327,9 @@ int CodeClassField::minimumListOccurances()
 {
     if (!parentIsAttribute())
     {
-        UMLRole * role = getParentObject()->asUMLRole();
+        const UMLRole * role = getParentObject()->asUMLRole();
         if (!role) {
-            uError() << "no valid parent object";
+            logError0("no valid parent object");
             return -1;
         }
         QString multi = role->multiplicity();
@@ -355,9 +355,9 @@ int CodeClassField::maximumListOccurances()
 {
     if (!parentIsAttribute())
     {
-        UMLRole * role = getParentObject()->asUMLRole();
+        const UMLRole * role = getParentObject()->asUMLRole();
         if (!role) {
-            uError() << "no valid parent object";
+            logError0("no valid parent object");
             return -1;
         }
         QString multi = role->multiplicity();
@@ -439,9 +439,9 @@ CodeAccessorMethod * CodeClassField::findMethodByType (CodeAccessorMethod::Acces
         // design.
         Q_FOREACH(CodeAccessorMethod *m, m_methodVector)
         {
-            UMLRole * role = m->getParentObject()->asUMLRole();
+            const UMLRole * role = m->getParentObject()->asUMLRole();
             if(!role)
-                uError()<<"    FindMethodByType()  cant create role for method type:"<<m->getType()<<endl;
+                logError1("FindMethodByType() cant create role for method type %1", m->getType());
             if(role && m->getType() == type && role->role() == role_id)
                 return m;
         }
@@ -524,7 +524,7 @@ void CodeClassField::updateContent()
             method->setWriteOutText(m_writeOutMethods);
         return;
     }
-    UMLRole * role = getParentObject()->asUMLRole();
+    const UMLRole * role = getParentObject()->asUMLRole();
     if (!role)
         return;
     Uml::Changeability::Enum changeType = role->changeability();
@@ -619,7 +619,7 @@ bool CodeClassField::fieldIsSingleValue ()
     if(parentIsAttribute())
         return true;
 
-    UMLRole * role = getParentObject()->asUMLRole();
+    const UMLRole * role = getParentObject()->asUMLRole();
     if(!role)
         return true; // it is really an attribute
 
