@@ -2,7 +2,7 @@
     SPDX-License-Identifier: GPL-2.0-or-later
 
     SPDX-FileCopyrightText: 2003 Brian Thomas <thomas@mail630.gsfc.nasa.gov>
-    SPDX-FileCopyrightText: 2004-2021 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
+    SPDX-FileCopyrightText: 2004-2022 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
 */
 
 // own header
@@ -146,12 +146,12 @@ UMLObject * CodeParameter::getParentObject()
 // this is kind of broken for UMLRoles.
 QString CodeParameter::ID() const
 {
-    UMLRole * role = m_parentObject->asUMLRole();
+    const UMLRole * role = m_parentObject->asUMLRole();
     if (role)
     {
         // cant use Role "ID" as that is used to distinquish if its
         // role "A" or "B"
-        UMLAssociation *assoc = role->parentAssociation();
+        const UMLAssociation *assoc = role->parentAssociation();
         return Uml::ID::toString(assoc->id());
     } else
         return Uml::ID::toString(m_parentObject->id());
@@ -170,7 +170,7 @@ void CodeParameter::setAttributesOnNode(QXmlStreamWriter& writer)
     // setting ID's takes special treatment
     // as UMLRoles arent properly stored in the XMI right now.
     // (change would break the XMI format..save for big version change)
-    UMLRole * role = m_parentObject->asUMLRole();
+    const UMLRole * role = m_parentObject->asUMLRole();
     if (role)
         writer.writeAttribute(QLatin1String("role_id"), QString::number(role->role()));
     else
@@ -180,7 +180,7 @@ void CodeParameter::setAttributesOnNode(QXmlStreamWriter& writer)
 
     // a comment which we will store in its own separate child node block
     writer.writeStartElement(QLatin1String("header"));
-    getComment()->saveToXMI1(writer); // comment
+    getComment()->saveToXMI(writer); // comment
     writer.writeEndElement();
 }
 
@@ -221,9 +221,9 @@ void CodeParameter::setAttributesFromNode(QDomElement & root)
             else if (role_id == 0)
                 role = assoc->getUMLRole(Uml::RoleType::B);
             else
-                uError() << "corrupt save file? "
-                    << "cant get proper UMLRole for codeparameter uml id:"
-                    << Uml::ID::toString(id) << " w/role_id:" << role_id;
+                logError2("CodeParameter::setAttributesFromNode: corrupt save file? "
+                          "cant get proper UMLRole for codeparameter uml id: %1 w/role_id: %2",
+                          Uml::ID::toString(id), role_id);
 
             // init using UMLRole obj
             if (role)
@@ -233,8 +233,8 @@ void CodeParameter::setAttributesFromNode(QDomElement & root)
             initFields (m_parentDocument, obj); // just the regular approach
 
     } else
-        uError() << "Cant load CodeParam: parentUMLObject w/id:"
-            << Uml::ID::toString(id) << " not found, corrupt save file?";
+        logError1("CodeParameter::setAttributesFromNode: Cant load CodeParam: parentUMLObject w/id: %1 not found",
+                  Uml::ID::toString(id));
 
     // other attribs now
     setInitialValue(root.attribute(QLatin1String("initialValue")));
@@ -249,7 +249,7 @@ void CodeParameter::setAttributesFromNode(QDomElement & root)
         if (tag == QLatin1String("header")) {
             QDomNode cnode = element.firstChild();
             QDomElement celem = cnode.toElement();
-            getComment()->loadFromXMI1(celem);
+            getComment()->loadFromXMI(celem);
             gotComment = true;
             break;
         }
@@ -258,7 +258,7 @@ void CodeParameter::setAttributesFromNode(QDomElement & root)
     }
 
     if (!gotComment)
-        uWarning()<<" loadFromXMI1 : Warning: unable to initialize CodeComment in codeparam:"<<this;
+        logWarn0("CodeParameter::setAttributesFromNode: unable to initialize CodeComment in codeparam");
 }
 
 /**
