@@ -2,7 +2,7 @@
     SPDX-License-Identifier: GPL-2.0-or-later
 
     SPDX-FileCopyrightText: 2003 Brian Thomas <thomas@mail630.gsfc.nasa.gov>
-    SPDX-FileCopyrightText: 2004-2021 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
+    SPDX-FileCopyrightText: 2004-2022 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
 */
 
 /**
@@ -31,6 +31,8 @@
 // qt includes
 #include <QRegExp>
 
+DEBUG_REGISTER(JavaClassifierCodeDocument)
+
 JavaClassifierCodeDocument::JavaClassifierCodeDocument (UMLClassifier * concept)
         : ClassifierCodeDocument (concept)
 {
@@ -142,9 +144,9 @@ void JavaClassifierCodeDocument::loadChildTextBlocksFromNode (QDomElement & root
 
                 if (name == QLatin1String("codecomment")) {
                     CodeComment * block = new JavaCodeComment(this);
-                    block->loadFromXMI1(element);
+                    block->loadFromXMI(element);
                     if (!addTextBlock(block)) {
-                        uError()<<"loadFromXMI1 : unable to add codeComment to :"<<this;
+                        logError0("JavaClassifierCodeDocument: loadFromXMI : unable to add codeComment");
                         delete block;
                     } else {
                         loadCheckForChildrenOK= true;
@@ -155,25 +157,25 @@ void JavaClassifierCodeDocument::loadChildTextBlocksFromNode (QDomElement & root
                     // search for our method in the
                     TextBlock * tb = findCodeClassFieldTextBlockByTag(acctag);
                     if (!tb || !addTextBlock(tb)) {
-                        uError()<<"loadFromXMI1 : unable to add codeclassfield child method to:"<<this;
+                        logError0("JavaClassifierCodeDocument: loadFromXMI : unable to add codeclassfield child method");
                         // DON'T delete
                     } else {
                         loadCheckForChildrenOK= true;
                     }
                 } else if (name == QLatin1String("codeblock")) {
                     CodeBlock * block = newCodeBlock();
-                    block->loadFromXMI1(element);
+                    block->loadFromXMI(element);
                     if (!addTextBlock(block)) {
-                        uError()<<"loadFromXMI1 : unable to add codeBlock to :"<<this;
+                        logError0("JavaClassifierCodeDocument: loadFromXMI : unable to add codeBlock");
                         delete block;
                     } else {
                         loadCheckForChildrenOK= true;
                     }
                 } else if (name == QLatin1String("codeblockwithcomments")) {
                     CodeBlockWithComments * block = newCodeBlockWithComments();
-                    block->loadFromXMI1(element);
+                    block->loadFromXMI(element);
                     if (!addTextBlock(block)) {
-                        uError()<<"loadFromXMI1 : unable to add codeBlockwithcomments to:"<<this;
+                        logError0("JavaClassifierCodeDocument: loadFromXMI : unable to add codeBlockwithcomments");
                         delete block;
                     } else {
                         loadCheckForChildrenOK= true;
@@ -182,9 +184,9 @@ void JavaClassifierCodeDocument::loadChildTextBlocksFromNode (QDomElement & root
                     // do nothing.. this is treated elsewhere
                 } else if (name == QLatin1String("hierarchicalcodeblock")) {
                     HierarchicalCodeBlock * block = newHierarchicalCodeBlock();
-                    block->loadFromXMI1(element);
+                    block->loadFromXMI(element);
                     if (!addTextBlock(block)) {
-                        uError()<<"Unable to add hierarchicalcodeBlock to:"<<this;
+                        logError0("JavaClassifierCodeDocument: Unable to add hierarchicalcodeBlock");
                         delete block;
                     } else {
                         loadCheckForChildrenOK= true;
@@ -196,28 +198,29 @@ void JavaClassifierCodeDocument::loadChildTextBlocksFromNode (QDomElement & root
                     UMLOperation * op = obj->asUMLOperation();
                     if (op) {
                         CodeOperation * block = new JavaCodeOperation(this, op);
-                        block->loadFromXMI1(element);
+                        block->loadFromXMI(element);
                         if (addTextBlock(block)) {
                             loadCheckForChildrenOK= true;
                         } else {
-                            uError()<<"Unable to add codeoperation to:"<<this;
+                            logError0("JavaClassifierCodeDocument: Unable to add codeoperation");
                             block->deleteLater();
                         }
                     } else {
-                        uError()<<"Unable to find operation create codeoperation for:"<<this;
+                        logError0("JavaClassifierCodeDocument: Unable to find operation create codeoperation");
                     }
                 } else if (name == QLatin1String("javaclassdeclarationblock")) {
                     JavaClassDeclarationBlock * block = getClassDecl();
-                    block->loadFromXMI1(element);
+                    block->loadFromXMI(element);
                     if (!addTextBlock(block)) {
-                        uError()<<"Unable to add java code declaration block to:"<<this;
+                        logError0("JavaClassifierCodeDocument: Unable to add java code declaration block");
                         // DON'T delete.
                         // block->deleteLater();
                     } else {
                         loadCheckForChildrenOK= true;
                     }
                 } else {
-                    uDebug()<<" LoadFromXMI: Got strange tag in text block stack:"<<name<<", ignoring";
+                    logDebug1("JavaClassifierCodeDocument::loadChildTextBlocksFromNode: Got strange tag in "
+                              "text block stack:%1, ignoring", name);
                 }
 
                 node = element.nextSibling();
@@ -231,7 +234,7 @@ void JavaClassifierCodeDocument::loadChildTextBlocksFromNode (QDomElement & root
     }
 
     if (!loadCheckForChildrenOK) {
-        uWarning() << "loadChildBlocks : unable to initialize any child blocks in doc: " << getFileName() << " " << this;
+        logWarn1("loadChildBlocks : unable to initialize any child blocks in doc: %1", getFileName());
     }
 }
 
