@@ -2,7 +2,7 @@
     SPDX-License-Identifier: GPL-2.0-or-later
 
     SPDX-FileCopyrightText: 2003 Brian Thomas <thomas@mail630.gsfc.nasa.gov>
-    SPDX-FileCopyrightText: 2004-2021 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
+    SPDX-FileCopyrightText: 2004-2022 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
 */
 
 // own header
@@ -167,7 +167,7 @@ static const char *reserved_words[] = {
     "typedef",
     "union",
     "UnknownError",
-    "UnsatisfiedLinuError",
+    "UnsatisfiedLinkError",
     "unsigned",
     "UnsupportedClassVersionError",
     "UnsupportedOperationException",
