@@ -3,7 +3,7 @@
 
     SPDX-FileCopyrightText: 2002 Heiko Nardmann <h.nardmann@secunet.de>
     SPDX-FileCopyrightText: 2004 Thorsten Kunz <tk AT bytecrash DOT net>
-    SPDX-FileCopyrightText: 2003-2020 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
+    SPDX-FileCopyrightText: 2003-2022 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
 */
 
 #include "php5writer.h"
@@ -14,6 +14,7 @@
 #include "debug_utils.h"
 #include "operation.h"
 #include "umldoc.h"
+#include "uml.h"  // only needed for log{Warn,Error}
 
 #include <QRegExp>
 #include <QTextStream>
@@ -2992,7 +2993,7 @@ Php5Writer::~Php5Writer()
 void Php5Writer::writeClass(UMLClassifier *c)
 {
     if (!c) {
-        uDebug()<<"Cannot write class of NULL concept!";
+        logWarn0("Php5Writer::writeClass: Cannot write class of NULL concept");
         return;
     }
 
@@ -3091,7 +3092,7 @@ void Php5Writer::writeClass(UMLClassifier *c)
             //which container to use.
             UMLObject *o = a->getObject(Uml::RoleType::A);
             if (o == 0) {
-                uError() << "aggregation role A object is NULL" << endl;
+                logError0("Php5Writer::writeClass: aggregation role A object is NULL");
                 continue;
             }
             //:UNUSED: QString typeName = cleanName(o->name());
@@ -3109,7 +3110,7 @@ void Php5Writer::writeClass(UMLClassifier *c)
             // see comment on Aggregation about multiplicity...
             UMLObject *o = a->getObject(Uml::RoleType::A);
             if (o == 0) {
-                uError() << "composition role A object is NULL";
+                logError0("Php5Writer::writeClass: composition role A object is NULL");
                 continue;
             }
             //:UNUSED: QString typeName = cleanName(o->name());
@@ -3224,7 +3225,8 @@ void Php5Writer::writeOperations(UMLClassifier *c, QTextStream &php)
  * @param classname   the name of the class
  * @param opList      the list of operations
  * @param php         output stream for the PHP file
- * @param interface   indicates if the operation is an interface member
+ * @param isInterface indicates if the operation is an interface member
+ * @param generateErrorStub  true generates trigger_error("Implement " . __FUNCTION__)
  */
 void Php5Writer::writeOperations(const QString & classname, UMLOperationList &opList,
                                  QTextStream &php, bool isInterface /* = false */,
