@@ -2,7 +2,7 @@
     SPDX-License-Identifier: GPL-2.0-or-later
 
     SPDX-FileCopyrightText: 2002 Heiko Nardmann <h.nardmann@secunet.de>
-    SPDX-FileCopyrightText: 2003-2020 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
+    SPDX-FileCopyrightText: 2003-2022 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
 */
 
 #include "phpwriter.h"
@@ -13,6 +13,7 @@
 #include "debug_utils.h"
 #include "operation.h"
 #include "umldoc.h"
+#include "uml.h"  // Only needed for log{Warn,Error}
 
 #include <QRegExp>
 #include <QTextStream>
@@ -2988,7 +2989,7 @@ PhpWriter::~PhpWriter()
 void PhpWriter::writeClass(UMLClassifier *c)
 {
     if (!c) {
-        uDebug() << "Cannot write class of NULL concept!";
+        logWarn0("PhpWriter::writeClass: Cannot write class of NULL concept");
         return;
     }
 
