@@ -1,6 +1,6 @@
 /*
     SPDX-License-Identifier: GPL-2.0-or-later
-    SPDX-FileCopyrightText: 2009-2021 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
+    SPDX-FileCopyrightText: 2009-2022 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
 */
 
 //
@@ -179,7 +179,7 @@ QStringList ValaWriter::defaultDatatypes() const
 void ValaWriter::writeClass(UMLClassifier *c)
 {
     if (!c) {
-        uDebug() << "Cannot write class of NULL concept!";
+        logWarn0("ValaWriter::writeClassL Cannot write class of NULL concept");
         return;
     }
 
@@ -500,8 +500,9 @@ void ValaWriter::writeRealizationsRecursive(UMLClassifier *currentClass, UMLAsso
  * Write a list of class operations.
  * @param opList the list of operations
  * @param cs output stream
- * @param interface indicates if the operation is an interface member
+ * @param isInterface indicates if the operation is an interface member
  * @param isOverride implementation of an inherited abstract function
+ * @param generateErrorStub  true generates a comment "The method or operation is not implemented"
  */
 void ValaWriter::writeOperations(UMLOperationList opList,
                                  QTextStream &cs, bool isInterface /* = false */,
@@ -716,7 +717,7 @@ void ValaWriter::writeAssociatedAttributes(UMLAssociationList &associated, UMLCl
 
         UMLObject *o = a->getObject(Uml::RoleType::B);
         if (o == 0) {
-            uError() << "composition role B object is NULL";
+            logError0("ValaWriter::writeAssociatedAttributes: composition role B object is NULL");
             continue;
         }
         // Take name and documentation from Role, take type name from the referenced object
@@ -813,7 +814,7 @@ void ValaWriter::writeAttribute(const QString& doc,
 
 /**
  * Find the type in used namespaces, if namespace found return short name, complete otherwise.
- * @param at Operation or Attribute to check type
+ * @param cl Operation or Attribute to check type
  * @return   the local type name
  */
 QString ValaWriter::makeLocalTypeName(UMLClassifierListItem *cl)
