@@ -1,6 +1,6 @@
 /*
     SPDX-License-Identifier: GPL-2.0-or-later
-    SPDX-FileCopyrightText: 2005-2020 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
+    SPDX-FileCopyrightText: 2005-2022 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
 */
 
 // own header
@@ -10,6 +10,7 @@
 #include "association.h"
 #include "attribute.h"
 #include "classifier.h"
+#define DBG_SRC QLatin1String("AdaImport")
 #include "debug_utils.h"
 #include "enum.h"
 #include "folder.h"
@@ -24,6 +25,8 @@
 
 #include <stdio.h>
 
+DEBUG_REGISTER(AdaImport)
+
 /**
  * Constructor.
  */
@@ -261,7 +264,7 @@ bool AdaImport::parseStmt()
         } else if (m_source[m_srcIndex] == QLatin1String("renames")) {
             m_renaming[name] = advance();
         } else {
-            uError() << "unexpected: " << m_source[m_srcIndex];
+            logError1("AdaImport::parseStmt unexpected: %1", m_source[m_srcIndex]);
             skipStmt(QLatin1String("is"));
         }
         if (m_inGenericFormalPart) {
@@ -297,7 +300,7 @@ bool AdaImport::parseStmt()
         QString name = advance();
         QString next = advance();
         if (next == QLatin1String("(")) {
-            uDebug() << name << ": discriminant handling is not yet implemented";
+            logDebug1("AdaImport::parseStmt %1: discriminant handling is not yet implemented", name);
             // @todo Find out how to map discriminated record to UML.
             //       For now, we just create a pro forma empty record.
             Import_Utils::createUMLObject(UMLObject::ot_Class, name, currentScope(),
@@ -315,7 +318,7 @@ bool AdaImport::parseStmt()
             return true;
         }
         if (next != QLatin1String("is")) {
-            uError() << "expecting \"is\"";
+            logError1("AdaImport::parseStmt: expecting \"is\" at %1", next);
             return false;
         }
         next = advance();
@@ -434,21 +437,21 @@ bool AdaImport::parseStmt()
     if (keyword == QLatin1String("end")) {
         if (m_klass) {
             if (advance() != QLatin1String("record")) {
-                uError() << "end: expecting \"record\" at "
-                          << m_source[m_srcIndex];
+                logError1("AdaImport::parseStmt end: expecting \"record\" at %1",
+                          m_source[m_srcIndex]);
             }
             m_klass = 0;
         } else if (scopeIndex()) {
             if (advance() != QLatin1String(";")) {
                 QString scopeName = currentScope()->fullyQualifiedName();
                 if (scopeName.toLower() != m_source[m_srcIndex].toLower())
-                    uError() << "end: expecting " << scopeName << ", found "
-                              << m_source[m_srcIndex];
+                    logError2("AdaImport::parseStmt end: expecting %1, found %2",
+                              scopeName, m_source[m_srcIndex]);
             }
             popScope();
             m_currentAccess = Uml::Visibility::Public;   // @todo make a stack for this
         } else {
-            uError() << "importAda: too many \"end\"";
+            logError1("AdaImport::parseStmt: too many \"end\" at index %1", m_srcIndex);
         }
         skipStmt();
         return true;
@@ -466,7 +469,7 @@ bool AdaImport::parseStmt()
             // subprograms.
             // In order to map those, we would need to create a UML
             // class with stereotype <<utility>> for the Ada package.
-            uDebug() << "ignoring parameterless " << keyword << " " << name;
+            logDebug2("AdaImport::parseStmt(%1): ignoring parameterless %2", keyword, name);
             skipStmt();
             return true;
         }
@@ -478,13 +481,14 @@ bool AdaImport::parseStmt()
             uint parNameCount = 0;
             do {
                 if (parNameCount >= MAX_PARNAMES) {
-                    uError() << "MAX_PARNAMES is exceeded at " << name;
+                    logError1("AdaImport::parseStmt: MAX_PARNAMES is exceeded at %1", name);
                     break;
                 }
                 parName[parNameCount++] = advance();
             } while (advance() == QLatin1String(","));
             if (m_source[m_srcIndex] != QLatin1String(":")) {
-                uError() << "importAda: expecting ':'";
+                logError2("AdaImport::parseStmt: expecting ':' at %1 (index %2)",
+                          m_source[m_srcIndex], m_srcIndex);
                 skipStmt();
                 break;
             }
@@ -543,8 +547,9 @@ bool AdaImport::parseStmt()
         if (keyword == QLatin1String("function")) {
             if (advance() != QLatin1String("return")) {
                 if (klass)
-                    uError() << "importAda: expecting \"return\" at function "
-                        << name;
+                    logError1("AdaImport::parseStmt: expecting \"return\" at function %1", name);
+                else
+                    logError1("AdaImport::parseStmt: expecting \"return\" at %1", m_source[m_srcIndex]);
                 return false;
             }
             returnType = expand(advance());
@@ -586,8 +591,7 @@ bool AdaImport::parseStmt()
             if (advance() == QLatin1String("record"))
                 skipStmt(QLatin1String("end"));
         } else {
-            uError() << "importAda: expecting \"use\" at rep spec of "
-                      << typeName;
+            logError1("AdaImport::parseStmt: expecting \"use\" at rep spec of %1", typeName);
         }
         skipStmt();
         return true;
@@ -599,8 +603,7 @@ bool AdaImport::parseStmt()
     }
     const QString& name = keyword;
     if (advance() != QLatin1String(":")) {
-        uError() << "adaImport: expecting \":\" at " << name << " "
-                  << m_source[m_srcIndex];
+        logError2("AdaImport::parseStmt:: expecting \":\" at %1 %2", name, m_source[m_srcIndex]);
         skipStmt();
         return true;
     }
