@@ -1,6 +1,6 @@
 /*
     SPDX-License-Identifier: GPL-2.0-or-later
-    SPDX-FileCopyrightText: 2005-2020 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
+    SPDX-FileCopyrightText: 2005-2022 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
 */
 
 // own header
@@ -11,6 +11,7 @@
 #include "artifact.h"
 #include "classifier.h"
 #include "datatype.h"
+#define DBG_SRC QLatin1String("Import_Utils")
 #include "debug_utils.h"
 #include "folder.h"
 #include "enum.h"
@@ -27,6 +28,9 @@
 #include <KMessageBox>
 #include <KLocalizedString>
 
+// qt includes
+#include <QtGlobal>
+
 #ifdef Q_OS_WIN
 #define PATH_SEPARATOR QLatin1Char(';')
 #else
@@ -34,8 +38,6 @@
 #endif
 
 DEBUG_REGISTER_DISABLED(Import_Utils)
-#undef DBG_SRC
-#define DBG_SRC QLatin1String("Import_Utils")
 
 namespace Import_Utils {
 
@@ -150,14 +152,23 @@ QString formatComment(const QString &comment)
     return lines.join(QLatin1String("\n"));
 }
 
-/*
-UMLObject* findUMLObject(QString name, UMLObject::ObjectType type)
-{
-    // Why an extra wrapper? See comment at addMethodParameter()
-    UMLObject * o = umldoc->findUMLObject(name, type);
-    return o;
-}
+/**
+ * Peculiarity of Umbrello: std::string must be mapped to "string" because
+ * that is the predefined type in the Datatypes folder, and if we leave
+ * std::string as it is then there will be a second type "string" in the
+ * package "std" generated by the import.
+ * Having two types "string" would create confusion for the user and would
+ * not fit with the C++ code generator which generates "std::string" from
+ * the "string" of the Datatypes folder.
+ *
+ * @param typeName  Writable reference to QString variable: If content is
+ *                  "std::string" then it will be changed to "string".
  */
+void checkStdString(QString& typeName)
+{
+    if (typeName == QLatin1String("std::string"))
+        typeName = QLatin1String("string");
+}
 
 /**
  * Find or create a document object.
@@ -182,21 +193,30 @@ UMLObject *createUMLObject(UMLObject::ObjectType type,
     UMLDoc *umldoc = UMLApp::app()->document();
     UMLFolder *logicalView = umldoc->rootFolder(Uml::ModelType::Logical);
     if (parentPkg == 0) {
-        // DEBUG(DBG_SRC) << "Import_Utils::createUMLObject(" << name
-        //     << "): parentPkg is 0, assuming Logical View";
+        // logDebug1("Import_Utils::createUMLObject(%1): parentPkg is 0, assuming Logical View", name);
         parentPkg = logicalView;
     } else if (parentPkg->baseType() == UMLObject::ot_Artifact) {
-        DEBUG(DBG_SRC) << "Import_Utils::createUMLObject(" << name
-                       << "): Artifact as parent package is not supported yet, using Logical View";
+        logDebug1("Import_Utils::createUMLObject(%1): Artifact as parent package is not supported yet, "
+                  "using Logical View", name);
         parentPkg = logicalView;
     } else if (parentPkg->baseType() == UMLObject::ot_Association) {
-        DEBUG(DBG_SRC) << "Import_Utils::createUMLObject(" << name
-                       << "): Association as parent package is not supported yet, using Logical View";
+#ifdef QT_NO_DEBUG
+        logError1("Import_Utils::createUMLObject(%1) grave error: "
+                  "Attempt to use Association as parent package", name);
+#else
+        qFatal("Import_Utils::createUMLObject(%s): Attempt to use Association as parent package",
+               qPrintable(name));
+#endif
         parentPkg = logicalView;
-    } else if (name.startsWith(UMLApp::app()->activeLanguageScopeSeparator())) {
+    } else if (name.startsWith(QLatin1String("::"))) {
         name = name.mid(2);
         parentPkg = logicalView;
+    } else if (UMLApp::app()->activeLanguage() == Uml::ProgrammingLanguage::Ada &&
+               name.startsWith(QLatin1String("Standard."), Qt::CaseInsensitive)) {
+        name = name.mid(9);
+        parentPkg = logicalView;
     }
+    checkStdString(name);
     bNewUMLObjectWasCreated = false;
     UMLObject *o = 0;
     if (searchInParentPackageOnly) {
@@ -211,8 +231,19 @@ UMLObject *createUMLObject(UMLObject::ObjectType type,
     }
     if (o == 0) {
         // Strip possible adornments and look again.
-        const bool isConst = name.contains(QRegExp(QLatin1String("^const ")));
-        name.remove(QRegExp(QLatin1String("^const\\s+")));
+        bool isConst = false;
+        if (name.contains(QRegExp(QLatin1String("^const ")))) {
+            name.remove(QRegExp(QLatin1String("^const\\s+")));
+            isConst = true;
+        }
+        if (name.contains(QRegExp(QLatin1String("\\bconst\\b")))) {
+            // Here, we lose info of the exact placement of the `const` qualifier.
+            // I argue that we are looking at a level of C++ detail that UML was not
+            // designed for.  Feel free to disagree and implement this :)
+            name.remove(QRegExp(QLatin1String("\\s+const\\b")));
+            name.remove(QRegExp(QLatin1String("\\bconst\\s+")));
+            isConst = true;
+        }
         const bool isVolatile = name.contains(QRegExp(QLatin1String("^volatile ")));
         name.remove(QRegExp(QLatin1String("^volatile\\s+")));
         const bool isMutable = name.contains(QRegExp(QLatin1String("^mutable ")));
@@ -223,6 +254,7 @@ UMLObject *createUMLObject(UMLObject::ObjectType type,
         const bool isRef = typeName.contains(QLatin1Char('&'));
         typeName.remove(QRegExp(QLatin1String("[^\\w:\\. ].*$")));
         typeName = typeName.simplified();
+        checkStdString(typeName);
         UMLObject *origType = umldoc->findUMLObject(typeName, UMLObject::ot_UMLObject, parentPkg);
         if (origType == 0) {
             // Still not found. Create the stripped down type.
@@ -239,9 +271,10 @@ UMLObject *createUMLObject(UMLObject::ObjectType type,
                 parentPkg = umldoc->datatypeFolder();
                 isAdorned = false;
             }
-            if (components.count() > 1) {
+            const bool isScopedName = (components.count() > 1);
+            if (isScopedName) {
                 typeName = components.back();
-                components.pop_back();
+                components.pop_back();  // remove the type name leaving only its scope path
                 while (components.count()) {
                     QString scopeName = components.front();
                     components.pop_front();
@@ -265,7 +298,7 @@ UMLObject *createUMLObject(UMLObject::ObjectType type,
                 bPutAtGlobalScope = true;
             }
             UMLObject::ObjectType t = type;
-            if (type == UMLObject::ot_UMLObject || isAdorned)
+            if (type == UMLObject::ot_UMLObject)
                 t = UMLObject::ot_Class;
             origType = Object_Factory::createUMLObject(t, typeName, parentPkg, false);
             bNewUMLObjectWasCreated = true;
@@ -287,8 +320,7 @@ UMLObject *createUMLObject(UMLObject::ObjectType type,
             if (dt && c)
                 dt->setOriginType(c);
             else
-                uError() << "createUMLObject(" << name << "): "
-                    << "origType " << typeName << " is not a UMLClassifier";
+                logError2("Import_Utils::createUMLObject(%1): origType %2 is not a UMLClassifier", name, typeName);
             if (dt && (isRef || isPointer))
                 dt->setIsReference();
             /*
@@ -308,8 +340,7 @@ UMLObject *createUMLObject(UMLObject::ObjectType type,
             if (existingPkg)
                 existingPkg->removeObject(o);
             else
-                uError() << "createUMLObject(" << name << "): "
-                    << "o->getUMLPackage() was NULL";
+                logError1("Import_Utils::createUMLObject(%1): o->getUMLPackage() was NULL", name);
             parentPkg->addObject(o);
             o->setUMLPackage(parentPkg);
             // setUMLPackage() triggers tree view item update if not loading by default
@@ -352,7 +383,7 @@ UMLObject *createUMLObject(UMLObject::ObjectType type,
         umldoc->addAssociation(assoc);
     }
     if (o == 0) {
-        uError() << "is NULL!";
+        logError1("Import_Utils::createUMLObject(%1) : operation failed", inName);
     }
     return o;
 }
@@ -360,8 +391,8 @@ UMLObject *createUMLObject(UMLObject::ObjectType type,
 /**
  * Create hierarchical tree of UML objects
  *
- * This method creates the UML object specified by #type and #name including an optional namespace hierarchy
- * if included in the #name e.g. NamespaceA::ClassA in C++.
+ * This method creates the UML object specified by @p type and @p name including an optional namespace hierarchy
+ * if included in the @p name e.g. NamespaceA::ClassA in C++.
  *
  * @param type  type of UML object to create
  * @param name  name of UML object
@@ -429,8 +460,8 @@ UMLAttribute* insertAttribute(UMLClassifier *owner,
     Uml::ProgrammingLanguage::Enum pl = UMLApp::app()->activeLanguage();
     if (! (ot == UMLObject::ot_Class ||
            (ot == UMLObject::ot_Interface && pl == Uml::ProgrammingLanguage::Java))) {
-        DEBUG(DBG_SRC) << "insertAttribute: Don not know what to do with "
-                 << owner->name() << " (object type " << UMLObject::toString(ot) << ")";
+        logDebug2("Import_Utils::insertAttribute: Don't know what to do with %1 (object type %2)",
+                  owner->name(), UMLObject::toString(ot));
         return 0;
     }
     UMLObject *o = owner->findChildObject(name, UMLObject::ot_Attribute);
@@ -561,8 +592,6 @@ void insertMethod(UMLClassifier *klass, UMLOperation* &op,
 
 /**
  * Add an argument to a UMLOperation.
- * The parentPkg arg is only used for resolving possible scope
- * prefixes in the `type'.
  */
 UMLAttribute* addMethodParameter(UMLOperation *method,
                                  const QString& type,
@@ -613,8 +642,8 @@ UMLAssociation *createGeneralization(UMLClassifier *child, UMLClassifier *parent
         assoc->setUMLPackage(child->umlPackage());
         child->addAssociationEnd(assoc);
     } else {
-        uDebug() << "Import_Utils::createGeneralization(child " << child->name()
-                 << ", parent " << parent->name() << ") : Package is not set on child";
+        logDebug2("Import_Utils::createGeneralization(child %1, parent %2) : "
+                  "Package is not set on child", child->name(), parent->name());
         UMLDoc *umldoc = UMLApp::app()->document();
         UMLPackage *owningPackage = umldoc->rootFolder(Uml::ModelType::Logical);
         assoc->setUMLPackage(owningPackage);
@@ -664,7 +693,7 @@ UMLObject *createArtifactFolder(const QString& name,
     o = Object_Factory::createUMLObject(type, name, componentView, false);
     UMLFolder *a = o->asUMLFolder();
     a->setDoc(comment);
-    DEBUG(DBG_SRC) << name << comment;
+    logDebug2("Import_Utils::createArtifactFolder %1 %2", name, comment);
     return o;
 }
 
@@ -688,7 +717,7 @@ UMLObject *createArtifact(const QString& name,
     UMLArtifact *a = o->asUMLArtifact();
     a->setDrawAsType(UMLArtifact::file);
     a->setDoc(comment);
-    DEBUG(DBG_SRC) << name << comment;
+    logDebug2("Import_Utils::createArtifact %1 %2", name, comment);
     return o;
 }
 
@@ -752,12 +781,14 @@ UMLEnum *remapUMLEnum(UMLObject *ns, UMLPackage *currentScope)
         currentScope = UMLApp::app()->document()->rootFolder(Uml::ModelType::Logical);
     UMLObject *o = Object_Factory::createNewUMLObject(UMLObject::ot_Enum, name, currentScope, false);
     if (!o) {
-        DEBUG(DBG_SRC) << name << " : Object_Factory::createNewUMLObject(ot_Enum) returns null";
+        logDebug1("Import_Utils::remapUMLEnum(%1) : Object_Factory::createNewUMLObject(ot_Enum) returns null",
+                  name);
         return 0;
     }
     UMLEnum *e = o->asUMLEnum();
     if (!e) {
-        DEBUG(DBG_SRC) << name << " : object returned by Object_Factory::createNewUMLObject is not Enum";
+        logDebug1("Import_Utils::remapUMLEnum(%1) : object returned by Object_Factory::createNewUMLObject "
+                  "is not Enum", name);
         return 0;
     }
     e->setDoc(comment);
@@ -766,7 +797,7 @@ UMLEnum *remapUMLEnum(UMLObject *ns, UMLPackage *currentScope)
     // add to parents child list
     if (currentScope->addObject(e, false))  // false => non interactively
         return e;
-    DEBUG(DBG_SRC) << name << " : name is already present in " << currentScope->name();
+    logDebug2("Import_Utils::remapUMLEnum(%1) : name is already present in %2", name, currentScope->name());
     return 0;
 }
 
