@@ -1,12 +1,7 @@
-/***************************************************************************
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   copyright (C) 2003-2014                                               *
- *   Umbrello UML Modeller Authors <umbrello-devel@kde.org>                *
- ***************************************************************************/
+/*
+    SPDX-License-Identifier: GPL-2.0-or-later
+    SPDX-FileCopyrightText: 2003-2020 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
+*/
 
 // own header
 #include "classpropertiesdialog.h"
@@ -92,26 +87,25 @@ ClassPropertiesDialog::ClassPropertiesDialog(QWidget *parent, UMLWidget *w)
     m_pWidget = w;
     m_pObject = w->umlObject();
 
-    if (w->baseType() == WidgetBase::wt_Class
-            || w->baseType() == WidgetBase::wt_Interface
-            || w->baseType() == WidgetBase::wt_Enum
-            || w->baseType() == WidgetBase::wt_Package) {
+    if (w->isClassWidget()
+            || w->isInterfaceWidget()
+            || w->isEnumWidget()
+            || w->isPackageWidget()) {
         setupPages(true);
-    } else if (w->baseType() == WidgetBase::wt_Component) {
+    } else if (w->isComponentWidget()) {
         if (w->isInstance()) {
             setupInstancePages();
         } else {
-            setupPages();
+            setupPages(true);
         }
-    } else if (w->baseType() == WidgetBase::wt_Node) {
+    } else if (w->isNodeWidget()) {
         setupInstancePages();
     } else {
         setupPages();
     }
 
     // now setup the options page for classes
-    if (w->baseType() == WidgetBase::wt_Class ||
-        w->baseType() == WidgetBase::wt_Interface) {
+    if (w->isClassWidget() || w->isInterfaceWidget()) {
         setupDisplayPage();
     }
     setupStylePage(m_pWidget);
@@ -224,6 +218,8 @@ void ClassPropertiesDialog::setupPages(bool assoc)
     if (ot == UMLObject::ot_Entity) {
         setupEntityAttributesPage();
         setupEntityConstraintsPage();
+        if (m_pWidget && m_pWidget->isEntityWidget())
+            setupEntityDisplayPage(m_pWidget->asEntityWidget());
     }
     if (ot == UMLObject::ot_Package) {
         setupContentsPage();
@@ -240,17 +236,15 @@ void ClassPropertiesDialog::setupPages(bool assoc)
  */
 void ClassPropertiesDialog::setupGeneralPage()
 {
-    QFrame* page = createPage(i18nc("general settings page name", "General"), i18n("General Settings"),
-                               Icon_Utils::it_Properties_General);
-    page->setMinimumSize(310, 330);
-    QHBoxLayout * topLayout = new QHBoxLayout(page);
     if (m_pWidget && m_pWidget->baseType() == UMLWidget::wt_Object)
-        m_pGenPage = new ClassGeneralPage(m_doc, page, static_cast<ObjectWidget*>(m_pWidget));
+        m_pGenPage = new ClassGeneralPage(m_doc, 0, static_cast<ObjectWidget*>(m_pWidget));
     else if (m_pWidget && !m_pObject)
-        m_pGenPage = new ClassGeneralPage(m_doc, page, m_pWidget);
+        m_pGenPage = new ClassGeneralPage(m_doc, 0, m_pWidget);
     else
-        m_pGenPage = new ClassGeneralPage(m_doc, page, m_pObject);
-    topLayout->addWidget(m_pGenPage);
+        m_pGenPage = new ClassGeneralPage(m_doc, 0, m_pObject);
+    createPage(i18nc("general settings page name", "General"), i18n("General Settings"),
+               Icon_Utils::it_Properties_General, m_pGenPage)->widget()->setMinimumSize(310, 330);
+    m_pGenPage->setFocus();
 }
 
 /**
@@ -258,12 +252,20 @@ void ClassPropertiesDialog::setupGeneralPage()
  */
 void ClassPropertiesDialog::setupDisplayPage()
 {
-    QFrame* page = createPage(i18nc("display option page name", "Display"), i18n("Display Options"),
-                               Icon_Utils::it_Properties_Display);
-    QHBoxLayout* m_pOptionsLayout = new QHBoxLayout(page);
-    ClassifierWidget *cw = static_cast<ClassifierWidget*>(m_pWidget);
-    m_pOptionsPage = new ClassOptionsPage(page, cw);
-    m_pOptionsLayout->addWidget(m_pOptionsPage);
+    ClassifierWidget *cw = m_pWidget->asClassifierWidget();
+    m_pOptionsPage = new ClassOptionsPage(0, cw);
+    createPage(i18nc("display option page name", "Display"), i18n("Display Options"),
+               Icon_Utils::it_Properties_Display, m_pOptionsPage);
+}
+
+/**
+ * Sets up the page "Display" for the component.
+ */
+void ClassPropertiesDialog::setupEntityDisplayPage(EntityWidget *widget)
+{
+    m_pOptionsPage = new ClassOptionsPage(0, widget);
+    createPage(i18nc("display option page name", "Display"), i18n("Display Options"),
+               Icon_Utils::it_Properties_Display, m_pOptionsPage);
 }
 
 /**
