@@ -1,6 +1,6 @@
 /*
     SPDX-License-Identifier: GPL-2.0-or-later
-    SPDX-FileCopyrightText: 2004-2020 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
+    SPDX-FileCopyrightText: 2004-2022 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
 */
 
 // own header
@@ -42,6 +42,7 @@ namespace Dialog_Utils {
  * @param labelText             The label text.
  * @param editField             The KLineEdit object allocated (return value)
  * @param editFieldText         Initialization text in the editField (optional.)
+ * @param columnOffset          Optional column number within the QGridLayout (default: 0)
  * @return a pointer to the KLineEdit so you can setFocus() if necessary
  */
 KLineEdit* makeLabeledEditField(QGridLayout* layout,    int row,
@@ -146,8 +147,8 @@ void updateTagsFromEditFields(UMLObject * o,
     tags.clear();
     for (int i = 0; i < attrDefs.size() && i < N_STEREOATTRS; i++) {
         if (pTagLineEdit[i] == 0) {
-            uError() << "updateTagsFromEditFields(" << o->name() << "): " << stereo->name(true)
-                     << " pTagLineEdit[" << i << "] is null";
+            logError3("updateTagsFromEditFields(%1): %2 pTagLineEdit[%3] is null",
+                      o->name(), stereo->name(true), i);
             break;
         }
         QString tag = pTagLineEdit[i]->text();
@@ -191,11 +192,12 @@ bool askName(const QString& title, const QString& prompt, QString& name)
 {
     bool ok;
 #if QT_VERSION >= 0x050000
-     name = QInputDialog::getText((QWidget*)UMLApp::app(), title, prompt, QLineEdit::Normal, name, &ok);
+    name = QInputDialog::getText((QWidget*)UMLApp::app(), title, prompt, QLineEdit::Normal, name, &ok);
 #else
-     name = KInputDialog::getText(title, prompt, name, &ok, (QWidget*)UMLApp::app());
+    name = KInputDialog::getText(title, prompt, name, &ok, (QWidget*)UMLApp::app());
 #endif
-     return ok;
+    name = Model_Utils::normalize(name);
+    return ok;
 }
 
 /**
