@@ -1,12 +1,15 @@
 /*
     SPDX-License-Identifier: GPL-2.0-or-later
-    SPDX-FileCopyrightText: 2012-2020 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
+    SPDX-FileCopyrightText: 2012-2022 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
 */
 
 #include "singlepagedialogbase.h"
 
 // app include
-#include <debug_utils.h>
+#include "debug_utils.h"
+#include "uml.h"
+
+// kde include
 #include <KLocalizedString>
 
 DEBUG_REGISTER(SinglePageDialogBase)
@@ -76,7 +79,8 @@ SinglePageDialogBase::~SinglePageDialogBase()
  */
 bool SinglePageDialogBase::apply()
 {
-    DEBUG(DBG_SRC) << "no derived apply() method present, called empty base implementation";
+    logDebug0("SinglePageDialogBase::apply: no derived apply() method present, "
+              "called empty base implementation");
     return true;
 }
 
