@@ -1,17 +1,21 @@
 /*
     SPDX-License-Identifier: GPL-2.0-or-later
-    SPDX-FileCopyrightText: 2020-2020 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
+    SPDX-FileCopyrightText: 2020-2022 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
 */
 
 #include "file_utils.h"
 
 // app includes
+#define DBG_SRC QLatin1String("File_Utils")
 #include "debug_utils.h"
+#include "uml.h"  // Only needed for logDebug
 
 // qt includes
 #include <QFileInfo>
 #include <QCoreApplication>
 
+DEBUG_REGISTER(File_Utils)
+
 namespace File_Utils {
 
 /**
@@ -26,7 +30,7 @@ QString xmlCatalogFilePath()
     QString dataRoot = QLatin1String("/");
 #endif
     QFileInfo fi(dataRoot + QLatin1String("etc/xml/catalog"));
-    uDebug() << fi.canonicalFilePath();
+    logDebug1("File_Utils::xmlCatalogFilePath: %1", fi.canonicalFilePath());
     return fi.canonicalFilePath();
 }
 
