@@ -1,6 +1,6 @@
 /*
     SPDX-License-Identifier: GPL-2.0-or-later
-    SPDX-FileCopyrightText: 2012-2021 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
+    SPDX-FileCopyrightText: 2012-2022 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
 */
 
 #include "layoutgenerator.h"
@@ -8,6 +8,7 @@
 #include "associationline.h"
 #include "associationwidget.h"
 #include "cmds.h"
+#define DBG_SRC QLatin1String("LayoutGenerator")
 #include "debug_utils.h"
 #include "floatingtextwidget.h"
 #include "uml.h"
@@ -77,6 +78,9 @@ static QGraphicsPathItem *s_debugItems;
 static QPainterPath s_path;
 #endif
 
+// Currently this file is not using debug statements. Activate this line when inserting them:
+//DEBUG_REGISTER(LayoutGenerator)
+
 /**
  * constructor
 */
@@ -107,7 +111,7 @@ bool LayoutGenerator::generate(UMLScene *scene, const QString &variant)
     QTemporaryFile out;
     QTemporaryFile xdotOut;
     if (!isEnabled()) {
-        uWarning() << "Could not apply autolayout because graphviz installation has not been found.";
+        logWarn0("LayoutGenerator::generate: Could not apply autolayout because graphviz not found.");
         return false;
     }
 
@@ -190,7 +194,7 @@ bool LayoutGenerator::generate(UMLScene *scene, const QString &variant)
 bool LayoutGenerator::apply(UMLScene *scene)
 {
     foreach(AssociationWidget *assoc, scene->associationList()) {
-        AssociationLine *path = assoc->associationLine();
+        AssociationLine& path = assoc->associationLine();
         QString type = Uml::AssociationType::toString(assoc->associationType()).toLower();
         QString key = QLatin1String("type::") + type;
 
@@ -203,10 +207,9 @@ bool LayoutGenerator::apply(UMLScene *scene)
         // adjust associations not used in the dot file
         if (!m_edges.contains(id)) {
             // shorten line path
-            AssociationLine *path = assoc->associationLine();
-            if (path->count() > 2 && assoc->widgetLocalIDForRole(Uml::RoleType::A) != assoc->widgetLocalIDForRole(Uml::RoleType::B)) {
-                while(path->count() > 2)
-                    path->removePoint(1);
+            if (path.count() > 2 && assoc->widgetLocalIDForRole(Uml::RoleType::A) != assoc->widgetLocalIDForRole(Uml::RoleType::B)) {
+                while (path.count() > 2)
+                    path.removePoint(1);
             }
             continue;
         }
@@ -234,29 +237,29 @@ bool LayoutGenerator::apply(UMLScene *scene)
         s_debugItems->setPath(s_path);
 #endif
         if (m_version <= 20130928) {
-            path->setLayout(Uml::LayoutType::Direct);
-            path->cleanup();
-            path->setEndPoints(mapToScene(p[0]), mapToScene(p[len-1]));
+            path.setLayout(Uml::LayoutType::Direct);
+            path.cleanup();
+            path.setEndPoints(mapToScene(p[0]), mapToScene(p[len-1]));
         } else {
-            path->setLayout(Settings::optionState().generalState.layoutType);
-            path->cleanup();
+            path.setLayout(Settings::optionState().generalState.layoutType);
+            path.cleanup();
 
             if (Settings::optionState().generalState.layoutType == Uml::LayoutType::Polyline) {
                 for (int i = 0; i < len; i++) {
                     if (i > 0 && p[i] == p[i-1])
                         continue;
-                    path->addPoint(mapToScene(p[i]));
+                    path.addPoint(mapToScene(p[i]));
                 }
             } else if(Settings::optionState().generalState.layoutType == Uml::LayoutType::Spline) {
                 for (int i = 0; i < len; i++) {
-                    path->addPoint(mapToScene(p[i]));
+                    path.addPoint(mapToScene(p[i]));
                 }
             } else if (Settings::optionState().generalState.layoutType == Uml::LayoutType::Orthogonal) {
                 for (int i = 0; i < len; i++) {
-                    path->addPoint(mapToScene(p[i]));
+                    path.addPoint(mapToScene(p[i]));
                 }
             } else
-                path->setEndPoints(mapToScene(p[0]), mapToScene(p[len-1]));
+                path.setEndPoints(mapToScene(p[0]), mapToScene(p[len-1]));
         }
     }
 
@@ -286,8 +289,7 @@ bool LayoutGenerator::apply(UMLScene *scene)
 
     foreach(AssociationWidget *assoc, scene->associationList()) {
         assoc->calculateEndingPoints();
-        if (assoc->associationLine())
-            assoc->associationLine()->update();
+        assoc->associationLine().update();
         assoc->resetTextPositions();
         assoc->saveIdealTextPositions();
     }
@@ -343,14 +345,14 @@ QPointF LayoutGenerator::origin(const QString &id)
     QString key = fixID(id);
     if (!m_nodes.contains(key)) {
 #ifdef LAYOUTGENERATOR_DATA_DEBUG
-        uDebug() << key;
+        DEBUG() << "LayoutGenerator::origin(" << id << "): " << key;
 #endif
         return QPoint(0,0);
     }
     QRectF &r = m_nodes[key];
     QPointF p(m_origin.x() + r.x() - r.width()/2, m_boundingRect.height() - r.y() + r.height()/2 + m_origin.y());
 #ifdef LAYOUTGENERATOR_DATA_DEBUG
-    uDebug() << r << p;
+    DEBUG() << r << p;
 #endif
     return p;
 }
@@ -509,10 +511,10 @@ bool LayoutGenerator::parseLine(const QString &line)
 
     QString keyword = m_cols.cap(1).trimmed();
     QString attributeString = m_cols.cap(2);
-    uDebug() << keyword << attributeString;
+    DEBUG() << "LayoutGenerator::parseLine " <<  keyword << attributeString;
     ParameterList attributes;
     splitParameters(attributes, attributeString);
-    uDebug() << attributes;
+    DEBUG() << attributes;
 
     if (keyword == QLatin1String("graph")) {
         if (attributes.contains(QLatin1String("bb"))) {
@@ -582,7 +584,7 @@ bool LayoutGenerator::parseLine(const QString &line)
             QStringList &a = attributes[QLatin1String("width")];
             f.setWidth(a[0].toDouble()*scale);
         }
-        uDebug() << "adding" << id << f;
+        DEBUG() << "LayoutGenerator::parseLine adding " << id << f;
         m_nodes[id] = f;
     }
 return true;
