@@ -1,9 +1,10 @@
 /*
     SPDX-License-Identifier: GPL-2.0-or-later
-    SPDX-FileCopyrightText: 2002-2021 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
+    SPDX-FileCopyrightText: 2002-2022 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
 */
 
 // app includes
+#define DBG_SRC QLatin1String("main")
 #include "debug_utils.h"
 #include "uml.h"
 #include "version.h"
@@ -35,6 +36,8 @@
 
 #include <stdio.h>
 
+DEBUG_REGISTER(main)
+
 void getFiles(QStringList& files, const QString& path, QStringList& filters);
 
 /**
@@ -59,6 +62,7 @@ bool showGUI(KCmdLineArgs *args)
  * in the configuration.
  *
  * @param args The command line arguments given.
+ * @param progLang The programming language to set if no existing file was opened.
  */
 void initDocument(KCmdLineArgs *args, Uml::ProgrammingLanguage::Enum progLang)
 {
@@ -84,11 +88,10 @@ void initDocument(KCmdLineArgs *args, Uml::ProgrammingLanguage::Enum progLang)
  * @param args The command line arguments given.
  * @param exportOpt A list containing all the "export" arguments given.
  */
-
 void exportAllViews(KCmdLineArgs *args, const QStringList &exportOpt)
 {
     QString extension(exportOpt.last());
-    uDebug() << "extension: " << extension;
+    logDebug1("exportAllViews extension: %1", extension);
 
     // export to the specified directory, or the directory where the file is saved
     // if no directory was specified
@@ -103,7 +106,7 @@ void exportAllViews(KCmdLineArgs *args, const QStringList &exportOpt)
 
     bool useFolders = args->isSet("use-folders");
 
-    uDebug() << "directory: " << directory;
+    logDebug1("exportAllViews directory: %1", directory.path());
 
     // the event is posted so when the Qt loop begins it's processed. UMLApp process this event executing
     // the method it provides for exporting the views. Once all the views were exported, a quit event
@@ -121,7 +124,7 @@ int main(int argc, char *argv[])
                               "based on the industry standard Unified Modelling Language (UML).<br/>"
                               "See also <a href=\"http://www.omg.org/spec/\">http://www.omg.org/spec/</a>."),
                          KAboutData::License_GPL,
-                         i18n("Copyright © 2001 Paul Hensgen,\nCopyright © 2002-2021 Umbrello UML Modeller Authors"),
+                         i18n("Copyright © 2001 Paul Hensgen,\nCopyright © 2002-2022 Umbrello UML Modeller Authors"),
                          KLocalizedString(),
                          "http://umbrello.kde.org/");
     aboutData.addAuthor(i18n("Paul Hensgen"), i18n("Author of initial version."), "phensgen@users.sourceforge.net");
@@ -154,7 +157,7 @@ int main(int argc, char *argv[])
     options.add("languages", i18n("list supported languages"));
     options.add("use-folders", i18n("keep the tree structure used to store the views in the document in the target directory"));
     options.add("import-directory <dir>", i18n("import files from directory <dir>"));
-    for (int i = Uml::ProgrammingLanguage::ActionScript; i <= Uml::ProgrammingLanguage::Reserved; i++) {
+    for (int i = 0; i <= Uml::ProgrammingLanguage::Reserved; i++) {
         Uml::ProgrammingLanguage::Enum pl = Uml::ProgrammingLanguage::fromInt(i);
         QByteArray optionString = "set-language-" + Uml::ProgrammingLanguage::toString(pl).toLower().toLocal8Bit();
         options.add(optionString, i18n("set active language"));
@@ -179,7 +182,7 @@ int main(int argc, char *argv[])
                 fprintf(stdout, "%s\n", qPrintable(type));
             return 0;
         } else if (args->isSet("languages")) {
-            for (int i = Uml::ProgrammingLanguage::ActionScript; i <= Uml::ProgrammingLanguage::Reserved; i++) {
+            for (int i = 0; i <= Uml::ProgrammingLanguage::Reserved; i++) {
                 Uml::ProgrammingLanguage::Enum pl = Uml::ProgrammingLanguage::fromInt(i);
                 fprintf(stdout, "%s\n", qPrintable(Uml::ProgrammingLanguage::toString(pl)));
             }
@@ -187,6 +190,7 @@ int main(int argc, char *argv[])
         }
 
         uml = new UMLApp();
+        uml->setup();
         app.processEvents();
 
         if (showGUI(args)) {
@@ -194,7 +198,7 @@ int main(int argc, char *argv[])
         }
 
         Uml::ProgrammingLanguage::Enum lang = Uml::ProgrammingLanguage::Reserved;
-        for(int i = Uml::ProgrammingLanguage::ActionScript; i < Uml::ProgrammingLanguage::Reserved; i++) {
+        for(int i = 0; i < Uml::ProgrammingLanguage::Reserved; i++) {
             Uml::ProgrammingLanguage::Enum pl = Uml::ProgrammingLanguage::fromInt(i);
             QByteArray langString = "set-language-";
             langString += Uml::ProgrammingLanguage::toString(pl).toLower().toLocal8Bit();
