@@ -1,6 +1,6 @@
 /*
     SPDX-License-Identifier: GPL-2.0-or-later
-    SPDX-FileCopyrightText: 2018-2021 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
+    SPDX-FileCopyrightText: 2018-2022 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
 */
 
 #include "umllistviewpopupmenu.h"
@@ -8,6 +8,7 @@
 #include "folder.h"
 #include "optionstate.h"
 #include "model_utils.h"
+#include "uml.h"  // only needed for log{Warn,Error}
 
 // kde includes
 #include <KLocalizedString>
@@ -133,14 +134,16 @@ UMLListViewPopupMenu::UMLListViewPopupMenu(QWidget *parent, UMLListViewItem *ite
         case UMLListViewItem::lvt_Component_Diagram:
         case UMLListViewItem::lvt_Deployment_Diagram:
         case UMLListViewItem::lvt_EntityRelationship_Diagram:
+            insert(mt_Rename);
             insertStdItems(false);
             insert(mt_Clone);
             insert(mt_Export_Image);
             insert(mt_Properties);
             break;
 
-    case UMLListViewItem::lvt_Artifact:
+        case UMLListViewItem::lvt_Artifact:
             insert(mt_Open_File);
+            insert(mt_Rename);
             insertStdItems(true);
             insert(mt_Show);
             insert(mt_Properties);
@@ -148,6 +151,7 @@ UMLListViewPopupMenu::UMLListViewPopupMenu(QWidget *parent, UMLListViewItem *ite
 
         case UMLListViewItem::lvt_Class:
             insertSubMenuNew(type);
+            insert(mt_Rename);
             insertStdItems();
             insert(mt_Show);
             addSeparator();
@@ -161,6 +165,7 @@ UMLListViewPopupMenu::UMLListViewPopupMenu(QWidget *parent, UMLListViewItem *ite
 
         case UMLListViewItem::lvt_Package:
             insertContainerItems(true, false, true);
+            insert(mt_Rename);
             insertStdItems();
             insert(mt_Show);
             insert(mt_Properties);
@@ -171,6 +176,7 @@ UMLListViewPopupMenu::UMLListViewPopupMenu(QWidget *parent, UMLListViewItem *ite
 
         case UMLListViewItem::lvt_Subsystem:
             insertSubMenuNew(type);
+            insert(mt_Rename);
             insertStdItems();
             insert(mt_Show);
             insert(mt_Properties);
@@ -181,6 +187,7 @@ UMLListViewPopupMenu::UMLListViewPopupMenu(QWidget *parent, UMLListViewItem *ite
 
         case UMLListViewItem::lvt_Component:
             insertSubMenuNew(type);
+            insert(mt_Rename);
             insertStdItems();
             insert(mt_Show);
             insert(mt_Properties);
@@ -190,6 +197,16 @@ UMLListViewPopupMenu::UMLListViewPopupMenu(QWidget *parent, UMLListViewItem *ite
             break;
 
         case UMLListViewItem::lvt_Datatype:
+            // Renaming, cut/paste etc shall not be offered for programming
+            // language predefined types
+            if (object && !Model_Utils::isCommonDataType(object->name())) {
+                insert(mt_Rename);
+                insertStdItems(false);
+            }
+            insert(mt_Show);
+            insert(mt_Properties);
+            break;
+
         case UMLListViewItem::lvt_EnumLiteral:
         case UMLListViewItem::lvt_Port:
         case UMLListViewItem::lvt_Node:
@@ -200,6 +217,7 @@ UMLListViewPopupMenu::UMLListViewPopupMenu(QWidget *parent, UMLListViewItem *ite
         case UMLListViewItem::lvt_InstanceAttribute:
         case UMLListViewItem::lvt_Operation:
         case UMLListViewItem::lvt_Template:
+            insert(mt_Rename);
             insertStdItems(false);
             insert(mt_Show);
             insert(mt_Properties);
@@ -207,6 +225,7 @@ UMLListViewPopupMenu::UMLListViewPopupMenu(QWidget *parent, UMLListViewItem *ite
 
         case UMLListViewItem::lvt_Interface:
             insertSubMenuNew(type);
+            insert(mt_Rename);
             insertStdItems();
             insert(mt_Show);
             insert(mt_Properties);
@@ -214,6 +233,7 @@ UMLListViewPopupMenu::UMLListViewPopupMenu(QWidget *parent, UMLListViewItem *ite
 
         case UMLListViewItem::lvt_Enum:
             insertSubMenuNew(type);
+            insert(mt_Rename);
             insertStdItems();
             insert(mt_Show);
             insert(mt_Properties);
@@ -221,6 +241,7 @@ UMLListViewPopupMenu::UMLListViewPopupMenu(QWidget *parent, UMLListViewItem *ite
 
         case UMLListViewItem::lvt_Category:
             insertSubMenuCategoryType(object->asUMLCategory());
+            insert(mt_Rename);
             insertStdItems(false);
             insert(mt_Show);
             insert(mt_Properties);
@@ -228,6 +249,7 @@ UMLListViewPopupMenu::UMLListViewPopupMenu(QWidget *parent, UMLListViewItem *ite
 
         case UMLListViewItem::lvt_Entity:
             insertSubMenuNew(type);
+            insert(mt_Rename);
             insertStdItems();
             insert(mt_Show);
             insert(mt_Properties);
@@ -235,6 +257,7 @@ UMLListViewPopupMenu::UMLListViewPopupMenu(QWidget *parent, UMLListViewItem *ite
 
         case UMLListViewItem::lvt_Instance:
             insertSubMenuNew(type);
+            insert(mt_Rename);
             insertStdItems();
             insert(mt_Show);
             insert(mt_Properties);
@@ -282,13 +305,10 @@ UMLListViewPopupMenu::UMLListViewPopupMenu(QWidget *parent, UMLListViewItem *ite
 /**
  * Override of related method from class ListPopupMenu
  * @param type list view type
- * @param menu pointer to menu instance or 0 to create a new instance
  */
-void UMLListViewPopupMenu::insertSubMenuNew(UMLListViewItem::ListViewType type, KMenu *menu)
+void UMLListViewPopupMenu::insertSubMenuNew(UMLListViewItem::ListViewType type)
 {
-    if (!menu) {
-        menu = makeNewMenu();
-    }
+    KMenu * menu = makeNewMenu();
 
     switch(type) {
         case UMLListViewItem::lvt_Deployment_View:
@@ -403,12 +423,13 @@ void UMLListViewPopupMenu::insertSubmodelAction()
     }
     UMLObject *o = Model_Utils::treeViewGetCurrentObject();
     if (o == 0) {
-        uError() << " Model_Utils::treeViewGetCurrentObject() returns NULL";
+        logError0("UMLListViewPopupMenu::insertSubmodelAction: "
+                  "Model_Utils::treeViewGetCurrentObject() returns NULL");
         return;
     }
-    UMLFolder *f = o->asUMLFolder();
+    const UMLFolder *f = o->asUMLFolder();
     if (f == 0) {
-        uError() << o->name() << " is not a Folder";
+        logError1("UMLListViewPopupMenu::insertSubmodelAction: %1 is not a Folder", o->name());
         return;
     }
     QString submodelFile = f->folderFile();
