@@ -1,6 +1,6 @@
 /*
     SPDX-License-Identifier: GPL-2.0-or-later
-    SPDX-FileCopyrightText: 2006-2020 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
+    SPDX-FileCopyrightText: 2006-2022 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
 */
 
 // own header
@@ -92,6 +92,13 @@ QString PetalNode::name() const
     return m_initialArgs.first();
 }
 
+QString PetalNode::viewTag() const
+{
+    if (m_initialArgs.count() == 0)
+        return QString();
+    return m_initialArgs.last();
+}
+
 /**
  * Return the documentation from a petal node with carriage
  * return handling and removed surrounding quotation marks
