@@ -1,6 +1,6 @@
 /*
     SPDX-License-Identifier: GPL-2.0-or-later
-    SPDX-FileCopyrightText: 2004-2021 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
+    SPDX-FileCopyrightText: 2004-2022 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
 */
 
 // own header
@@ -67,7 +67,6 @@ void ToolBarStateOther::setCurrentElement()
  * If the widget is the visual representation of a UMLObject, the object
  * factory handles its creation. Otherwise, the widget is created using
  * newWidget().
- * The UMLView is resized to fit on all the items.
  */
 void ToolBarStateOther::mouseReleaseEmpty()
 {
@@ -78,8 +77,6 @@ void ToolBarStateOther::mouseReleaseEmpty()
             m_pUMLScene->setCreateObject(true);
             Object_Factory::createUMLObject(getObjectType());
         }
-
-        m_pUMLScene->resizeSceneToItems();
     }
 }
 
@@ -333,7 +330,8 @@ bool ToolBarStateOther::newWidget()
         }
         break;
     default:
-        uWarning() << "Unknown ToolBar_Buttons: " << QLatin1String(ENUM_NAME(WorkToolBar, WorkToolBar::ToolBar_Buttons, getButton()));
+        logWarn1("ToolBarStateOther::newWidget unknown ToolBar_Buttons: %1",
+                 QLatin1String(ENUM_NAME(WorkToolBar, WorkToolBar::ToolBar_Buttons, getButton())));
         break;
     }
 
