@@ -98,6 +98,8 @@ public:
     explicit UMLApp(QWidget* parent = 0);
     ~UMLApp();
 
+    void setup();
+
     static UMLApp* app();
 
 #if QT_VERSION >= 0x050000
@@ -418,7 +420,6 @@ private:
     BirdViewDockWidget* m_birdViewDock;///< Contains the bird's eye view
 
     DocWindow*   m_docWindow;          ///< Documentation window.
-    QListWidget* m_logWindow;          ///< Logging window.
     BirdView*    m_birdView;           ///< Bird View window
     QUndoView*   m_pQUndoView;         ///< Undo / Redo Viewer
     RefactoringAssistant* m_refactoringAssist;  ///< Refactoring assistant.
@@ -499,6 +500,7 @@ private:
      * Statusbar items
      */
     QLabel*      m_zoomValueLbl;
+    QWidget*     m_defaultZoomWdg;
     QPushButton* m_pZoomOutPB;
     QPushButton* m_pZoomInPB;
     StatusBarToolButton* m_pZoomFitSBTB;
