@@ -1,12 +1,7 @@
-/***************************************************************************
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   copyright (C) 2003-2014                                               *
- *   Umbrello UML Modeller Authors <umbrello-devel@kde.org>                *
- ***************************************************************************/
+/*
+    SPDX-License-Identifier: GPL-2.0-or-later
+    SPDX-FileCopyrightText: 2003-2022 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
+*/
 
 // own header
 #include "association.h"
@@ -21,6 +16,7 @@
 #include "umlrole.h"
 #include "uniqueid.h"
 #include "model_utils.h"
+#include "optionstate.h"
 #include "cmds.h"
 
 // kde includes
@@ -70,13 +66,13 @@ UMLAssociation::UMLAssociation(Uml::AssociationType::Enum type)
 UMLAssociation::~UMLAssociation()
 {
     if (m_pRole[RoleType::A] == 0) {
-        uError() << "UMLAssociation destructor: m_pRole[A] is NULL already";
+        logError0("UMLAssociation destructor: m_pRole[A] is null already");
     } else {
         delete m_pRole[RoleType::A];
         m_pRole[RoleType::A] = 0;
     }
     if (m_pRole[RoleType::B] == 0) {
-        uError() << "UMLAssociation destructor: m_pRole[B] is NULL already";
+        logError0("UMLAssociation destructor: m_pRole[B] is null already");
     } else {
         delete m_pRole[RoleType::B];
         m_pRole[RoleType::B] = 0;
@@ -112,24 +108,9 @@ Uml::AssociationType::Enum UMLAssociation::getAssocType() const
  */
 QString UMLAssociation::toString() const
 {
-    QString string;
-    if(m_pRole[RoleType::A])
-    {
-        string += m_pRole[RoleType::A]->object()->name();
-        string += QLatin1Char(':');
-        string += m_pRole[RoleType::A]->name();
-    } else {
-        string += QLatin1String("null");
-    }
+    QString string = m_pRole[RoleType::A]->toString();
     string += QLatin1Char(' ') + Uml::AssociationType::toStringI18n(m_AssocType) + QLatin1Char(' ');
-    if(m_pRole[RoleType::B])
-    {
-        string += m_pRole[RoleType::B]->object()->name();
-        string += QLatin1Char(':');
-        string += m_pRole[RoleType::B]->name();
-    } else {
-        string += QLatin1String("null");
-    }
+    string += m_pRole[RoleType::B]->toString();
     return string;
 }
 
@@ -161,70 +142,78 @@ bool UMLAssociation::resolveRef()
  * Creates the <UML:Generalization> or <UML:Association> XMI element
  * including its role objects.
  */
-void UMLAssociation::saveToXMI(QDomDocument & qDoc, QDomElement & qElement)
+void UMLAssociation::saveToXMI(QXmlStreamWriter& writer)
 {
     if (m_AssocType == Uml::AssociationType::Generalization) {
-        QDomElement assocElement = UMLObject::save(QLatin1String("UML:Generalization"), qDoc);
-        assocElement.setAttribute(QLatin1String("discriminator"), QString());
-        assocElement.setAttribute(QLatin1String("child"), Uml::ID::toString(getObjectId(RoleType::A)));
-        assocElement.setAttribute(QLatin1String("parent"), Uml::ID::toString(getObjectId(RoleType::B)));
-        qElement.appendChild(assocElement);
+        // In UML2 mode, the generalization is saved in UMLClassifier::saveToXMI()
+        if (! Settings::optionState().generalState.uml2) {
+            UMLObject::save1(writer, QLatin1String("Generalization"), QLatin1String("generalization"));
+            writer.writeAttribute(QLatin1String("child"), Uml::ID::toString(getObjectId(RoleType::A)));
+            writer.writeAttribute(QLatin1String("parent"), Uml::ID::toString(getObjectId(RoleType::B)));
+            writer.writeEndElement();
+        }
         return;
     }
     if (m_AssocType == Uml::AssociationType::Realization) {
-        QDomElement assocElement = UMLObject::save(QLatin1String("UML:Abstraction"), qDoc);
-        assocElement.setAttribute(QLatin1String("client"), Uml::ID::toString(getObjectId(RoleType::A)));
-        assocElement.setAttribute(QLatin1String("supplier"), Uml::ID::toString(getObjectId(RoleType::B)));
-        qElement.appendChild(assocElement);
+        if (Settings::optionState().generalState.uml2) {
+            UMLObject::save1(writer, QLatin1String("InterfaceRealization"),
+                                     QLatin1String("interfaceRealization"));
+        } else {
+            UMLObject::save1(writer, QLatin1String("Abstraction"));
+        }
+        writer.writeAttribute(QLatin1String("client"), Uml::ID::toString(getObjectId(RoleType::A)));
+        writer.writeAttribute(QLatin1String("supplier"), Uml::ID::toString(getObjectId(RoleType::B)));
+        writer.writeEndElement();
         return;
     }
     if (m_AssocType == Uml::AssociationType::Dependency) {
-        QDomElement assocElement = UMLObject::save(QLatin1String("UML:Dependency"), qDoc);
-        assocElement.setAttribute(QLatin1String("client"), Uml::ID::toString(getObjectId(RoleType::A)));
-        assocElement.setAttribute(QLatin1String("supplier"), Uml::ID::toString(getObjectId(RoleType::B)));
-        qElement.appendChild(assocElement);
+        UMLObject::save1(writer, QLatin1String("Dependency"));
+        writer.writeAttribute(QLatin1String("client"), Uml::ID::toString(getObjectId(RoleType::A)));
+        writer.writeAttribute(QLatin1String("supplier"), Uml::ID::toString(getObjectId(RoleType::B)));
+        writer.writeEndElement();
         return;
     }
     if (m_AssocType == Uml::AssociationType::Child2Category) {
-        QDomElement assocElement = UMLObject::save(QLatin1String("UML:Child2Category"), qDoc);
-        assocElement.setAttribute(QLatin1String("client"), Uml::ID::toString(getObjectId(RoleType::A)));
-        assocElement.setAttribute(QLatin1String("supplier"), Uml::ID::toString(getObjectId(RoleType::B)));
-        qElement.appendChild(assocElement);
+        UMLObject::save1(writer, QLatin1String("Child2Category"));
+        writer.writeAttribute(QLatin1String("client"), Uml::ID::toString(getObjectId(RoleType::A)));
+        writer.writeAttribute(QLatin1String("supplier"), Uml::ID::toString(getObjectId(RoleType::B)));
+        writer.writeEndElement();
         return;
     }
     if (m_AssocType == Uml::AssociationType::Category2Parent) {
-        QDomElement assocElement = UMLObject::save(QLatin1String("UML:Category2Parent"), qDoc);
-        assocElement.setAttribute(QLatin1String("client"), Uml::ID::toString(getObjectId(RoleType::A)));
-        assocElement.setAttribute(QLatin1String("supplier"), Uml::ID::toString(getObjectId(RoleType::B)));
-        qElement.appendChild(assocElement);
+        UMLObject::save1(writer, QLatin1String("Category2Parent"));
+        writer.writeAttribute(QLatin1String("client"), Uml::ID::toString(getObjectId(RoleType::A)));
+        writer.writeAttribute(QLatin1String("supplier"), Uml::ID::toString(getObjectId(RoleType::B)));
+        writer.writeEndElement();
         return;
     }
 
-    QDomElement associationElement = UMLObject::save(QLatin1String("UML:Association"), qDoc);
-    QDomElement connElement = qDoc.createElement(QLatin1String("UML:Association.connection"));
-    getUMLRole(RoleType::A)->saveToXMI (qDoc, connElement);
-    getUMLRole(RoleType::B)->saveToXMI (qDoc, connElement);
-    associationElement.appendChild (connElement);
-    qElement.appendChild(associationElement);
+    UMLObject::save1(writer, QLatin1String("Association"));
+    if (! Settings::optionState().generalState.uml2) {
+        writer.writeStartElement(QLatin1String("UML:Association.connection"));
+    }
+                                                   // TODO: Adapt to UML2:
+    getUMLRole(RoleType::A)->saveToXMI (writer);   // 1) attribute "memberEnd" with two space separated xmiIds
+    getUMLRole(RoleType::B)->saveToXMI (writer);   // 2) nested element <ownedEnd xmi:type="uml:Property">
+    if (! Settings::optionState().generalState.uml2) {
+        writer.writeEndElement();            // UML:Association.connection
+    }
+    writer.writeEndElement();  // uml:Association
 }
 
 bool UMLAssociation::showPropertiesDialog(QWidget *parent)
 {
     QPointer<ClassPropertiesDialog> dlg = new ClassPropertiesDialog(parent, this, true);
-    bool modified = false;
-    if (dlg->exec()) {
-        modified = true;
-    }
-    dlg->close();
+    bool modified = dlg->exec();
     delete dlg;
     return modified;
 }
 
 /**
- * Creates the <UML:Generalization> or <UML:Association> XMI element
+ * Loads the <UML:Generalization> or <UML:Association> XMI element
  * including its role objects.
  */
-bool UMLAssociation::load(QDomElement & element)
+bool UMLAssociation::load1(QDomElement & element)
 {
     if (id() == Uml::ID::None)
         return false; // old style XMI file. No real info in this association.
@@ -240,8 +229,8 @@ bool UMLAssociation::load(QDomElement & element)
         if (!general.isEmpty()) {
             UMLClassifier *owningClassifier = umlParent()->asUMLClassifier();
             if (owningClassifier == 0){
-                uWarning() << "Cannot load UML2 generalization: m_pUMLPackage is expected "
-                           << "to be the owning classifier (=client)";
+                logWarn1("Cannot load UML2 generalization: m_pUMLPackage (%1) is expected "
+                         "to be the owning classifier (=client)", umlParent()->name());
                 return false;
             }
             m_pRole[RoleType::A]->setObject(owningClassifier);
@@ -271,7 +260,7 @@ bool UMLAssociation::load(QDomElement & element)
                 if (umlPackage() == 0) {
                     Uml::ModelType::Enum mt = Model_Utils::convert_OT_MT(obj[r]->baseType());
                     setUMLPackage(doc->rootFolder(mt));
-                    DEBUG(DBG_SRC) << "assoctype " << m_AssocType
+                    DEBUG() << "assoctype " << m_AssocType
                         << ": setting model type " << Uml::ModelType::toString(mt);
                 }
             }
@@ -283,25 +272,24 @@ bool UMLAssociation::load(QDomElement & element)
                     continue;
                 QDomElement tempElement = node.toElement();
                 QString tag = tempElement.tagName();
-                if (Model_Utils::isCommonXMIAttribute(tag))
+                if (Model_Utils::isCommonXMI1Attribute(tag))
                     continue;
                 // Permitted tag names:
                 //  roleA: "child" "subtype" "client"
                 //  roleB: "parent" "supertype" "supplier"
-                QString idStr = tempElement.attribute(QLatin1String("xmi.id"));
+                QString idStr = Model_Utils::getXmiId(tempElement);
                 if (idStr.isEmpty())
                     idStr = tempElement.attribute(QLatin1String("xmi.idref"));
                 if (idStr.isEmpty()) {
                     QDomNode inner = node.firstChild();
                     QDomElement tmpElem = inner.toElement();
-                    idStr = tmpElem.attribute(QLatin1String("xmi.id"));
+                    idStr = Model_Utils::getXmiId(tmpElem);
                     if (idStr.isEmpty())
                         idStr = tmpElem.attribute(QLatin1String("xmi.idref"));
                 }
                 if (idStr.isEmpty()) {
-                    uError() << "type " << m_AssocType
-                        << ", id " << Uml::ID::toString(id()) << ": "
-                        << "xmi id not given for " << tag;
+                    logError3("UMLAssociation::load1 type %1, id %2 : xmi id not given for %3",
+                              m_AssocType, Uml::ID::toString(id()), tag);
                     continue;
                 }
                 // Since we know for sure that we're dealing with a non
@@ -330,30 +318,30 @@ bool UMLAssociation::load(QDomElement & element)
             continue;
         QDomElement tempElement = node.toElement();
         QString tag = tempElement.tagName();
-        if (Model_Utils::isCommonXMIAttribute(tag))
-            continue;
-        if (!UMLDoc::tagEq(tag, QLatin1String("Association.connection")) &&
-                !UMLDoc::tagEq(tag, QLatin1String("Association.end")) &&  // Embarcadero's Describe
-                !UMLDoc::tagEq(tag, QLatin1String("Namespace.ownedElement")) &&
-                !UMLDoc::tagEq(tag, QLatin1String("Namespace.contents"))) {
-            uWarning() << "unknown child node " << tag;
+        if (Model_Utils::isCommonXMI1Attribute(tag))
             continue;
+        QDomNode nodeA = node;
+        if (UMLDoc::tagEq(tag, QLatin1String("Association.connection")) ||
+                UMLDoc::tagEq(tag, QLatin1String("Association.end")) ||  // Embarcadero's Describe
+                UMLDoc::tagEq(tag, QLatin1String("Namespace.ownedElement")) ||
+                UMLDoc::tagEq(tag, QLatin1String("Namespace.contents"))) {
+            nodeA = tempElement.firstChild();
         }
         // Load role A.
-        QDomNode nodeA = tempElement.firstChild();
         while (nodeA.isComment())
             nodeA = nodeA.nextSibling();
         tempElement = nodeA.toElement();
         if (tempElement.isNull()) {
-            uWarning() << "UML:Association : element (A) is Null";
+            logWarn0("UMLAssociation::load1 : element (A) is null");
             return false;
         }
         tag = tempElement.tagName();
         if (UMLDoc::tagEq(tag, QLatin1String("NavigableEnd"))) {  // Embarcadero's Describe
             m_AssocType = Uml::AssociationType::UniAssociation;
-        } else if (!UMLDoc::tagEq(tag, QLatin1String("AssociationEndRole")) &&
-                   !UMLDoc::tagEq(tag, QLatin1String("AssociationEnd"))) {
-            uWarning() << "unknown child (A) tag " << tag;
+        } else if (!UMLDoc::tagEq(tag, QLatin1String("ownedEnd")) &&
+                   !UMLDoc::tagEq(tag, QLatin1String("AssociationEnd")) &&
+                   !UMLDoc::tagEq(tag, QLatin1String("AssociationEndRole"))) {
+            logWarn1("UMLAssociation::load1: unknown child (A) tag %1", tag);
             return false;
         }
         if (! getUMLRole(RoleType::A)->loadFromXMI(tempElement))
@@ -364,15 +352,16 @@ bool UMLAssociation::load(QDomElement & element)
             nodeB = nodeB.nextSibling();
         tempElement = nodeB.toElement();
         if (tempElement.isNull()) {
-            uWarning() << "UML:Association : element (B) is Null";
+            logWarn0("UMLAssociation::load1 : element (B) is null");
             return false;
         }
         tag = tempElement.tagName();
         if (UMLDoc::tagEq(tag, QLatin1String("NavigableEnd"))) {  // Embarcadero's Describe
             m_AssocType = Uml::AssociationType::UniAssociation;
-        } else if (!UMLDoc::tagEq(tag, QLatin1String("AssociationEndRole")) &&
-                   !UMLDoc::tagEq(tag, QLatin1String("AssociationEnd"))) {
-            uWarning() << "unknown child (B) tag " << tag;
+        } else if (!UMLDoc::tagEq(tag, QLatin1String("ownedEnd")) &&
+                   !UMLDoc::tagEq(tag, QLatin1String("AssociationEnd")) &&
+                   !UMLDoc::tagEq(tag, QLatin1String("AssociationEndRole"))) {
+            logWarn1("UMLAssociation::load1: unknown child (B) tag %1", tag);
             return false;
         }
         if (! getUMLRole(RoleType::B)->loadFromXMI(tempElement))
@@ -381,13 +370,13 @@ bool UMLAssociation::load(QDomElement & element)
         if (umlPackage() == 0) {
             Uml::ModelType::Enum mt = Model_Utils::convert_OT_MT(getObject(RoleType::B)->baseType());
             setUMLPackage(doc->rootFolder(mt));
-            DEBUG(DBG_SRC) << "setting model type " << Uml::ModelType::toString(mt);
+            DEBUG() << "setting model type " << Uml::ModelType::toString(mt);
         }
 
         // setting the association type:
         //
         // In the old days, we could just record this on the association,
-        // and be done with it. But thats not how the UML13.dtd does things.
+        // and be done with it. But that's not how the UML13.dtd does things.
         // As a result, we are checking roleA for information about the
         // parent association (!) which by this point in the parse, should
         // be set. However, the information that the roles are allowed to have
@@ -418,7 +407,7 @@ bool UMLAssociation::load(QDomElement & element)
                     "associationself",  // Uml::AssociationType::Association_Self
                     "collmessage",      // Uml::AssociationType::Coll_Message
                     "seqmessage",       // Uml::AssociationType::Seq_Message
-                    "collmessageself",  // Uml::AssociationType::Coll_Message_Self
+                    "collmessageself",  // Uml::AssociationType::Coll_Mesg_Self
                     "seqmessageself",   // Uml::AssociationType::Seq_Message_Self
                     "implementation",   // Uml::AssociationType::Implementation
                     "composition",      // Uml::AssociationType::Composition
@@ -428,12 +417,12 @@ bool UMLAssociation::load(QDomElement & element)
                     "state",            // Uml::AssociationType::State
                     "activity",         // Uml::AssociationType::Activity
                     "exception",        // Uml::AssociationType::Exception
-                    "category2parent"   // Uml::AssociationType::Category2Parent
-                    "child2category"    // Uml::AssociationType::Child2Category
+                    "category2parent",  // Uml::AssociationType::Category2Parent
+                    "child2category",   // Uml::AssociationType::Child2Category
                     "relationship"      // Uml::AssociationType::Relationship
         };
         const int arraySize = sizeof(assocTypeString) / sizeof(char*);
-        DEBUG(DBG_SRC) << "AssociationType string array size = " << arraySize;
+        DEBUG() << "AssociationType string array size = " << arraySize;
 
         int index;
         for (index = 0; index < arraySize; ++index)
@@ -445,7 +434,8 @@ bool UMLAssociation::load(QDomElement & element)
         int assocTypeNum = assocTypeStr.toInt();
         if (assocTypeNum < (int)Uml::AssociationType::Generalization ||   // first enum
             assocTypeNum >= (int)Uml::AssociationType::Reserved) {     // last enum
-            uWarning() << "bad assoctype of UML:AssociationType::Enum " << Uml::ID::toString(id());
+            logWarn1("UMLAssociation::load1: bad assoctype of UML:AssociationType::Enum %1",
+                     Uml::ID::toString(id()));
             return false;
         }
         assocType = Uml::AssociationType::fromInt(assocTypeNum);
@@ -533,10 +523,11 @@ Uml::ID::Type UMLAssociation::getObjectId(Uml::RoleType::Enum role) const
     if (o == 0) {
         QString auxID = roleObj->secondaryId();
         if (auxID.isEmpty()) {
-            uError() << "role " << role << ": getObject returns NULL";
+            logError1("UMLAssociation::getObjectId role %1 : getObject returns null",
+                      Uml::RoleType::toString(role));
             return Uml::ID::None;
         } else {
-            DEBUG(DBG_SRC) << "role " << role << ": using secondary ID " << auxID;
+            DEBUG() << "role " << role << ": using secondary ID " << auxID;
             return Uml::ID::fromString(auxID);
         }
     }
@@ -635,7 +626,7 @@ void UMLAssociation::setAssociationType(Uml::AssociationType::Enum assocType)
         // In this case we need to auto-set the multiplicity/rolenames
         // of the roles
 #ifdef VERBOSE_DEBUGGING
-        DEBUG(DBG_SRC) << " A new uni-association has been created.";
+        DEBUG() << " A new uni-association has been created.";
 #endif
     }
     UMLObject::emitModified();
