@@ -1,12 +1,7 @@
-/***************************************************************************
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   copyright (C) 2003-2014                                               *
- *   Umbrello UML Modeller Authors <umbrello-devel@kde.org>                *
- ***************************************************************************/
+/*
+    SPDX-License-Identifier: GPL-2.0-or-later
+    SPDX-FileCopyrightText: 2003-2022 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
+*/
 
 // own header
 #include "enum.h"
@@ -14,6 +9,7 @@
 // app includes
 #include "debug_utils.h"
 #include "enumliteral.h"
+#include "optionstate.h"
 #include "umldoc.h"
 #include "uml.h"
 #include "uniqueid.h"
@@ -23,6 +19,8 @@
 #include <KLocalizedString>
 #include <KMessageBox>
 
+DEBUG_REGISTER(UMLEnum)
+
 /**
  * Sets up an enum.
  * @param name  The name of the Enum.
@@ -38,7 +36,7 @@ UMLEnum::UMLEnum(const QString& name, Uml::ID::Type id) : UMLClassifier(name, id
  */
 UMLEnum::~UMLEnum()
 {
-    m_List.clear();
+    subordinates().clear();
 }
 
 /**
@@ -112,7 +110,7 @@ UMLObject* UMLEnum::createEnumLiteral(const QString& name)
 
     if (!ok) {
         delete newEnumLiteral;
-        return NULL;
+        return 0;
     }
 
     addEnumLiteral(newEnumLiteral);
@@ -127,17 +125,18 @@ UMLObject* UMLEnum::createEnumLiteral(const QString& name)
  * @param name  The name of the enumliteral.
  * @param id  The id of the enumliteral (optional.)
  *            If omitted a new ID is assigned internally.
+ * @param value  Optional numeric representation of the enumliteral.
  * @return  Pointer to the UMLEnumliteral created.
  */
 UMLObject* UMLEnum::addEnumLiteral(const QString &name, Uml::ID::Type id, const QString& value)
 {
     UMLObject *el = UMLCanvasObject::findChildObject(name);
-    if (el != NULL) {
-        uDebug() << name << " is already present";
+    if (el != 0) {
+        logDebug1("UMLEnum::addEnumLiteral: %1 is already present", name);
         return el;
     }
     UMLEnumLiteral* literal = new UMLEnumLiteral(this, name, id, value);
-    m_List.append(literal);
+    subordinates().append(literal);
     UMLObject::emitModified();
     emit enumLiteralAdded(literal);
     connect(literal, SIGNAL(modified()), this, SIGNAL(modified()));
@@ -154,9 +153,9 @@ UMLObject* UMLEnum::addEnumLiteral(const QString &name, Uml::ID::Type id, const
 bool UMLEnum::addEnumLiteral(UMLEnumLiteral* literal, IDChangeLog* Log /* = 0*/)
 {
     QString name = (QString)literal->name();
-    if (findChildObject(name) == NULL) {
+    if (findChildObject(name) == 0) {
         literal->setParent(this);
-        m_List.append(literal);
+        subordinates().append(literal);
         UMLObject::emitModified();
         emit enumLiteralAdded(literal);
         connect(literal, SIGNAL(modified()), this, SIGNAL(modified()));
@@ -181,12 +180,12 @@ bool UMLEnum::addEnumLiteral(UMLEnumLiteral* literal, int position)
 {
     Q_ASSERT(literal);
     QString name = (QString)literal->name();
-    if (findChildObject(name) == NULL) {
+    if (findChildObject(name) == 0) {
         literal->setParent(this);
-        if (position >= 0 && position <= (int)m_List.count())  {
-            m_List.insert(position, literal);
+        if (position >= 0 && position <= (int)subordinates().count())  {
+            subordinates().insert(position, literal);
         } else {
-            m_List.append(literal);
+            subordinates().append(literal);
         }
         UMLObject::emitModified();
         emit enumLiteralAdded(literal);
@@ -204,8 +203,8 @@ bool UMLEnum::addEnumLiteral(UMLEnumLiteral* literal, int position)
  */
 int UMLEnum::removeEnumLiteral(UMLEnumLiteral* literal)
 {
-    if (!m_List.removeAll(literal)) {
-        uDebug() << "cannot find att given in list";
+    if (!subordinates().removeAll(literal)) {
+        logDebug0("UMLEnum::removeEnumLiteral: cannot find att given in list");
         return -1;
     }
     emit enumLiteralRemoved(literal);
@@ -214,16 +213,16 @@ int UMLEnum::removeEnumLiteral(UMLEnumLiteral* literal)
     // for us by QObject. -b.t.
     // disconnect(a, SIGNAL(modified()), this, SIGNAL(modified()));
     delete literal;
-    return m_List.count();
+    return subordinates().count();
 }
 
 /**
  * Returns the number of enumliterals for the class.
  * @return  The number of enumliterals for the class.
  */
-int UMLEnum::enumLiterals()
+int UMLEnum::enumLiterals() const
 {
-    return m_List.count();
+    return subordinates().count();
 }
 
 /**
@@ -237,21 +236,27 @@ void UMLEnum::signalEnumLiteralRemoved(UMLClassifierListItem *elit)
 /**
  * Creates the <UML:Enum> element including its enumliterals.
  */
-void UMLEnum::saveToXMI(QDomDocument& qDoc, QDomElement& qElement)
+void UMLEnum::saveToXMI(QXmlStreamWriter& writer)
 {
-    QDomElement enumElement = UMLObject::save(QLatin1String("UML:Enumeration"), qDoc);
+    UMLObject::save1(writer, QLatin1String("Enumeration"));
     // save enum literals
+    if (! Settings::optionState().generalState.uml2) {
+        writer.writeStartElement(QLatin1String("UML:Enumeration.literal"));
+    }
     UMLClassifierListItemList enumLiterals = getFilteredList(UMLObject::ot_EnumLiteral);
     foreach (UMLClassifierListItem* pEnumLiteral, enumLiterals) {
-        pEnumLiteral->saveToXMI(qDoc, enumElement);
+        pEnumLiteral->saveToXMI(writer);
     }
-    qElement.appendChild(enumElement);
+    if (! Settings::optionState().generalState.uml2) {
+        writer.writeEndElement();            // UML:Enumeration.literal
+    }
+    UMLObject::save1end(writer); // UML:Enumeration
 }
 
 /**
  * Loads the <UML:Enum> element including its enumliterals.
  */
-bool UMLEnum::load(QDomElement& element)
+bool UMLEnum::load1(QDomElement& element)
 {
     QDomNode node = element.firstChild();
     while(!node.isNull()) {
@@ -268,14 +273,14 @@ bool UMLEnum::load(QDomElement& element)
             if(!pEnumLiteral->loadFromXMI(tempElement)) {
                 return false;
             }
-            m_List.append(pEnumLiteral);
-        } else if (UMLDoc::tagEq(tag, QLatin1String("Enumeration.literal"))) {  // Embarcadero's Describe
-            if (! load(tempElement))
+            subordinates().append(pEnumLiteral);
+        } else if (UMLDoc::tagEq(tag, QLatin1String("Enumeration.literal"))) {  // UML 1.4
+            if (! load1(tempElement))
                 return false;
         } else if (tag == QLatin1String("stereotype")) {
-            uDebug() << name() << ": losing old-format stereotype.";
+            logDebug1("UMLEnum::load1 %1: losing old-format stereotype.", name());
         } else {
-            uWarning() << "unknown child type: " << tag;
+            logWarn1("UMLEnum::load1: unknown child type %1", tag);
         }
         node = node.nextSibling();
     }//end while
@@ -292,7 +297,7 @@ bool UMLEnum::load(QDomElement& element)
  */
 UMLClassifierListItem* UMLEnum::makeChildObject(const QString& xmiTag)
 {
-    UMLClassifierListItem* pObject = NULL;
+    UMLClassifierListItem* pObject = 0;
     if (UMLDoc::tagEq(xmiTag, QLatin1String("EnumerationLiteral")) ||
                UMLDoc::tagEq(xmiTag, QLatin1String("EnumLiteral"))) {
         pObject = new UMLEnumLiteral(this);
