@@ -1,18 +1,14 @@
-/***************************************************************************
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   copyright (C) 2006-2014                                               *
- *   Umbrello UML Modeller Authors <umbrello-devel@kde.org>                *
- ***************************************************************************/
+/*
+    SPDX-License-Identifier: GPL-2.0-or-later
+    SPDX-FileCopyrightText: 2006-2022 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
+*/
 
 // own header
 #include "folder.h"
 
 // app includes
 #include "debug_utils.h"
+#include "dialog_utils.h"
 #include "model_utils.h"
 #include "object_factory.h"
 #include "optionstate.h"
@@ -20,6 +16,7 @@
 #include "umldoc.h"
 #include "umlscene.h"
 #include "umlview.h"
+#include "datatype.h"
 
 // kde includes
 #include <KLocalizedString>
@@ -27,6 +24,9 @@
 
 // qt includes
 #include <QFile>
+#include <QXmlStreamWriter>
+
+DEBUG_REGISTER(UMLFolder)
 
 /**
  * Sets up a Folder.
@@ -94,7 +94,6 @@ void UMLFolder::addView(UMLView *view)
 void UMLFolder::removeView(UMLView *view)
 {
     m_diagrams.removeAll(view);
-    delete view;
 }
 
 /**
@@ -109,7 +108,7 @@ void UMLFolder::appendViews(UMLViewList& viewList, bool includeNested)
         foreach (UMLObject* o, m_objects) {
             uIgnoreZeroPointer(o);
             if (o->baseType() == UMLObject::ot_Folder) {
-                UMLFolder *f = static_cast<UMLFolder*>(o);
+                UMLFolder *f = o->asUMLFolder();
                 f->appendViews(viewList);
             }
         }
@@ -120,7 +119,7 @@ void UMLFolder::appendViews(UMLViewList& viewList, bool includeNested)
 }
 
 /**
- * Acivate the views in this folder.
+ * Activate the views in this folder.
  * "Activation": Some widgets require adjustments after loading from file,
  * those are done here.
  */
@@ -129,13 +128,15 @@ void UMLFolder::activateViews()
     foreach (UMLObject* o, m_objects) {
         uIgnoreZeroPointer(o);
         if (o->baseType() == UMLObject::ot_Folder) {
-            UMLFolder *f = static_cast<UMLFolder*>(o);
+            UMLFolder *f = o->asUMLFolder();
             f->activateViews();
         }
     }
 
     foreach (UMLView* v, m_diagrams) {
-        v->umlScene()->activateAfterLoad();
+        UMLScene *scene = v->umlScene();
+        scene->activateAfterLoad();
+        uDebug() << "UMLFolder::activateViews: " << scene->name() << " sceneRect = " << scene->sceneRect();
     }
     // Make sure we have a treeview item for each diagram.
     // It may happen that we are missing them after switching off tabbed widgets.
@@ -154,7 +155,7 @@ void UMLFolder::activateViews()
 UMLView *UMLFolder::findView(Uml::ID::Type id)
 {
     foreach (UMLView* v, m_diagrams) {
-        if (v->umlScene()->ID() == id) {
+        if (v && v->umlScene() && v->umlScene()->ID() == id) {
             return v;
         }
     }
@@ -166,7 +167,7 @@ UMLView *UMLFolder::findView(Uml::ID::Type id)
         if (o->baseType() != UMLObject::ot_Folder) {
             continue;
         }
-        UMLFolder *f = static_cast<UMLFolder*>(o);
+        UMLFolder *f = o->asUMLFolder();
         v = f->findView(id);
         if (v) {
             break;
@@ -197,7 +198,7 @@ UMLView *UMLFolder::findView(Uml::DiagramType::Enum type, const QString &name, b
             if (o->baseType() != UMLObject::ot_Folder) {
                 continue;
             }
-            UMLFolder *f = static_cast<UMLFolder*>(o);
+            UMLFolder *f = o->asUMLFolder();
             v = f->findView(type, name, searchAllScopes);
             if (v) {
                 break;
@@ -227,7 +228,7 @@ void UMLFolder::removeAllViews()
         uIgnoreZeroPointer(o);
         if (o->baseType() != UMLObject::ot_Folder)
             continue;
-        UMLFolder *f = static_cast<UMLFolder*>(o);
+        UMLFolder *f = o->asUMLFolder();
         f->removeAllViews();
     }
 
@@ -237,7 +238,7 @@ void UMLFolder::removeAllViews()
         // from a view, it also causes any UMLAssociations that lack parent
         // association widgets (but once had them) to remove themselves from
         // this document.
-        uDebug() << "removing " << v->umlScene()->name();
+        logDebug1("UMLFolder::removeAllViews: removing %1", v->umlScene()->name());
         UMLApp::app()->document()->removeView(v, false);
     }
 
@@ -266,64 +267,81 @@ QString UMLFolder::folderFile() const
  * Can be used regardless of whether saving to the main model file
  * or to an external folder file (see m_folderFile.)
  */
-void UMLFolder::saveContents(QDomDocument& qDoc, QDomElement& qElement)
+void UMLFolder::saveContents(QXmlStreamWriter& writer)
 {
-    QDomElement ownedElement = qDoc.createElement(QLatin1String("UML:Namespace.ownedElement"));
-    UMLObject *obj = 0;
+    if (! Settings::optionState().generalState.uml2) {
+        writer.writeStartElement(QLatin1String("UML:Namespace.ownedElement"));
+    }
     // Save contained objects if any.
-    for (UMLObjectListIt oit(m_objects); oit.hasNext();) {
-        obj = oit.next();
+    foreach (UMLObject *obj, m_objects) {
         uIgnoreZeroPointer(obj);
-        obj->saveToXMI (qDoc, ownedElement);
+        obj->saveToXMI (writer);
     }
-    // Save asscociations if any.
-    for (UMLObjectListIt ait(m_List); ait.hasNext();) {
-        obj = ait.next();
-        obj->saveToXMI (qDoc, ownedElement);
+    // Save associations if any.
+    foreach (UMLObject *obj, subordinates()) {
+        obj->saveToXMI (writer);
+    }
+    if (! Settings::optionState().generalState.uml2) {
+        writer.writeEndElement();
     }
-    qElement.appendChild(ownedElement);
     // Save diagrams to `extension'.
     if (m_diagrams.count()) {
-        QDomElement diagramsElement = qDoc.createElement(QLatin1String("diagrams"));
-
-        foreach (UMLView* pView, m_diagrams) {
-            pView->umlScene()->saveToXMI(qDoc, diagramsElement);
+        if (Settings::optionState().generalState.uml2) {
+            writer.writeStartElement(QLatin1String("xmi:Extension"));
+            writer.writeAttribute(QLatin1String("extender"), QLatin1String("umbrello"));
+        } else {
+            writer.writeStartElement(QLatin1String("XMI.extension"));
+            writer.writeAttribute(QLatin1String("xmi.extender"), QLatin1String("umbrello"));
         }
-        QDomElement extension = qDoc.createElement(QLatin1String("XMI.extension"));
-        extension.setAttribute(QLatin1String("xmi.extender"), QLatin1String("umbrello"));
-        extension.appendChild(diagramsElement);
-        qElement.appendChild(extension);
+        writer.writeStartElement(QLatin1String("diagrams"));
+        if (!qFuzzyIsNull(UMLApp::app()->document()->resolution())) {
+            writer.writeAttribute(QLatin1String("resolution"),
+                                  QString::number(UMLApp::app()->document()->resolution()));
+        }
+        foreach (UMLView* pView, m_diagrams) {
+            pView->umlScene()->saveToXMI(writer);
+        }
+        writer.writeEndElement();            // diagrams
+        writer.writeEndElement();   // XMI.extension
     }
 }
 
 /**
- * Auxiliary to saveToXMI(): Creates a <UML:Model> element when saving
- * a predefined modelview, or a <UML:Package> element when saving a
- * user created folder. Invokes saveContents() with the newly created
- * element.
+ * Auxiliary to saveToXMI():
+ * - In UML1 mode it creates a <UML:Model> element when saving a predefined
+ *   modelview, or a <UML:Package> element when saving a user created folder.
+ * - In UML2 mode it creates a \<packagedElement xmi:type="uml:Model"> when
+ *   saving a predefined view, or a \<packagedElement xmi:type="uml:Package">
+ *   when saving a user created folder.
+ * Invokes saveContents() with the newly created element.
  */
-void UMLFolder::save(QDomDocument& qDoc, QDomElement& qElement)
+void UMLFolder::save1(QXmlStreamWriter& writer)
 {
     UMLDoc *umldoc = UMLApp::app()->document();
-    QString elementName(QLatin1String("UML:Package"));
+    QString elementName(QLatin1String("Package"));
+    QString elementTag (QLatin1String("<use_type_as_tag>"));
     const Uml::ModelType::Enum mt = umldoc->rootFolderType(this);
     if (mt != Uml::ModelType::N_MODELTYPES) {
-        elementName = QLatin1String("UML:Model");
+        elementName = QLatin1String("Model");
+        if (Settings::optionState().generalState.uml2)
+            elementTag  = QLatin1String("packagedElement");
     }
-    QDomElement folderElement = UMLObject::save(elementName, qDoc);
-    saveContents(qDoc, folderElement);
-    qElement.appendChild(folderElement);
+    UMLObject::save1(writer, elementName, elementTag);
+    saveContents(writer);
+    writer.writeEndElement();
 }
 
 /**
- * Creates a UML:Model or UML:Package element:
- * UML:Model is created for the predefined fixed folders,
- * UML:Package with stereotype "folder" is created for all else.
+ * Saves the folder in XMI representation:
+ * If m_folderFile is empty then calls save1().
+ * If m_folderFile is non empty then
+ * - creates an XMI Extension stub for the folder in the main XMI file;
+ * - creates the external file for the submodel and writes its XMI.
  */
-void UMLFolder::saveToXMI(QDomDocument& qDoc, QDomElement& qElement)
+void UMLFolder::saveToXMI(QXmlStreamWriter& writer)
 {
     if (m_folderFile.isEmpty()) {
-        save(qDoc, qElement);
+        save1(writer);
         return;
     }
     // See if we can create the external file.
@@ -336,40 +354,41 @@ void UMLFolder::saveToXMI(QDomDocument& qDoc, QDomElement& qElement)
 #endif
     QFile file(fileName);
     if (!file.open(QIODevice::WriteOnly)) {
-        uError() << m_folderFile << QLatin1String(": ")
-            << "cannot create file, contents will be saved in main model file";
+        logError1("UMLFolder::saveToXMI(%1) : cannot create file. Content will be saved in main model file",
+                  m_folderFile);
         m_folderFile.clear();
-        save(qDoc, qElement);
+        save1(writer);
         return;
     }
-    // Okay, external file is writable.  Wrap up main file.
-    QDomElement folderElement = UMLObject::save(QLatin1String("UML:Package"), qDoc);
-    QDomElement extension = qDoc.createElement(QLatin1String("XMI.extension"));
-    extension.setAttribute(QLatin1String("xmi.extender"), QLatin1String("umbrello"));
-    QDomElement fileElement = qDoc.createElement(QLatin1String("external_file"));
-    fileElement.setAttribute(QLatin1String("name"), m_folderFile);
-    extension.appendChild(fileElement);
-    folderElement.appendChild(extension);
-    qElement.appendChild(folderElement);
+    // External file is writable.  Create XMI.extension stub in main file.
+    UMLObject::save1(writer, QLatin1String("Package"));
+    if (Settings::optionState().generalState.uml2) {
+        writer.writeStartElement(QLatin1String("xmi:Extension"));
+        writer.writeAttribute(QLatin1String("extender"), QLatin1String("umbrello"));
+    } else {
+        writer.writeStartElement(QLatin1String("XMI.extension"));
+        writer.writeAttribute(QLatin1String("xmi.extender"), QLatin1String("umbrello"));
+    }
+    writer.writeStartElement(QLatin1String("external_file"));
+    writer.writeAttribute(QLatin1String("name"), m_folderFile);
+    writer.writeEndElement();            // external_file
+    writer.writeEndElement();        // XMI.extension
+    writer.writeEndElement();    // UML:Package
 
-    // Save folder to external file.
-    QDomDocument folderDoc;
-    QDomElement folderRoot;
-    QDomProcessingInstruction xmlHeading =
-        folderDoc.createProcessingInstruction(QLatin1String("xml"),
-                                              QString::fromLatin1("version=\"1.0\" encoding=\"UTF-8\""));
-    folderDoc.appendChild(xmlHeading);
-    folderRoot = folderDoc.createElement(QLatin1String("external_file"));
-    folderRoot.setAttribute(QLatin1String("name"), name());
-    folderRoot.setAttribute(QLatin1String("filename"), m_folderFile);
-    folderRoot.setAttribute(QLatin1String("mainModel"), umldoc->url().fileName());
-    folderRoot.setAttribute(QLatin1String("parentId"), Uml::ID::toString(m_pUMLPackage->id()));
-    folderRoot.setAttribute(QLatin1String("parent"), m_pUMLPackage->fullyQualifiedName(QLatin1String("::"), true));
-    saveContents(folderDoc, folderRoot);
-    folderDoc.appendChild(folderRoot);
-    QTextStream stream(&file);
-    stream.setCodec("UTF-8");
-    stream << folderDoc.toString();
+    // Write the external file.
+    QXmlStreamWriter xfWriter(&file);
+    xfWriter.setCodec("UTF-8");
+    xfWriter.setAutoFormatting(true);
+    xfWriter.setAutoFormattingIndent(2);
+    xfWriter.writeStartDocument();
+    xfWriter.writeStartElement(QLatin1String("external_file"));
+    xfWriter.writeAttribute(QLatin1String("name"), name());
+    xfWriter.writeAttribute(QLatin1String("filename"), m_folderFile);
+    xfWriter.writeAttribute(QLatin1String("mainModel"), umldoc->url().fileName());
+    xfWriter.writeAttribute(QLatin1String("parentId"), Uml::ID::toString(umlPackage()->id()));
+    xfWriter.writeAttribute(QLatin1String("parent"), umlPackage()->fullyQualifiedName(QLatin1String("::"), true));
+    saveContents(xfWriter);
+    xfWriter.writeEndElement();
     file.close();
 }
 
@@ -377,8 +396,25 @@ void UMLFolder::saveToXMI(QDomDocument& qDoc, QDomElement& qElement)
  * Auxiliary to load():
  * Load the diagrams from the "diagrams" in the <XMI.extension>
  */
-bool UMLFolder::loadDiagramsFromXMI(QDomNode& diagrams)
+bool UMLFolder::loadDiagramsFromXMI1(QDomNode& node)
 {
+    qreal resolution = 0.0;
+    QString res = node.toElement().attribute(QLatin1String("resolution"), QLatin1String(""));
+    if (!res.isEmpty()) {
+       resolution = res.toDouble();
+    }
+    if (!qFuzzyIsNull(resolution)) {
+       UMLApp::app()->document()->setResolution(resolution);
+    } else {
+       /* FIXME how to get dpi ?
+        * 1. from user -> will open a dialog box for any old file
+        * 2. after loading from user changeable document settings
+        * 3. estimated from contained widgets
+        */
+       UMLApp::app()->document()->setResolution(0.0);
+    }
+
+    QDomNode diagrams = node.firstChild();
     const Settings::OptionState optionState = Settings::optionState();
     UMLDoc *umldoc = UMLApp::app()->document();
     bool totalSuccess = true;
@@ -386,7 +422,7 @@ bool UMLFolder::loadDiagramsFromXMI(QDomNode& diagrams)
          diagrams = diagrams.nextSibling(), diagram = diagrams.toElement()) {
         QString tag = diagram.tagName();
         if (tag != QLatin1String("diagram")) {
-            uDebug() << "ignoring " << tag << " in <diagrams>";
+            logDebug1("UMLFolder::loadDiagramsFromXMI1: ignoring %1 in <diagrams>", tag);
             continue;
         }
         UMLView * pView = new UMLView(this);
@@ -430,7 +466,7 @@ bool UMLFolder::loadFolderFile(const QString& path)
     QString error;
     int line;
     if (!doc.setContent(data, false, &error, &line)) {
-        uError() << "Cannot set content:" << error << " line:" << line;
+        logError2("UMLFolder::loadFolderFile cannot set content: error %1 line %2", error, line);
         return false;
     }
     QDomNode rootNode = doc.firstChild();
@@ -438,22 +474,23 @@ bool UMLFolder::loadFolderFile(const QString& path)
         rootNode = rootNode.nextSibling();
     }
     if (rootNode.isNull()) {
-        uError() << "Root node is Null";
+        logError0("UMLFolder::loadFolderFile: Root node is null");
         return false;
     }
     QDomElement element = rootNode.toElement();
     QString type = element.tagName();
     if (type != QLatin1String("external_file")) {
-        uError() << "Root node has unknown type " << type;
+        logError1("UMLFolder::loadFolderFile: Root node has unknown type %1", type);
         return false;
     }
-    return load(element);
+    return load1(element);
 }
 
 /**
- * Loads the owned elements of the <UML:Model>.
+ * Loads the owned elements of the \<packagedElement xmi:type="uml:Model">
+ * (in UML2 mode) or <UML:Model> (in UML1 mode).
  */
-bool UMLFolder::load(QDomElement& element)
+bool UMLFolder::load1(QDomElement& element)
 {
     UMLDoc *umldoc = UMLApp::app()->document();
     bool totalSuccess = true;
@@ -463,31 +500,29 @@ bool UMLFolder::load(QDomElement& element)
             continue;
         QDomElement tempElement = node.toElement();
         QString type = tempElement.tagName();
-        if (Model_Utils::isCommonXMIAttribute(type))
+        if (Model_Utils::isCommonXMI1Attribute(type))
             continue;
         if (UMLDoc::tagEq(type, QLatin1String("Namespace.ownedElement")) ||
                 UMLDoc::tagEq(type, QLatin1String("Namespace.contents"))) {
             //CHECK: Umbrello currently assumes that nested elements
             // are ownedElements anyway.
             // Therefore these tags are not further interpreted.
-            if (! load(tempElement)) {
-                uDebug() << "An error happened while loading the " << type
-                    << " of the " << name();
+            if (! load1(tempElement)) {
+                logDebug2("UMLFolder::load1 %1: An error happened while loading %2", name(), type);
                 totalSuccess = false;
             }
             continue;
-        } else if (UMLDoc::tagEq(type, QLatin1String("packagedElement")) ||
-                   UMLDoc::tagEq(type, QLatin1String("ownedElement"))) {
+        } else if (type == QLatin1String("packagedElement") ||
+                   type == QLatin1String("ownedElement")) {
             type = tempElement.attribute(QLatin1String("xmi:type"));
-        } else if (type == QLatin1String("XMI.extension")) {
+        } else if (type == QLatin1String("XMI.extension") ||
+                   type == QLatin1String("xmi:Extension")) {
             for (QDomNode xtnode = node.firstChild(); !xtnode.isNull();
                                               xtnode = xtnode.nextSibling()) {
                 QDomElement el = xtnode.toElement();
                 const QString xtag = el.tagName();
                 if (xtag == QLatin1String("diagrams")) {
-                    QDomNode diagramNode = xtnode.firstChild();
-                    if (!loadDiagramsFromXMI(diagramNode))
-                        totalSuccess = false;
+                    umldoc->addDiagramToLoad(this, xtnode);
                 } else if (xtag == QLatin1String("external_file")) {
 #if QT_VERSION >= 0x050000
                     const QString rootDir(umldoc->url().adjusted(QUrl::RemoveFilename).path());
@@ -499,7 +534,7 @@ bool UMLFolder::load(QDomElement& element)
                     if (loadFolderFile(path))
                         m_folderFile = fileName;
                 } else {
-                    uDebug() << name() << ": ignoring XMI.extension " << xtag;
+                    logDebug2("UMLFolder::load1 %1: ignoring XMI.extension %2", name(), xtag);
                     continue;
                 }
             }
@@ -524,14 +559,30 @@ bool UMLFolder::load(QDomElement& element)
             Uml::ID::Type id = Uml::ID::fromString(idStr);
             pObject = umldoc->findObjectById(id);
             if (pObject) {
-                uDebug() << "object " << idStr << "already exists";
+                logDebug1("UMLFolder::load1: object %1 already exists", idStr);
+            }
+        }
+        // Avoid duplicate creation of datatype
+        if (pObject == 0 && this == umldoc->datatypeFolder()) {
+            QString name = tempElement.attribute(QLatin1String("name"));
+            foreach (UMLObject *o, m_objects) {
+                uIgnoreZeroPointer(o);
+                if (o->name() == name) {
+                    UMLDatatype *dt = o->asUMLDatatype();
+                    if (dt) {
+                        QString isActive = tempElement.attribute(QLatin1String("isActive"));
+                        dt->setActive(isActive != QLatin1String("false"));
+                        pObject = dt;
+                        break;
+                    }
+                }
             }
         }
         if (pObject == 0) {
             QString stereoID = tempElement.attribute(QLatin1String("stereotype"));
             pObject = Object_Factory::makeObjectFromXMI(type, stereoID);
             if (!pObject) {
-                uWarning() << "Unknown type of umlobject to create: " << type;
+                logWarn1("UMLFolder::load1 unknown type of umlobject to create: %1", type);
                 continue;
             }
         }
@@ -545,6 +596,17 @@ bool UMLFolder::load(QDomElement& element)
     return totalSuccess;
 }
 
+bool UMLFolder::showPropertiesDialog(QWidget *parent)
+{
+    Q_UNUSED(parent);
+    QString folderName = this->name();
+    bool ok = Dialog_Utils::askRenameName(UMLObject::ot_Folder, folderName);
+    if (ok) {
+        setName(folderName);
+    }
+    return ok;
+}
+
 /**
  * Overloading operator for debugging output.
  */
