@@ -1,12 +1,7 @@
-/***************************************************************************
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   copyright (C) 2003-2014                                               *
- *   Umbrello UML Modeller Authors <umbrello-devel@kde.org>                *
- ***************************************************************************/
+/*
+    SPDX-License-Identifier: GPL-2.0-or-later
+    SPDX-FileCopyrightText: 2003-2022 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
+*/
 
 // own header
 #include "umlrole.h"
@@ -14,6 +9,8 @@
 // local includes
 #include "association.h"
 #include "debug_utils.h"
+#include "model_utils.h"
+#include "optionstate.h"
 #include "umldoc.h"
 #include "umlroledialog.h"
 #include "uml.h"
@@ -22,6 +19,8 @@
 #include <QPointer>
 #include <QRegExp>
 
+DEBUG_REGISTER(UMLRole)
+
 /**
  * Sets up an association.
  *
@@ -66,6 +65,21 @@ bool UMLRole::operator==(const UMLRole &rhs) const
           );
 }
 
+/**
+ * Returns a String representation of this UMLRole instance.
+ */
+QString UMLRole::toString() const
+{
+    QString result;
+    if (object()) {
+        result = object()->name();
+        result += QLatin1Char(':');
+        result += name();
+    } else
+        result = QLatin1String("null");
+    return result;
+}
+
 UMLAssociation * UMLRole::parentAssociation() const
 {
     return m_pAssoc;
@@ -113,8 +127,8 @@ void UMLRole::setObject(UMLObject *obj)
     // to only take UMLClassifiers here, but I'll leave it more open
     // for the time being. -b.t.
     if (obj && obj->asUMLRole()) {
-        uError() << "UMLRole(" << Uml::ID::toString(m_nId) << ") cannot setObject() to another UMLRole("
-            << Uml::ID::toString(obj->id()) << ")";
+        logError2("UMLRole(%1) cannot setObject() to another UMLRole(%2)",
+                  Uml::ID::toString(m_nId), Uml::ID::toString(obj->id()));
         return;
     }
 
@@ -159,59 +173,57 @@ Uml::RoleType::Enum UMLRole::role() const
 /**
  * Creates the <UML:AssociationEnd> XMI element.
  */
-void UMLRole::saveToXMI(QDomDocument & qDoc, QDomElement & qElement)
+void UMLRole::saveToXMI(QXmlStreamWriter& writer)
 {
-    QDomElement roleElement = UMLObject::save(QLatin1String("UML:AssociationEnd"), qDoc);
+    UMLObject::save1(writer, QLatin1String("AssociationEnd"), QLatin1String("ownedEnd"));
     if (m_pSecondary)
-        roleElement.setAttribute(QLatin1String("type"), Uml::ID::toString(m_pSecondary->id()));
+        writer.writeAttribute(QLatin1String("type"), Uml::ID::toString(m_pSecondary->id()));
     else
-        uError() << "id " << Uml::ID::toString(m_nId) << ": m_pSecondary is NULL";
+        logError1("UMLRole::saveToXMI(id %1) : m_pSecondary is null", Uml::ID::toString(m_nId));
     if (!m_Multi.isEmpty())
-        roleElement.setAttribute(QLatin1String("multiplicity"), m_Multi);
+        writer.writeAttribute(QLatin1String("multiplicity"), m_Multi);
     if (m_role == Uml::RoleType::A) {  // role aggregation based on parent type
         // role A
         switch (m_pAssoc->getAssocType()) {
         case Uml::AssociationType::Composition:
-            roleElement.setAttribute(QLatin1String("aggregation"), QLatin1String("composite"));
+            writer.writeAttribute(QLatin1String("aggregation"), QLatin1String("composite"));
             break;
         case Uml::AssociationType::Aggregation:
-            roleElement.setAttribute(QLatin1String("aggregation"), QLatin1String("aggregate"));
+            writer.writeAttribute(QLatin1String("aggregation"), QLatin1String("aggregate"));
             break;
         default:
-            roleElement.setAttribute(QLatin1String("aggregation"), QLatin1String("none"));
+            writer.writeAttribute(QLatin1String("aggregation"), QLatin1String("none"));
             break;
         }
         if (m_pAssoc->getAssocType() == Uml::AssociationType::UniAssociation) {
             // Normally the isNavigable attribute is "true".
             // We set it to false on role A to indicate that
             // role B gets an explicit arrowhead.
-            roleElement.setAttribute(QLatin1String("isNavigable"), QLatin1String("false"));
+            writer.writeAttribute(QLatin1String("isNavigable"), QLatin1String("false"));
         } else {
-            roleElement.setAttribute(QLatin1String("isNavigable"), QLatin1String("true"));
+            writer.writeAttribute(QLatin1String("isNavigable"), QLatin1String("true"));
         }
     } else {
-        roleElement.setAttribute(QLatin1String("aggregation"), QLatin1String("none"));
-        roleElement.setAttribute(QLatin1String("isNavigable"), QLatin1String("true"));
+        writer.writeAttribute(QLatin1String("aggregation"), QLatin1String("none"));
+        writer.writeAttribute(QLatin1String("isNavigable"), QLatin1String("true"));
         //FIXME obviously this isn't standard XMI
         if (m_pAssoc->getAssocType() == Uml::AssociationType::Relationship) {
-            roleElement.setAttribute(QLatin1String("relationship"), QLatin1String("true"));
+            writer.writeAttribute(QLatin1String("relationship"), QLatin1String("true"));
         }
     }
 
-    roleElement.setAttribute(QLatin1String("visibility"), Uml::Visibility::toString(visibility(), false));
-
     switch (m_Changeability) {
         case Uml::Changeability::Frozen:
-            roleElement.setAttribute(QLatin1String("changeability"), QLatin1String("frozen"));
+            writer.writeAttribute(QLatin1String("changeability"), QLatin1String("frozen"));
             break;
         case Uml::Changeability::AddOnly:
-            roleElement.setAttribute(QLatin1String("changeability"), QLatin1String("addOnly"));
+            writer.writeAttribute(QLatin1String("changeability"), QLatin1String("addOnly"));
             break;
         case Uml::Changeability::Changeable:
-            roleElement.setAttribute(QLatin1String("changeability"), QLatin1String("changeable"));
+            writer.writeAttribute(QLatin1String("changeability"), QLatin1String("changeable"));
             break;
     }
-    qElement.appendChild(roleElement);
+    writer.writeEndElement();
 }
 
 /**
@@ -223,10 +235,7 @@ void UMLRole::saveToXMI(QDomDocument & qDoc, QDomElement & qElement)
 bool UMLRole::showPropertiesDialog(QWidget *parent)
 {
     QPointer<UMLRoleDialog> dlg = new UMLRoleDialog(parent, this);
-    bool modified = false;
-    if (dlg->exec() == QDialog::Accepted) {
-        modified = true;
-    }
+    bool modified = dlg->exec() == QDialog::Accepted;
     delete dlg;
     return modified;
 }
@@ -235,14 +244,14 @@ bool UMLRole::showPropertiesDialog(QWidget *parent)
  * Loads the <UML:AssociationEnd> XMI element.
  * Auxiliary to UMLObject::loadFromXMI.
  */
-bool UMLRole::load(QDomElement & element)
+bool UMLRole::load1(QDomElement & element)
 {
     UMLDoc * doc = UMLApp::app()->document();
     QString type = element.attribute(QLatin1String("type"));
     if (!type.isEmpty()) {
         if (!m_SecondaryId.isEmpty())
-            uWarning() << "overwriting old m_SecondaryId \"" << m_SecondaryId
-                << " with new value \"" << type << "\"";
+            logWarn2("UMLRole::load1 overwriting old m_SecondaryId %1 with new value %2",
+                     m_SecondaryId, type);
         m_SecondaryId = type;
     }
     // Inspect child nodes - for multiplicity (and type if not set above.)
@@ -317,22 +326,22 @@ bool UMLRole::load(QDomElement & element)
         } else if (m_SecondaryId.isEmpty() &&
                    (UMLDoc::tagEq(tag, QLatin1String("type")) ||
                     UMLDoc::tagEq(tag, QLatin1String("participant")))) {
-            m_SecondaryId = tempElement.attribute(QLatin1String("xmi.id"));
+            m_SecondaryId = Model_Utils::getXmiId(tempElement);
             if (m_SecondaryId.isEmpty())
                 m_SecondaryId = tempElement.attribute(QLatin1String("xmi.idref"));
             if (m_SecondaryId.isEmpty()) {
                 QDomNode inner = tempElement.firstChild();
                 QDomElement innerElem = inner.toElement();
-                m_SecondaryId = innerElem.attribute(QLatin1String("xmi.id"));
+                m_SecondaryId = Model_Utils::getXmiId(innerElem);
                 if (m_SecondaryId.isEmpty())
                     m_SecondaryId = innerElem.attribute(QLatin1String("xmi.idref"));
             }
         }
     }
     if (!m_Multi.isEmpty())
-        uDebug() << name() << ": m_Multi is " << m_Multi;
+        logDebug2("UMLRole::load1 %1: m_Multi is %2", name(), m_Multi);
     if (m_SecondaryId.isEmpty()) {
-        uError() << name() << ": type not given or illegal";
+        logError1("UMLRole::load1(%1) : type not given or illegal", name());
         return false;
     }
     UMLObject * obj;
