@@ -144,9 +144,9 @@ public:
     Settings::OptionState& optionState();
     void setOptionState(const Settings::OptionState& options);
 
-    const AssociationWidgetList associationList() const;
-    const MessageWidgetList messageList() const;
-    const UMLWidgetList widgetList() const;
+    AssociationWidgetList associationList() const;
+    MessageWidgetList messageList() const;
+    UMLWidgetList widgetList() const;
     void addWidgetCmd(UMLWidget* widget);
     void addWidgetCmd(AssociationWidget *widget);
 
@@ -274,12 +274,10 @@ public:
 
     void fileLoaded();
 
-    void resizeSceneToItems();
-
     // Load/Save interface:
 
-    virtual void saveToXMI1(QXmlStreamWriter& writer);
-    virtual bool loadFromXMI1(QDomElement & qElement);
+    virtual void saveToXMI(QXmlStreamWriter& writer);
+    virtual bool loadFromXMI(QDomElement & qElement);
 
     bool loadUISDiagram(QDomElement & qElement);
     UMLWidget* loadWidgetFromXMI(QDomElement& widgetElement);
@@ -323,6 +321,13 @@ public:
     void setWidgetLink(WidgetBase *w);
     WidgetBase *widgetLink();
 
+    qreal maxCanvasSize() { return s_maxCanvasSize; }
+
+    void updateCanvasSizeEstimate(qreal x, qreal y, qreal w, qreal h);
+
+    qreal fixX() const;
+    qreal fixY() const;
+
 protected:
     // Methods and members related to loading/saving
 
@@ -390,20 +395,26 @@ protected:
 
 private:
     UMLScenePrivate *m_d;
-    static const qreal defaultCanvasSize;  ///< The default size of a diagram in pixels.
-    static bool m_showDocumentationIndicator; ///< Status of documentation indicator
+    static const qreal s_defaultCanvasWidth;    ///< The default width of a diagram in pixels.
+    static const qreal s_defaultCanvasHeight;   ///< The default height of a diagram in pixels.
+    static const qreal s_maxCanvasSize;         ///< The maximum supported canvas size.
+    static bool s_showDocumentationIndicator; ///< Status of documentation indicator
 
     UMLView *m_view;   ///< The view to which this scene is related.
     UMLFolder *m_pFolder;  ///< The folder in which this UMLView is contained.
 
     IDChangeLog * m_pIDChangesLog;  ///< LocalID Changes Log for paste actions
-    bool m_isActivated;             ///< True if the view was activated after the serialization(load).
+    bool m_isActivated;             ///< True if the view was activated after the deserialization(load).
     bool m_bPopupShowing;           ///< Status of a popupmenu on view. True - a popup is on view.
     QPointF m_PastePoint;     ///< The offset at which to paste the clipboard.
     UMLDoc* m_doc;                  ///< Pointer to the UMLDoc.
     UMLViewImageExporter* m_pImageExporter;  ///< Used to export the view.
     LayoutGrid*  m_layoutGrid;      ///< layout grid in the background
     bool m_autoIncrementSequence; ///< state of auto increment sequence
+    qreal m_minX, m_minY;     ///< Gather data for estimating required canvas size (used during loadFromXMI)
+    qreal m_maxX, m_maxY;     ///< Gather data for estimating required canvas size (used during loadFromXMI)
+    qreal m_fixX;             ///< Compensate for QGraphicsScene offsets, https://bugs.kde.org/show_bug.cgi?id=449622
+    qreal m_fixY;             ///< Compensate for QGraphicsScene offsets, https://bugs.kde.org/show_bug.cgi?id=449622
 
     void createAutoAttributeAssociation(UMLClassifier *type,
                                         UMLAttribute *attr,
