@@ -1,12 +1,13 @@
 /*
     SPDX-License-Identifier: GPL-2.0-or-later
-    SPDX-FileCopyrightText: 2006-2020 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
+    SPDX-FileCopyrightText: 2006-2022 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
 */
 
 // own header
 #include "umlviewimageexporter.h"
 
 // application specific includes
+#define DBG_SRC QLatin1String("UMLViewImageExporter")
 #include "debug_utils.h"
 #include "dotgenerator.h"
 #include "umlfiledialog.h"
@@ -35,7 +36,6 @@
 #include <QString>
 #include <QStringList>
 
-#define DBG_IE QLatin1String("UMLViewImageExporter")
 DEBUG_REGISTER_DISABLED(UMLViewImageExporter)
 
 /**
@@ -170,7 +170,8 @@ bool UMLViewImageExporter::getParametersFromUser()
         m_imageMimeType = dialog->currentMimeFilter();
 #endif
         UMLApp::app()->setImageMimeType(m_imageMimeType);
-        DEBUG(DBG_IE) << "image mime type=" << m_imageMimeType << " / URL=" << m_imageURL;
+        logDebug2("UMLViewImageExporter::getParametersFromUser: image mime type=%1"
+                  " / URL=%2", m_imageMimeType, m_imageURL.path());
     }
     delete dialog;
     return success;
