@@ -1,6 +1,6 @@
 /*
     SPDX-License-Identifier: GPL-2.0-or-later
-    SPDX-FileCopyrightText: 2002-2020 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
+    SPDX-FileCopyrightText: 2002-2022 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
 */
 
 // own header
@@ -32,7 +32,7 @@ const qreal AssociationLine::SelfAssociationMinimumHeight = 30;
 
 /**
  * Constructor.
- * Constructs an AssociationLine item with its parent being \a parent.
+ * Constructs an AssociationLine item slaved to the given AssociationWidget.
  */
 AssociationLine::AssociationLine(AssociationWidget *association)
   : QGraphicsObject(association),
@@ -71,7 +71,8 @@ AssociationLine::~AssociationLine()
 QPointF AssociationLine::point(int index) const
 {
     if ((index < 0) | (index >= m_points.size())) {
-        uWarning() << "Index " << index << " out of range [0.." << m_points.size() - 1 << "].";
+        logWarn2("AssociationLine::point: Index %1 out of range [0..%2]",
+                 index, m_points.size() - 1);
         return QPointF(-1.0, -1.0);
     }
     return m_points.at(index);
@@ -83,7 +84,8 @@ QPointF AssociationLine::point(int index) const
 bool AssociationLine::setPoint(int index, const QPointF &point)
 {
     if ((index < 0) | (index >= m_points.size())) {
-        uWarning() << "Index " << index << " out of range [0.." << m_points.size() - 1 << "].";
+        logWarn2("AssociationLine::setPoint: Index %1 out of range [0..%2]",
+                 index, m_points.size() - 1);
         return false;
     }
     if (m_points.at(index) == point) {
@@ -217,6 +219,8 @@ int AssociationLine::closestPointIndex(const QPointF &point, qreal delta) const
  * Return index of closest segment.
  *
  * @param point The point which is to be tested for closeness.
+ * @param delta The distance in pixels that the point may be removed from
+ *              a segment but is still considered to be on the segment.
  *
  * @return Index of the line segment closest to the \a point passed;
  *         -1 if no line segment is closer to passed in \a point.
@@ -314,14 +318,14 @@ void AssociationLine::dumpPoints()
 {
     for (int i = 1; i < m_points.size(); ++i) {
         QPointF p = m_points.at(i);
-        DEBUG(DBG_SRC) << i << ". point x:" << p.x() << " / y:" << p.y();
+        DEBUG() << i << ". point x:" << p.x() << " / y:" << p.y();
     }
 }
 
 /**
  * Loads AssociationLine information saved in \a qElement XMI element.
  */
-bool AssociationLine::loadFromXMI1(QDomElement &qElement)
+bool AssociationLine::loadFromXMI(QDomElement &qElement)
 {
     QString layout = qElement.attribute(QLatin1String("layout"), QLatin1String("polyline"));
     m_layout = Uml::LayoutType::fromString(layout);
@@ -334,11 +338,12 @@ bool AssociationLine::loadFromXMI1(QDomElement &qElement)
     if(startElement.isNull() || startElement.tagName() != QLatin1String("startpoint")) {
         return false;
     }
+    UMLScene* umlScene = m_associationWidget->umlScene();
     qreal dpiScale = UMLApp::app()->document()->dpiScale();
     QString x = startElement.attribute(QLatin1String("startx"), QLatin1String("0"));
-    qreal nX = toDoubleFromAnyLocale(x);
+    qreal nX = toDoubleFromAnyLocale(x) + umlScene->fixX();
     QString y = startElement.attribute(QLatin1String("starty"), QLatin1String("0"));
-    qreal nY = toDoubleFromAnyLocale(y);
+    qreal nY = toDoubleFromAnyLocale(y) + umlScene->fixY();
     QPointF startPoint(nX, nY);
 
     node = startElement.nextSibling();
@@ -347,21 +352,21 @@ bool AssociationLine::loadFromXMI1(QDomElement &qElement)
         return false;
     }
     x = endElement.attribute(QLatin1String("endx"), QLatin1String("0"));
-    nX = toDoubleFromAnyLocale(x);
+    nX = toDoubleFromAnyLocale(x) + umlScene->fixX();
     y = endElement.attribute(QLatin1String("endy"), QLatin1String("0"));
-    nY = toDoubleFromAnyLocale(y);
+    nY = toDoubleFromAnyLocale(y) + umlScene->fixY();
     QPointF endPoint(nX, nY);
     setEndPoints(startPoint * dpiScale, endPoint * dpiScale);
     QPointF point;
     node = endElement.nextSibling();
     QDomElement element = node.toElement();
     int i = 1;
-    while(!element.isNull()) {
-        if(element.tagName() == QLatin1String("point")) {
+    while (!element.isNull()) {
+        if (element.tagName() == QLatin1String("point")) {
             x = element.attribute(QLatin1String("x"), QLatin1String("0"));
             y = element.attribute(QLatin1String("y"), QLatin1String("0"));
-            point.setX(toDoubleFromAnyLocale(x));
-            point.setY(toDoubleFromAnyLocale(y));
+            point.setX(toDoubleFromAnyLocale(x) + umlScene->fixX());
+            point.setY(toDoubleFromAnyLocale(y) + umlScene->fixY());
             insertPoint(i++, point * dpiScale);
         }
         node = element.nextSibling();
@@ -375,7 +380,7 @@ bool AssociationLine::loadFromXMI1(QDomElement &qElement)
  * Saves association line information into XMI element named "linepath".
  * @note Stored as linepath for backward compatibility
  */
-void AssociationLine::saveToXMI1(QXmlStreamWriter& writer)
+void AssociationLine::saveToXMI(QXmlStreamWriter& writer)
 {
     writer.writeStartElement(QLatin1String("linepath"));
     writer.writeAttribute(QLatin1String("layout"), Uml::LayoutType::toString(m_layout));
@@ -484,8 +489,9 @@ void AssociationLine::calculateInitialEndPoints()
         }
         UMLWidget *wid = m_associationWidget->widgetForRole(Uml::RoleType::B);
         if (!wid) {
-            uError() << "AssociationWidget is partially constructed."
-                "UMLWidget for role B is null.";
+            logError0("AssociationLine::calculateInitialEndPoints: "
+                      "AssociationWidget is partially constructed."
+                      "UMLWidget for role B is null.");
             return;
         }
         const QRectF rect = m_associationWidget->mapFromScene(
@@ -756,9 +762,11 @@ void AssociationLine::alignSymbols()
  */
 QPainterPath AssociationLine::path() const
 {
-    if (m_points.count() > 0) {
-        QPainterPath path;
-        switch (m_layout) {
+    if (m_points.count() == 0) {
+        return QPainterPath();
+    }
+    QPainterPath path;
+    switch (m_layout) {
         case Uml::LayoutType::Direct:
             path.moveTo(m_points.first());
             path.lineTo(m_points.last());
@@ -777,12 +785,8 @@ QPainterPath AssociationLine::path() const
             QPolygonF polygon(m_points);
             path.addPolygon(polygon);
             break;
-        }
-        return path;
-    }
-    else {
-        return QPainterPath();
     }
+    return path;
 }
 
 /**
@@ -849,7 +853,7 @@ void AssociationLine::setLayout(Uml::LayoutType::Enum layout)
 {
     prepareGeometryChange();
     m_layout = layout;
-    DEBUG(DBG_SRC) << "new layout = " << Uml::LayoutType::toString(m_layout);
+    DEBUG() << "new layout = " << Uml::LayoutType::toString(m_layout);
     if (m_layout == Uml::LayoutType::Spline) {
         createSplinePoints();
     }
@@ -879,35 +883,35 @@ void AssociationLine::createSplinePoints()
         qreal oneHalfX = 0.5 * dx;
         qreal oneHalfY = 0.5 * dy;
         if (dx > dy) {
-            c1dx = oneHalfX;
-            c1dy = 0;
-            c2dx = -oneHalfX;
-            c2dy = 0;
+            m_c1dx = oneHalfX;
+            m_c1dy = 0;
+            m_c2dx = -oneHalfX;
+            m_c2dy = 0;
         }
         else {
-            c1dx = 0;
-            c1dy = oneHalfY;
-            c2dx = 0;
-            c2dy = -oneHalfY;
+            m_c1dx = 0;
+            m_c1dy = oneHalfY;
+            m_c2dx = 0;
+            m_c2dy = -oneHalfY;
         }
         
-        c1 = QPointF(p1.x() + c1dx,  // control point 1
-                p1.y() + c1dy);
-        c2 = QPointF(p2.x() + c2dx,  // control point 2
-                p2.y() + c2dy);
+        c1 = QPointF(p1.x() + m_c1dx,  // control point 1
+                     p1.y() + m_c1dy);
+        c2 = QPointF(p2.x() + m_c2dx,  // control point 2
+                     p2.y() + m_c2dy);
     } else {
         //c1 = m_points[1];
         //c2 = m_points[2];
         
-        //c1dx = c1.x() - p1.x();
-        //c1dy = c1.y() - p1.y();
-        //c2dx = c2.x() - p2.x();
-        //c2dy = c2.y() - p2.y();
+        //m_c1dx = c1.x() - p1.x();
+        //m_c1dy = c1.y() - p1.y();
+        //m_c2dx = c2.x() - p2.x();
+        //m_c2dy = c2.y() - p2.y();
         
-        c1 = QPointF(p1.x() + c1dx,  // control point 1
-                    p1.y() + c1dy);
-        c2 = QPointF(p2.x() + c2dx,  // control point 2
-                    p2.y() + c2dy);
+        c1 = QPointF(p1.x() + m_c1dx,  // control point 1
+                     p1.y() + m_c1dy);
+        c2 = QPointF(p2.x() + m_c2dx,  // control point 2
+                     p2.y() + m_c2dy);
     }
     if (m_points.size() == 2) {  // create two points
         insertPoint(1, c1);
@@ -972,7 +976,7 @@ QPainterPath AssociationLine::createOrthogonalPath(QVector<QPointF> points)
         QPointF end    = points.last();
         qreal deltaX = fabs(start.x() - end.x());
         qreal deltaY = fabs(start.y() - end.y());
-        // DEBUG("AssociationLine") << "start=" << start << " / end=" << end
+        // DEBUG() << "start=" << start << " / end=" << end
         //               << " / deltaX=" << deltaX << " / deltaY=" << deltaY;
         QVector<QPointF> vector;
         for (int i = 0; i < points.size() - 1; ++i) {
@@ -1134,18 +1138,14 @@ void AssociationLine::paint(QPainter* painter, const QStyleOptionGraphicsItem* o
  */
 void AssociationLine::mousePressEvent(QGraphicsSceneMouseEvent *event)
 {
-    DEBUG(DBG_SRC) << "at " << event->scenePos();
+    DEBUG() << "at " << event->scenePos();
     if (event->buttons() & Qt::LeftButton) {
         m_activePointIndex = closestPointIndex(event->scenePos());
-        if (m_activePointIndex != -1 && isEndPointIndex(m_activePointIndex)) {
-            // end points are not drawn and hence not active
-            m_activePointIndex = -1;
-        }
         // calculate only if active point index is -1
         m_activeSegmentIndex = (m_activePointIndex != -1) ? -1 : closestSegmentIndex(event->scenePos());
     }
     else if (event->buttons() & Qt::RightButton) {
-        DEBUG(DBG_SRC) << "call context menu of association widget at " << event->scenePos();
+        DEBUG() << "call context menu of association widget at " << event->scenePos();
     }
     else {
         m_activePointIndex   = -1;
@@ -1160,10 +1160,10 @@ void AssociationLine::mouseMoveEvent(QGraphicsSceneMouseEvent *event)
 {
     UMLScene* scene = m_associationWidget->umlScene();
 
-    QPointF oldPos = event->scenePos();
+    QPointF unsnappedPos = event->scenePos();
     QPointF newPos(
-        scene->snappedX(oldPos.x()),
-        scene->snappedY(oldPos.y())
+        scene->snappedX(unsnappedPos.x()),
+        scene->snappedY(unsnappedPos.y())
     );
 
     // Prevent the moving vertex from disappearing underneath a widget
@@ -1193,13 +1193,14 @@ void AssociationLine::mouseMoveEvent(QGraphicsSceneMouseEvent *event)
     }
 
     if (m_activePointIndex != -1) {
+        const int nPoints = m_points.size();
         // Move a single point (snap behaviour)
         if (m_activePointIndex == 1) {
-            c1dx = newPos.x() - m_points.at(0).x();
-            c1dy = newPos.y() - m_points.at(0).y();
-        } else if (m_activePointIndex == 2) {
-            c2dx = newPos.x() - m_points.at(3).x();
-            c2dy = newPos.y() - m_points.at(3).y();
+            m_c1dx = newPos.x() - m_points.at(0).x();
+            m_c1dy = newPos.y() - m_points.at(0).y();
+        } else if (nPoints > 3 && m_activePointIndex == nPoints - 2) {
+            m_c2dx = newPos.x() - m_points.at(nPoints-1).x();
+            m_c2dy = newPos.y() - m_points.at(nPoints-1).y();
         }
         setPoint(m_activePointIndex, newPos);
         m_autoLayoutSpline = false;
@@ -1224,12 +1225,12 @@ void AssociationLine::mouseReleaseEvent(QGraphicsSceneMouseEvent *event)
 }
 
 /**
- * Calculates the "to be highlighted" point and segment indicies
+ * Calculates the "to be highlighted" point and segment indices
  * and updates if necessary.
  */
 void AssociationLine::hoverEnterEvent(QGraphicsSceneHoverEvent *event)
 {
-    DEBUG(DBG_SRC) << "at " << event->scenePos();
+    DEBUG() << "at " << event->scenePos();
     int oldPointIndex = m_activePointIndex;
     int oldSegmentIndex = m_activeSegmentIndex;
 
@@ -1248,7 +1249,7 @@ void AssociationLine::hoverEnterEvent(QGraphicsSceneHoverEvent *event)
 }
 
 /**
- * Calculates the "to be highlighted" point and segment indicies
+ * Calculates the "to be highlighted" point and segment indices
  * and updates if necessary.
  */
 void AssociationLine::hoverMoveEvent(QGraphicsSceneHoverEvent *event)
@@ -1271,11 +1272,11 @@ void AssociationLine::hoverMoveEvent(QGraphicsSceneHoverEvent *event)
 }
 
 /**
- * Reset active indicies and updates.
+ * Reset active indices and updates.
  */
 void AssociationLine::hoverLeaveEvent(QGraphicsSceneHoverEvent *event)
 {
-    DEBUG(DBG_SRC) << "at " << event->scenePos();
+    DEBUG() << "at " << event->scenePos();
     //Q_UNUSED(event)
     m_activePointIndex   = -1;
     m_activeSegmentIndex = -1;
@@ -1284,46 +1285,78 @@ void AssociationLine::hoverLeaveEvent(QGraphicsSceneHoverEvent *event)
 
 //-----------------------------------------------------------------------------
 
+/**
+ * Auxiliary struct for Symbol::SymbolProperty in C Plain Old Data format
+ * avoids danger of "C++ static initialization order fiasco", see
+ * https://en.cppreference.com/w/cpp/language/siof
+ */
+struct SymbolPropertyPOD {
+    int boundRectX, boundRectY, boundRectW, boundRectH;
+    int axisLineStartX, axisLineStartY, axisLineEndX, axisLineEndY;
+    int endPoint0x, endPoint0y, endPoint1x, endPoint1y;
+};
+
+static const SymbolPropertyPOD symPropData[] =
+{
+    {
+        -6,  0, 12, 10,
+         0,  0,  0, 10,
+         0, 10,  0, 10
+    },
+    {
+        -6,  0, 12, 10,
+         0,  0,  0, 10,
+         0,  0,  0, 10
+    },
+    {
+        -6,  0, 12, 10,
+         0,  0,  0, 10,
+         0, 10,  0, 10
+    },
+    {
+        -5, -10, 10, 20,
+         0, -10,  0, 10,
+         0, -10,  0, 10
+    },
+    {
+        -15, -10, 30, 20,
+        -10,   0,  0,  0,
+          0,   0,  0,  0
+    },
+    {
+        -8, -8, 16, 16,
+         0, -8,  0,  8,
+         0, -8,  0,  8
+    }
+};
+
 /**
  * SymbolEndPoints:
  * The first point is where the AssociationLine's visible line is
  * supposed to end.
  * The second points is where the actual symbol part is to appear.
  */
-Symbol::SymbolProperty Symbol::symbolTable[Count] =
-{
-    {
-        QRectF(-6, 0, 12, 10), QPainterPath(), QLineF(0, 0, 0, 10),
-        SymbolEndPoints(QPointF(0, 10), QPointF(0, 10))
-    },
-    {
-        QRectF(-6, 0, 12, 10), QPainterPath(), QLineF(0, 0, 0, 10),
-        SymbolEndPoints(QPointF(0, 0), QPointF(0, 10))
-    },
-    {
-        QRectF(-6, 0, 12, 10), QPainterPath(), QLineF(0, 0, 0, 10),
-        SymbolEndPoints(QPointF(0, 10), QPointF(0, 10))
-    },
-    {
-        QRectF(-5, -10, 10, 20), QPainterPath(), QLineF(0, -10, 0, 10),
-        SymbolEndPoints(QPointF(0, -10), QPointF(0, 10))
-    },
-    {
-        QRectF(-15, -10, 30, 20), QPainterPath(), QLineF(-10, 0, 0, 0),
-        SymbolEndPoints(QPointF(0, 0), QPointF(0, 0))
-    },
-    {
-        QRectF(-8, -8, 16, 16), QPainterPath(), QLineF(0, -8, 0, 8),
-        SymbolEndPoints(QPointF(0, -8), QPointF(0, 8))
-    }
-
-};
+Symbol::SymbolProperty *Symbol::symbolTable;
 
 /**
  * @internal A convenience method to setup shapes of all symbols.
  */
 void Symbol::setupSymbolTable()
 {
+    if (symbolTable)
+        return;
+    symbolTable = new SymbolProperty[Count];
+
+    // Copy C symPropData to C++ symbolTable
+    for (int i = 0; i < Count; i++) {
+        const SymbolPropertyPOD& c = symPropData[i];
+        SymbolProperty& prop = symbolTable[i];
+        prop.boundRect = QRectF(c.boundRectX, c.boundRectY, c.boundRectW, c.boundRectH);
+        prop.axisLine  = QLineF(c.axisLineStartX, c.axisLineStartY, c.axisLineEndX, c.axisLineEndY);
+        prop.endPoints = SymbolEndPoints(QPointF(c.endPoint0x, c.endPoint0y),
+                                         QPointF(c.endPoint1x, c.endPoint1y));
+    }
+
     SymbolProperty &openArrow = symbolTable[OpenArrow];
     if (openArrow.shape.isEmpty()) {
         QRectF rect = openArrow.boundRect;
@@ -1450,7 +1483,7 @@ void Symbol::paint(QPainter *painter, const QStyleOptionGraphicsItem * option, Q
     default:
         break;
     }
-    painter->drawPath(Symbol::symbolTable[m_symbolType].shape);
+    painter->drawPath(symbolTable[m_symbolType].shape);
 }
 
 /**
@@ -1459,7 +1492,7 @@ void Symbol::paint(QPainter *painter, const QStyleOptionGraphicsItem * option, Q
 QRectF Symbol::boundingRect() const
 {
     const qreal adj = .5 * m_pen.widthF();
-    return Symbol::symbolTable[m_symbolType].boundRect.
+    return symbolTable[m_symbolType].boundRect.
         adjusted(-adj, -adj, adj, adj);
 }
 
@@ -1486,7 +1519,7 @@ void Symbol::alignTo(const QLineF& to)
 {
     QLineF toMapped(mapFromParent(to.p1()), mapFromParent(to.p2()));
 
-    QLineF origAxis = Symbol::symbolTable[m_symbolType].axisLine;
+    QLineF origAxis = symbolTable[m_symbolType].axisLine;
     QLineF translatedAxis = origAxis.translated(toMapped.p2() - origAxis.p2());
 
     qreal angle = translatedAxis.angleTo(toMapped);
@@ -1501,7 +1534,7 @@ void Symbol::alignTo(const QLineF& to)
  */
 Symbol::SymbolEndPoints Symbol::symbolEndPoints() const
 {
-    return Symbol::symbolTable[m_symbolType].endPoints;
+    return symbolTable[m_symbolType].endPoints;
 }
 
 /**
