@@ -1,11 +1,12 @@
 /*
     SPDX-License-Identifier: GPL-2.0-or-later
-    SPDX-FileCopyrightText: 2002-2020 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
+    SPDX-FileCopyrightText: 2002-2022 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
 */
 
 #ifndef ASSOCIATIONWIDGET_H
 #define ASSOCIATIONWIDGET_H
 
+#include "associationline.h"
 #include "associationwidgetlist.h"
 #include "associationwidgetrole.h"
 #include "linkwidget.h"
@@ -13,7 +14,6 @@
 #include "umlwidgetlist.h"
 #include "widgetbase.h"
 
-class AssociationLine;
 class ClassifierWidget;
 class UMLScene;
 class UMLAssociation;
@@ -57,7 +57,7 @@ public:
 
     virtual void setUMLObject(UMLObject *obj);
 
-    //---------- LinkWidget Interface methods implementation from now on.
+    //---------- LinkWidget Interface methods implementation from here on.
 
     virtual void lwSetFont(QFont font);
     virtual UMLClassifier *operationOwner();
@@ -137,7 +137,8 @@ public:
     bool isActivated() const;
     void setActivated(bool active);
 
-    AssociationLine* associationLine() const;
+    const AssociationLine& associationLine() const;
+    AssociationLine& associationLine();
 
     virtual bool activate(IDChangeLog *changeLog = 0);
     virtual QRectF boundingRect() const;
@@ -175,10 +176,10 @@ public:
 
     void clipSize();
 
-    bool loadFromXMI1(QDomElement& qElement, const UMLWidgetList& widgets,
+    bool loadFromXMI(QDomElement& qElement, const UMLWidgetList& widgets,
                      const MessageWidgetList* messages);
-    virtual bool loadFromXMI1(QDomElement& qElement);
-    virtual void saveToXMI1(QXmlStreamWriter& writer);
+    virtual bool loadFromXMI(QDomElement& qElement);
+    virtual void saveToXMI(QXmlStreamWriter& writer);
 
     void cleanup();
 
@@ -221,7 +222,7 @@ private:
     void mergeAssociationDataIntoUMLRepresentation();
 
     static Uml::Region::Enum findPointRegion(const QRectF& rect, const QPointF& pos);
-    static qreal findInterceptOnEdge(const QRectF &rect, Uml::Region::Enum region, const QPointF &point);
+    static bool findIntercept(const QRectF& rect, const QPointF& point, QPointF& result);
     static QLineF::IntersectType intersect(const QRectF &rect, const QLineF &line,
                                            QPointF* intersectionPoint);
 
@@ -231,11 +232,6 @@ private:
 
     static QPointF swapXY(const QPointF &p);
 
-    // not used at the moment
-    // static QPointF calculatePointAtDistance(const QPointF &P1, const QPointF &P2, float Distance);
-    // static QPointF calculatePointAtDistanceOnPerpendicular(const QPointF &P1, const QPointF &P2, float Distance);
-    // static float perpendicularProjection(const QPointF& P1, const QPointF& P2, const QPointF& P3, QPointF& ResultingPoint);
-
     static QPointF midPoint(const QPointF& p0, const QPointF& p1);
 
     void createPointsSelfAssociation();
@@ -243,14 +239,9 @@ private:
     void createPointsException();
     void updatePointsException();
 
-    void updateRegionLineCount(int index, int totalCount,
-                               Uml::Region::Enum region, Uml::RoleType::Enum role);
+    static bool setStartAndEndPoint(AssociationWidget *assocwidget, UMLWidget *pWidget);
 
-    void updateAssociations(int totalCount, Uml::Region::Enum region, Uml::RoleType::Enum role);
-
-    int getRegionCount(Uml::Region::Enum region, Uml::RoleType::Enum role);
-
-    void doUpdates(const QPointF &otherP, Uml::RoleType::Enum role);
+    static void updateAssociations(UMLWidget *pWidget, AssociationWidgetList list);
 
     void setChangeWidget(const QString &strChangeWidget, Uml::RoleType::Enum role);
 
@@ -258,13 +249,8 @@ private:
     bool checkRemovePoint(const QPointF &scenePos);
     bool checkAutoLayoutSpline();
 
-    bool linePathStartsAt(const UMLWidget* widget);
-
-    void insertIntoLists(qreal position, const AssociationWidget* assoc);
-
-    qreal m_positions[100];           ///< auxiliary variable for updateAssociations()
-    int m_positions_len;              ///< auxiliary variable for updateAssociations()
-    AssociationWidgetList m_ordered;  ///< auxiliary variable for updateAssociations()
+    bool linePathStartsAt(const UMLWidget* widget) const;
+    bool linePathEndsAt  (const UMLWidget* widget) const;
 
     bool m_activated;   ///< flag which is true if the activate method has been called for this class instance
 
@@ -290,7 +276,7 @@ private:
     QGraphicsRectItem *m_pAssocClassLineSel0;  ///< selection decoration for the start point of the assoc. class line
     QGraphicsRectItem *m_pAssocClassLineSel1;  ///< selection decoration for the end point of the assoc. class line
 
-    AssociationLine *m_associationLine;      ///< the definition points for the association line
+    AssociationLine   m_associationLine;     ///< the definition points for the association line
     ClassifierWidget *m_associationClass;    ///< used if we have an assoc. class
     Uml::AssociationType::Enum m_associationType;  ///< is only used if m_pObject is not set
     AssociationWidgetRole  m_role[2];
