@@ -1,6 +1,6 @@
 /*
     SPDX-License-Identifier: GPL-2.0-or-later
-    SPDX-FileCopyrightText: 2003-2020 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
+    SPDX-FileCopyrightText: 2003-2021 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
 */
 
 // own header
@@ -138,7 +138,7 @@ void EnumWidget::paint(QPainter *painter, const QStyleOptionGraphicsItem *option
     painter->drawLine(0, y, w, y);
 
     QFontMetrics fontMetrics(font);
-    UMLClassifier *classifier = m_umlObject->asUMLClassifier();
+    const UMLClassifier *classifier = m_umlObject->asUMLClassifier();
     UMLClassifierListItem* enumLiteral = 0;
     UMLClassifierListItemList list = classifier->getFilteredList(UMLObject::ot_EnumLiteral);
     foreach (enumLiteral, list) {
@@ -155,9 +155,9 @@ void EnumWidget::paint(QPainter *painter, const QStyleOptionGraphicsItem *option
 /**
  * Loads from an "enumwidget" XMI element.
  */
-bool EnumWidget::loadFromXMI1(QDomElement & qElement)
+bool EnumWidget::loadFromXMI(QDomElement & qElement)
 {
-    if (!UMLWidget::loadFromXMI1(qElement)) {
+    if (!UMLWidget::loadFromXMI(qElement)) {
         return false;
     }
     QString showpackage = qElement.attribute(QLatin1String("showpackage"), QLatin1String("0"));
@@ -170,10 +170,10 @@ bool EnumWidget::loadFromXMI1(QDomElement & qElement)
 /**
  * Saves to the "enumwidget" XMI element.
  */
-void EnumWidget::saveToXMI1(QXmlStreamWriter& writer)
+void EnumWidget::saveToXMI(QXmlStreamWriter& writer)
 {
     writer.writeStartElement(QLatin1String("enumwidget"));
-    UMLWidget::saveToXMI1(writer);
+    UMLWidget::saveToXMI(writer);
 
     writer.writeAttribute(QLatin1String("showpackage"), QString::number(m_showPackage));
     writer.writeEndElement();
@@ -247,7 +247,7 @@ QSizeF EnumWidget::minimumSize() const
 
     width = w > width?w:width;
 
-    UMLClassifier *classifier = m_umlObject->asUMLClassifier();
+    const UMLClassifier *classifier = m_umlObject->asUMLClassifier();
     UMLClassifierListItemList list = classifier->getFilteredList(UMLObject::ot_EnumLiteral);
     UMLClassifierListItem* listItem = 0;
     foreach (listItem, list) {
