@@ -1,6 +1,6 @@
 /*
     SPDX-License-Identifier: GPL-2.0-or-later
-    SPDX-FileCopyrightText: 2002-2020 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
+    SPDX-FileCopyrightText: 2002-2022 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
 */
 
 // onw header
@@ -153,7 +153,7 @@ MessageWidget::~MessageWidget()
 void MessageWidget::setY(qreal y)
 {
     if (y < getMinY()) {
-        DEBUG(DBG_SRC) << "got out of bounds y position, check the reason" << this->y() << getMinY();
+        DEBUG() << "got out of bounds y position, check the reason" << this->y() << getMinY();
         return;
     }
 
@@ -196,7 +196,7 @@ bool MessageWidget::isInResizeArea(QGraphicsSceneMouseEvent *me)
 {
     if (!m_resizable) {
         m_scene->activeView()->setCursor(Qt::ArrowCursor);
-        DEBUG(DBG_SRC) << "!m_resizable";
+        DEBUG() << "!m_resizable";
         return false;
     }
 
@@ -212,7 +212,7 @@ bool MessageWidget::isInResizeArea(QGraphicsSceneMouseEvent *me)
 
     if (me->scenePos().y() < y() + h - m) {
         m_scene->activeView()->setCursor(Qt::ArrowCursor);
-        DEBUG(DBG_SRC) << "Y condition not satisfied";
+        DEBUG() << "Y condition not satisfied";
         return false;
     }
 
@@ -221,11 +221,11 @@ bool MessageWidget::isInResizeArea(QGraphicsSceneMouseEvent *me)
     if ((x1 < x2 && me->scenePos().x() >= x() + w - m) ||
         (x1 > x2 && me->scenePos().x() >= x() - m)) {
         m_scene->activeView()->setCursor(Qt::SizeVerCursor);
-        DEBUG(DBG_SRC) << "X condition is satisfied";
+        DEBUG() << "X condition is satisfied";
         return true;
     } else {
         m_scene->activeView()->setCursor(Qt::ArrowCursor);
-        DEBUG(DBG_SRC) << "X condition not satisfied";
+        DEBUG() << "X condition not satisfied";
         return false;
     }
 }
@@ -350,7 +350,8 @@ void MessageWidget::paint(QPainter *painter, const QStyleOptionGraphicsItem *opt
     } else if (m_sequenceMessageType == Uml::SequenceMessage::Found) {
         paintFound(painter, option);
     } else {
-        uWarning() << "Unknown message type";
+        logWarn1("MessageWidget::paint: Unknown message type %1",
+                 m_sequenceMessageType);
     }
 }
 
@@ -675,7 +676,7 @@ UMLWidget* MessageWidget::onWidget(const QPointF& p)
 void MessageWidget::setTextPosition()
 {
     if (m_pFText == 0) {
-        DEBUG(DBG_SRC) << "m_pFText is NULL";
+        DEBUG() << "m_pFText is NULL";
         return;
     }
     if (m_pFText->displayText().isEmpty()) {
@@ -769,7 +770,7 @@ void MessageWidget::slotWidgetMoved(Uml::ID::Type id)
     const Uml::ID::Type idA = m_pOw[Uml::RoleType::A]->localID();
     const Uml::ID::Type idB = m_pOw[Uml::RoleType::B]->localID();
     if (idA != id && idB != id) {
-        DEBUG(DBG_SRC) << "id=" << Uml::ID::toString(id) << ": ignoring for idA=" << Uml::ID::toString(idA)
+        DEBUG() << "id=" << Uml::ID::toString(id) << ": ignoring for idA=" << Uml::ID::toString(idA)
             << ", idB=" << Uml::ID::toString(idB);
         return;
     }
@@ -839,12 +840,12 @@ bool MessageWidget::activate(IDChangeLog * /*Log = 0*/)
     if (m_pOw[Uml::RoleType::A] == 0) {
         UMLWidget *pWA = m_scene->findWidget(m_widgetAId);
         if (pWA == 0) {
-            DEBUG(DBG_SRC) << "role A object " << Uml::ID::toString(m_widgetAId) << " not found";
+            DEBUG() << "role A object " << Uml::ID::toString(m_widgetAId) << " not found";
             return false;
         }
         m_pOw[Uml::RoleType::A] = pWA->asObjectWidget();
         if (m_pOw[Uml::RoleType::A] == 0) {
-            DEBUG(DBG_SRC) << "role A widget " << Uml::ID::toString(m_widgetAId)
+            DEBUG() << "role A widget " << Uml::ID::toString(m_widgetAId)
                 << " is not an ObjectWidget";
             return false;
         }
@@ -852,19 +853,19 @@ bool MessageWidget::activate(IDChangeLog * /*Log = 0*/)
     if (m_pOw[Uml::RoleType::B] == 0) {
         UMLWidget *pWB = m_scene->findWidget(m_widgetBId);
         if (pWB == 0) {
-            DEBUG(DBG_SRC) << "role B object " << Uml::ID::toString(m_widgetBId) << " not found";
+            DEBUG() << "role B object " << Uml::ID::toString(m_widgetBId) << " not found";
             return false;
         }
         m_pOw[Uml::RoleType::B] = pWB->asObjectWidget();
         if (m_pOw[Uml::RoleType::B] == 0) {
-            DEBUG(DBG_SRC) << "role B widget " << Uml::ID::toString(m_widgetBId)
+            DEBUG() << "role B widget " << Uml::ID::toString(m_widgetBId)
                 << " is not an ObjectWidget";
             return false;
         }
     }
     updateResizability();
 
-    UMLClassifier *c = m_pOw[Uml::RoleType::B]->umlObject()->asUMLClassifier();
+    const UMLClassifier *c = m_pOw[Uml::RoleType::B]->umlObject()->asUMLClassifier();
     UMLOperation *op = 0;
     if (c && !m_CustomOp.isEmpty()) {
         Uml::ID::Type opId = Uml::ID::fromString(m_CustomOp);
@@ -1071,7 +1072,8 @@ void MessageWidget::calculateDimensions()
     } else if (m_sequenceMessageType == Uml::SequenceMessage::Found) {
         calculateDimensionsFound();
     } else {
-        uWarning() << "Unknown message type";
+        logWarn1("MessageWidget::calculateDimensions: Unknown message type %1",
+                 m_sequenceMessageType);
     }
     if (! UMLApp::app()->document()->loading()) {
         adjustAssocs(x(), y());  // adjust assoc lines
@@ -1334,7 +1336,8 @@ QSizeF MessageWidget::minimumSize() const
     } else if (m_sequenceMessageType == Uml::SequenceMessage::Found) {
         return QSizeF(width(), 10);
     } else {
-        uWarning() << "Unknown message type";
+        logWarn1("MessageWidget::minimumSize: Unknown message type %1",
+                 m_sequenceMessageType);
     }
     return QSize(width(), height());
 }
@@ -1383,7 +1386,7 @@ void MessageWidget::setyclicked(int yclick)
 bool MessageWidget::showPropertiesDialog()
 {
     if (!lwClassifier()) {
-        uError() << "lwClassifier() returns a NULL classifier";
+        logError0("MessageWidget::showPropertiesDialog: lwClassifier() returns a NULL classifier");
         return false;
     }
     bool result = false;
@@ -1402,11 +1405,11 @@ bool MessageWidget::showPropertiesDialog()
 /**
  * Saves to the "messagewidget" XMI element.
  */
-void MessageWidget::saveToXMI1(QXmlStreamWriter& writer)
+void MessageWidget::saveToXMI(QXmlStreamWriter& writer)
 {
     writer.writeStartElement(QLatin1String("messagewidget"));
-    UMLWidget::saveToXMI1(writer);
-    LinkWidget::saveToXMI1(writer);
+    UMLWidget::saveToXMI(writer);
+    LinkWidget::saveToXMI(writer);
     if (m_pOw[Uml::RoleType::A])
         writer.writeAttribute(QLatin1String("widgetaid"), Uml::ID::toString(m_pOw[Uml::RoleType::A]->localID()));
     if (m_pOw[Uml::RoleType::B])
@@ -1425,7 +1428,7 @@ void MessageWidget::saveToXMI1(QXmlStreamWriter& writer)
     // save the corresponding message text
     if (m_pFText && !m_pFText->text().isEmpty()) {
         writer.writeAttribute(QLatin1String("textid"), Uml::ID::toString(m_pFText->id()));
-        m_pFText->saveToXMI1(writer);
+        m_pFText->saveToXMI(writer);
     }
 
     writer.writeEndElement();
@@ -1434,12 +1437,12 @@ void MessageWidget::saveToXMI1(QXmlStreamWriter& writer)
 /**
  * Loads from the "messagewidget" XMI element.
  */
-bool MessageWidget::loadFromXMI1(QDomElement& qElement)
+bool MessageWidget::loadFromXMI(QDomElement& qElement)
 {
-    if (!UMLWidget::loadFromXMI1(qElement)) {
+    if (!UMLWidget::loadFromXMI(qElement)) {
         return false;
     }
-    if (!LinkWidget::loadFromXMI1(qElement)) {
+    if (!LinkWidget::loadFromXMI(qElement)) {
         return false;
     }
     QString textid = qElement.attribute(QLatin1String("textid"), QLatin1String("-1"));
@@ -1469,7 +1472,7 @@ bool MessageWidget::loadFromXMI1(QDomElement& qElement)
         if (tag == QLatin1String("floatingtext") || tag == QLatin1String("UML::FloatingTextWidget")) {
             m_pFText = new FloatingTextWidget(m_scene, tr, operationText(m_scene), m_textId);
             m_scene->addFloatingTextWidget(m_pFText);
-            if(! m_pFText->loadFromXMI1(element)) {
+            if(! m_pFText->loadFromXMI(element)) {
                 // Most likely cause: The FloatingTextWidget is empty.
                 delete m_pFText;
                 m_pFText = 0;
@@ -1477,7 +1480,7 @@ bool MessageWidget::loadFromXMI1(QDomElement& qElement)
             else
                 m_pFText->setSequenceNumber(m_SequenceNumber);
         } else {
-            uError() << "unknown tag " << tag;
+            logError1("MessageWidget::loadFromXMI: unknown tag %1", tag);
         }
     }
     return true;
