@@ -1,6 +1,6 @@
 /*
     SPDX-License-Identifier: GPL-2.0-or-later
-    SPDX-FileCopyrightText: 2003-2020 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
+    SPDX-FileCopyrightText: 2003-2022 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
 */
 
 // own header
@@ -112,7 +112,7 @@ void NodeWidget::paint(QPainter *painter, const QStyleOptionGraphicsItem *option
 QSizeF NodeWidget::minimumSize() const
 {
     if (m_umlObject == 0) {
-        DEBUG(DBG_SRC) << "m_umlObject is NULL";
+        DEBUG() << "m_umlObject is NULL";
         return UMLWidget::minimumSize();
     }
 
@@ -143,10 +143,10 @@ QSizeF NodeWidget::minimumSize() const
  * Saves to the "nodewidget" XMI element.
  * Note: For loading we use the method inherited from UMLWidget.
  */
-void NodeWidget::saveToXMI1(QXmlStreamWriter& writer)
+void NodeWidget::saveToXMI(QXmlStreamWriter& writer)
 {
     writer.writeStartElement(QLatin1String("nodewidget"));
-    UMLWidget::saveToXMI1(writer);
+    UMLWidget::saveToXMI(writer);
     writer.writeEndElement();
 }
 
