@@ -1,6 +1,6 @@
 /*
     SPDX-License-Identifier: GPL-2.0-or-later
-    SPDX-FileCopyrightText: 2002-2020 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
+    SPDX-FileCopyrightText: 2002-2022 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
 */
 
 // own header
@@ -16,6 +16,7 @@
 #include "umldoc.h"
 #include "umlscene.h"
 #include "umlview.h"
+#include "widget_utils.h"
 
 // kde includes
 #include <KLocalizedString>
@@ -89,13 +90,16 @@ void NoteWidget::paint(QPainter *painter, const QStyleOptionGraphicsItem *option
     painter->setPen(textColor());
     switch(m_noteType) {
     case NoteWidget::PreCondition :
-        painter->drawText(0, defaultMargin , w, fontHeight, Qt::AlignCenter, QLatin1String("<< precondition >>"));
+        painter->drawText(0, defaultMargin , w, fontHeight, Qt::AlignCenter,
+                          Widget_Utils::adornStereo(QLatin1String("precondition")));
         break;
     case NoteWidget::PostCondition :
-        painter->drawText(0, defaultMargin , w, fontHeight, Qt::AlignCenter, QLatin1String("<< postcondition >>"));
+        painter->drawText(0, defaultMargin , w, fontHeight, Qt::AlignCenter,
+                          Widget_Utils::adornStereo(QLatin1String("postcondition")));
         break;
     case NoteWidget::Transformation :
-        painter->drawText(0, defaultMargin , w, fontHeight, Qt::AlignCenter, QLatin1String("<< transformation >>"));
+        painter->drawText(0, defaultMargin , w, fontHeight, Qt::AlignCenter,
+                          Widget_Utils::adornStereo(QLatin1String("transformation")));
         break;
     case NoteWidget::Normal :
     default :
@@ -169,7 +173,8 @@ void NoteWidget::setDiagramLink(Uml::ID::Type viewID)
     UMLDoc *umldoc = UMLApp::app()->document();
     UMLView *view = umldoc->findView(viewID);
     if (view == 0) {
-        uError() << "no view found for viewID " << Uml::ID::toString(viewID);
+        logError1("NoteWidget::setDiagramLink: no view found for viewID %1",
+                  Uml::ID::toString(viewID));
         return;
     }
     QString linkText(QLatin1String("Diagram: ") + view->umlScene()->name());
@@ -242,9 +247,9 @@ void NoteWidget::askForNoteType(UMLWidget* &targetWidget)
 /**
  * Loads a "notewidget" XMI element.
  */
-bool NoteWidget::loadFromXMI1(QDomElement & qElement)
+bool NoteWidget::loadFromXMI(QDomElement & qElement)
 {
-    if (!UMLWidget::loadFromXMI1(qElement))
+    if (!UMLWidget::loadFromXMI(qElement))
         return false;
     setZValue(20); //make sure always on top.
     setDocumentation(qElement.attribute(QLatin1String("text")));
@@ -259,10 +264,10 @@ bool NoteWidget::loadFromXMI1(QDomElement & qElement)
 /**
  * Saves to the "notewidget" XMI element.
  */
-void NoteWidget::saveToXMI1(QXmlStreamWriter& writer)
+void NoteWidget::saveToXMI(QXmlStreamWriter& writer)
 {
     writer.writeStartElement(QLatin1String("notewidget"));
-    UMLWidget::saveToXMI1(writer);
+    UMLWidget::saveToXMI(writer);
     writer.writeAttribute(QLatin1String("text"), documentation());
     if (m_diagramLink != Uml::ID::None)
         writer.writeAttribute(QLatin1String("diagramlink"), Uml::ID::toString(m_diagramLink));
@@ -333,15 +338,15 @@ QSizeF NoteWidget::calculateSize(bool withExtensions /* = true */) const
     const int textWidth = size.width();
     const int textHeight = size.height();
     if (m_noteType == PreCondition) {
-        const int widthtemp = fm.width(QLatin1String("<< precondition >>"));
+        const int widthtemp = fm.width(Widget_Utils::adornStereo(QLatin1String("precondition")));
         width = textWidth > widthtemp ? textWidth : widthtemp;
     }
     else if (m_noteType == PostCondition) {
-        const int widthtemp = fm.width(QLatin1String("<< postcondition >>"));
+        const int widthtemp = fm.width(Widget_Utils::adornStereo(QLatin1String("postcondition")));
         width = textWidth > widthtemp ? textWidth : widthtemp;
     }
     else if (m_noteType == Transformation) {
-        const int widthtemp = fm.width(QLatin1String("<< transformation >>"));
+        const int widthtemp = fm.width(Widget_Utils::adornStereo(QLatin1String("transformation")));
         width = textWidth > widthtemp ? textWidth : widthtemp;
     }
 
