@@ -1,6 +1,6 @@
 /*
     SPDX-License-Identifier: GPL-2.0-or-later
-    SPDX-FileCopyrightText: 2014-2021 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
+    SPDX-FileCopyrightText: 2014-2022 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
 */
 
 // own header
@@ -11,6 +11,7 @@
 #include "package.h"
 #include "debug_utils.h"
 #include "listpopupmenu.h"
+#include "uml.h"
 #include "umldoc.h"
 #include "umlscene.h"
 #include "umlview.h"
@@ -26,6 +27,8 @@
 // sys includes
 #include <cmath>
 
+DEBUG_REGISTER(PinPortBase)
+
 PinPortBase::PinPortBase(UMLScene *scene, WidgetType type, UMLWidget *owner, UMLObject *o)
   : UMLWidget(scene, type, o),
     m_childPlacement(createPlacement(type))
@@ -113,7 +116,7 @@ QPointF PinPortBase::getPos() const
 void PinPortBase::updateWidget()
 {
     QString strName = name();
-    uDebug() << " port name is " << strName;
+    logDebug1("PinPortBase::updateWidget: port name is %1", strName);
     if (m_pName) {
         m_pName->setText(strName);
     } else {
@@ -184,7 +187,7 @@ QRectF PinPortBase::boundingRect() const
  */
 void PinPortBase::slotMenuSelection(QAction* action)
 {
-    uDebug() << "PinPortBase::slotMenuSelection";
+    logDebug0("PinPortBase::slotMenuSelection");
     ListPopupMenu::MenuType sel = ListPopupMenu::typeFromAction(action);
     switch(sel) {
     case ListPopupMenu::mt_NameAsTooltip:
@@ -201,7 +204,7 @@ void PinPortBase::slotMenuSelection(QAction* action)
             m_pName->activate();
             UMLWidget* owner = ownerWidget();
             if (owner == 0) {
-                uError() << "PinPortBase::slotMenuSelection: ownerWidget() returns NULL";
+                logError0("PinPortBase::slotMenuSelection: ownerWidget() returns null");
                 setX(x());
                 setY(y());
             } else {
@@ -252,10 +255,14 @@ void PinPortBase::setFloatingTextWidget(FloatingTextWidget *ft) {
  */
 UMLWidget* PinPortBase::onWidget(const QPointF &p)
 {
-    if (UMLWidget::onWidget(p) != 0)
+    UMLWidget * onWidget = UMLWidget::onWidget(p);
+    logDebug4("PinPortBase::onWidget (%1,%2) returns %3 (owner %4)",
+              p.x(), p.y(), (onWidget != 0), ownerWidget()->name());
+    if (onWidget) {
         return this;
+    }
     if (m_pName) {
-        uDebug() << "floatingtext: " << m_pName->text();
+        logDebug1("PinPortBase::onWidget floatingtext: %1", m_pName->text());
         return m_pName->onWidget(p);
     }
     return 0;
@@ -277,16 +284,16 @@ UMLWidget* PinPortBase::widgetWithID(Uml::ID::Type id)
 /**
  * Saves the widget to the "pinwidget" or "portwidget" XMI element.
  */
-void PinPortBase::saveToXMI1(QXmlStreamWriter& writer)
+void PinPortBase::saveToXMI(QXmlStreamWriter& writer)
 {
     QString tag = (baseType() == wt_Pin ? QLatin1String("pinwidget")
                                         : QLatin1String("portwidget"));
     writer.writeStartElement(tag);
     Q_ASSERT(ownerWidget() != 0);
     writer.writeAttribute(QLatin1String("widgetaid"), Uml::ID::toString(ownerWidget()->id()));
-    UMLWidget::saveToXMI1(writer);
+    UMLWidget::saveToXMI(writer);
     if (m_pName && !m_pName->text().isEmpty()) {
-        m_pName->saveToXMI1(writer);
+        m_pName->saveToXMI(writer);
     }
     writer.writeEndElement();
 }
@@ -294,16 +301,16 @@ void PinPortBase::saveToXMI1(QXmlStreamWriter& writer)
 /**
  * Loads from a "pinwidget" or from a "portwidget" XMI element.
  */
-bool PinPortBase::loadFromXMI1(QDomElement & qElement)
+bool PinPortBase::loadFromXMI(QDomElement & qElement)
 {
-    if (!UMLWidget::loadFromXMI1(qElement))
+    if (!UMLWidget::loadFromXMI(qElement))
         return false;
 
     QString widgetaid = qElement.attribute(QLatin1String("widgetaid"), QLatin1String("-1"));
     Uml::ID::Type aId = Uml::ID::fromString(widgetaid);
     UMLWidget *owner = m_scene->findWidget(aId);
     if (owner == 0) {
-        DEBUG(DBG_SRC) << "owner object " << Uml::ID::toString(aId) << " not found";
+        logDebug1("PinPortBase::loadFromXMI: owner object %1 not found", Uml::ID::toString(aId));
         return false;
     }
     setParentItem(owner);
@@ -316,22 +323,26 @@ bool PinPortBase::loadFromXMI1(QDomElement & qElement)
         if (tag == QLatin1String("floatingtext")) {
             m_pName = new FloatingTextWidget(m_scene, Uml::TextRole::Floating,
                                              name(), Uml::ID::Reserved);
-            if (!m_pName->loadFromXMI1(element)) {
+            m_pName->setParentItem(this);
+            if (!m_pName->loadFromXMI(element)) {
                 // Most likely cause: The FloatingTextWidget is empty.
+                // m_scene->removeItem(m_pName); m_pName->deleteLater();
                 delete m_pName;
                 m_pName = 0;
             } else {
-                m_pName->setParentItem(this);
                 m_pName->activate();
                 m_pName->update();
             }
         } else {
-            uError() << "unknown tag " << tag;
+            logError1("PinPortBase::loadFromXMI: unknown tag %1", tag);
         }
     }
     return true;
 }
 
+/**
+ * Reimplementation of method from @ref WidgetBase
+ */
 bool PinPortBase::activate(IDChangeLog* changeLog)
 {
     Q_UNUSED(changeLog);
