@@ -1,6 +1,6 @@
 /*
     SPDX-License-Identifier: GPL-2.0-or-later
-    SPDX-FileCopyrightText: 2002-2021 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
+    SPDX-FileCopyrightText: 2002-2022 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
 */
 
 #include "umlwidget.h"
@@ -310,16 +310,16 @@ void UMLWidget::toForeground()
 {
     QRectF rect = QRectF(scenePos(), QSizeF(width(), height()));
     QList<QGraphicsItem*> items = scene()->items(rect, Qt::IntersectsItemShape, Qt::DescendingOrder);
-    DEBUG(DBG_SRC) << "items at " << rect << " = " << items.count();
+    logDebug2("UMLWidget %1 toForeground: items at rect = %2", name(), items.count());
     if (items.count() > 1) {
         foreach(QGraphicsItem* i, items) {
             UMLWidget* w = dynamic_cast<UMLWidget*>(i);
             if (w) {
-                DEBUG(DBG_SRC) << "item=" << w->name() << " with zValue=" << w->zValue();
+                logDebug2("- item=%1 with zValue=%2", w->name(), w->zValue());
                 if (w->name() != name()) {
                     if (w->zValue() >= zValue()) {
                         setZValue(w->zValue() + 1.0);
-                        DEBUG(DBG_SRC) << "bring to foreground with zValue: " << zValue();
+                        logDebug1("-- bring to foreground with zValue: %1", zValue());
                     }
                 }
             }
@@ -328,7 +328,7 @@ void UMLWidget::toForeground()
     else {
         setZValue(0.0);
     }
-    DEBUG(DBG_SRC) << "zValue is " << zValue();
+    logDebug2("UMLWidget %1 toForeground: zValue is %2", name(), zValue());
 }
 
 /**
@@ -364,17 +364,12 @@ void UMLWidget::mousePressEvent(QGraphicsSceneMouseEvent *event)
         event->ignore();
         return;
     }
-    DEBUG(DBG_SRC) << "widget = " << name() << " / type = " << baseTypeStr()
-                   << " event->scenePos = " << event->scenePos()
-                   << " pos = " << pos();
     /*
-    if (! onWidget(event->scenePos())) {
-        DEBUG(DBG_SRC) << name() << " event->scenePos onWidget = false, ignoring event";
-        event->ignore();
-        return;
-    } */
+    logDebug4("UMLWidget::mousePressEvent: widget=%1 / type=%2 / event->scenePos=%3 / pos=%4",
+              name(), baseTypeStr(), event->scenePos(), pos());
+     */
     event->accept();
-    DEBUG(DBG_SRC) << "widget = " << name() << " / type = " << baseTypeStr();
+    logDebug2("UMLWidget::mousePressEvent: widget = %1 / type = %2", name(), baseTypeStr());
 
     toForeground();
 
@@ -383,7 +378,7 @@ void UMLWidget::mousePressEvent(QGraphicsSceneMouseEvent *event)
 
     // saving the values of the widget
     m_pressOffset = event->scenePos() - pos();
-    DEBUG(DBG_SRC) << "press offset=" << m_pressOffset;
+    logDebug2("UMLWidget::mousePressEvent: press offset x=%1, y=%2", m_pressOffset.x(), m_pressOffset.y());
 
     m_oldStatusBarMsg = UMLApp::app()->statusBarMsg();
 
@@ -496,7 +491,7 @@ void UMLWidget::mouseMoveEvent(QGraphicsSceneMouseEvent* event)
 
     QPointF delta = event->scenePos() - event->lastScenePos();
 
-    DEBUG(DBG_SRC) << "diffX=" << diffX << " / diffY=" << diffY;
+    logDebug2("UMLWidget::mouseMoveEvent: diffX=%1 / diffY=%2", diffX, diffY);
     foreach(UMLWidget* widget, umlScene()->selectedWidgets()) {
         if ((widget->parentItem() == 0) || (!widget->parentItem()->isSelected())) {
             widget->moveWidgetBy(diffX, diffY);
@@ -511,8 +506,6 @@ void UMLWidget::mouseMoveEvent(QGraphicsSceneMouseEvent* event)
             aw->moveEntireAssoc(diffX, diffY);
         }
     }
-
-    umlScene()->resizeSceneToItems();
 }
 
 /**
@@ -540,21 +533,26 @@ void UMLWidget::mouseMoveEvent(QGraphicsSceneMouseEvent* event)
  */
 void UMLWidget::mouseReleaseEvent(QGraphicsSceneMouseEvent *event)
 {
+    logDebug0("UMLWidget::mouseReleaseEvent");
     if (!m_moved && !m_resized) {
         if (!m_shiftPressed && (m_scene->selectedCount() > 1)) {
             selectSingle(event);
         } else if (!isSelected()) {
             deselect(event);
+        } else {
+            Widget_Utils::ensureNestedVisible(this, umlScene()->widgetList());
         }
     } else {
         // Commands
         if (m_moved) {
-            int selectionCount = umlScene()->selectedWidgets().count();
+            UMLWidgetList selectedWidgets = umlScene()->selectedWidgets();
+            int selectionCount = selectedWidgets.count();
             if (selectionCount > 1) {
                 UMLApp::app()->beginMacro(i18n("Move widgets"));
             }
-            foreach(UMLWidget* widget, umlScene()->selectedWidgets()) {
+            foreach (UMLWidget* widget, selectedWidgets) {
                 UMLApp::app()->executeCommand(new Uml::CmdMoveWidget(widget));
+                Widget_Utils::ensureNestedVisible(widget, umlScene()->widgetList());
             }
             if (selectionCount > 1) {
                 UMLApp::app()->endMacro();
@@ -572,7 +570,6 @@ void UMLWidget::mouseReleaseEvent(QGraphicsSceneMouseEvent *event)
             umlDoc()->setModified(true);
             umlScene()->invalidate();
         }
-        umlScene()->resizeSceneToItems();
 
         UMLApp::app()->document()->writeToStatusBar(m_oldStatusBarMsg);
     }
@@ -593,7 +590,7 @@ void UMLWidget::mouseReleaseEvent(QGraphicsSceneMouseEvent *event)
 void UMLWidget::mouseDoubleClickEvent(QGraphicsSceneMouseEvent *event)
 {
     if (event->button() == Qt::LeftButton) {
-        DEBUG(DBG_SRC) << "widget = " << name() << " / type = " << baseTypeStr();
+        logDebug2("UMLWidget::mouseDoubleClickEvent: widget = %1 / type = %2", name(), baseTypeStr());
         showPropertiesDialog();
         event->accept();
     }
@@ -696,6 +693,8 @@ void UMLWidget::constrain(qreal& width, qreal& height)
     if (fixedAspectRatio()) {
         QSizeF size = rect().size();
         float aspectRatio = size.width() > 0 ? (float)size.height()/size.width() : 1;
+        logDebug3("UMLWidget::constrain(%1) : Changing input height %2 to %3 due to fixedAspectRatio",
+                  name(), height, (width * aspectRatio));
         height = width * aspectRatio;
     }
 }
@@ -724,7 +723,7 @@ void UMLWidget::init()
         m_fillColor = optionState.uiState.fillColor;
         m_showStereotype = optionState.classState.showStereoType;
     } else {
-        uError() << "SERIOUS PROBLEM - m_scene is NULL";
+        logError0("UMLWidget::init SERIOUS PROBLEM - m_scene is null");
         m_useFillColor = false;
         m_usesDiagramFillColor = false;
         m_usesDiagramUseFillColor = false;
@@ -1192,10 +1191,7 @@ void UMLWidget::setFillColorCmd(const QColor &color)
 }
 
 /**
- * Reimplemented from class WidgetBase
- *
- * @param ChangeLog
- * @return  true for success
+ * Reimplemented from @ref WidgetBase
  */
 bool UMLWidget::activate(IDChangeLog* changeLog)
 {
@@ -1317,7 +1313,7 @@ void UMLWidget::removeAssoc(AssociationWidget* pAssoc)
  */
 void UMLWidget::adjustAssocs(qreal dx, qreal dy)
 {
-    qDebug() << this;
+    logDebug3("UMLWidget::adjustAssocs(%1) : w=%2, h=%3", name(), width(), height());
     // don't adjust Assocs on file load, as
     // the original positions, which are stored in XMI
     // should be reproduced exactly
@@ -1325,7 +1321,7 @@ void UMLWidget::adjustAssocs(qreal dx, qreal dy)
     //   as file is only partly loaded -> reposition
     //   could be misguided)
     /// @todo avoid trigger of this event during load
-    if (m_doc->loading()) {
+    if (m_doc->loading() || (qFuzzyIsNull(dx) && qFuzzyIsNull(dy))) {
         // don't recalculate the assocs during load of XMI
         // -> return immediately without action
         return;
@@ -1354,7 +1350,9 @@ void UMLWidget::adjustUnselectedAssocs(qreal dx, qreal dy)
     }
 
     foreach(AssociationWidget* assocwidget, associationWidgetList()) {
-        if (!assocwidget->isSelected()) {
+        if (!assocwidget->isSelected() &&
+               (this == assocwidget->widgetForRole(Uml::RoleType::A) ||
+                this == assocwidget->widgetForRole(Uml::RoleType::B))) {
             assocwidget->widgetMoved(this, dx, dy);
         }
     }
@@ -1410,6 +1408,46 @@ void UMLWidget::setPenFromSettings(QPainter *p)
     p->setPen(QPen(m_lineColor, m_lineWidth));
 }
 
+/**
+ * Return true if `this' is located in the bounding rectangle of `other'.
+ */
+bool UMLWidget::isLocatedIn(const UMLWidget *other) const
+{
+    const QPointF pos = scenePos();
+    const QPointF otherPos = other->scenePos();
+    const QString msgProlog = QLatin1String("UMLWidget ") + name() +
+                              QLatin1String(" isLocatedIn(") + other->name() + QLatin1String(")");
+
+    if (otherPos.x() > pos.x() || otherPos.y() > pos.y()) {
+        logDebug1("%1 returns false due to x or y out of range", msgProlog);
+        return false;
+    }
+
+    const int endX = pos.x() + width();
+    const int endY = pos.y() + height();
+
+    if (otherPos.x() > endX || otherPos.y() > endY) {
+        logDebug1("%1 returns false due to endX or endY out of range", msgProlog);
+        return false;
+    }
+
+    const int otherEndX = otherPos.x() + other->width();
+    if (otherEndX < pos.x() || otherEndX < endX) {
+        logDebug1("%1 returns false due to otherEndX out of range", msgProlog);
+        return false;
+    }
+
+    const int otherEndY = otherPos.y() + other->height();
+    if (otherEndY < pos.y() || otherEndY < endY) {
+        logDebug1("%1 returns false due to otherEndY out of range", msgProlog);
+        return false;
+    }
+
+    logDebug2("UMLWidget %1 isLocatedIn(%2) returns true", name(), other->name());
+    return true;
+}
+
+
 /**
  * Returns the cursor to be shown when resizing the widget.
  * Default cursor is KCursor::sizeFDiagCursor().
@@ -1492,7 +1530,7 @@ void UMLWidget::resize()
     // @TODO minimumSize() do not work in all cases, we need a dedicated autoResize() method
     QSizeF size = minimumSize();
     setSize(size.width(), size.height());
-    DEBUG(DBG_SRC) << "size=" << size;
+    logDebug3("UMLWidget::resize(%1) w=%2, h=%3", name(), size.width(), size.height());
     adjustAssocs(size.width()-oldW, size.height()-oldH);
 }
 
@@ -1532,11 +1570,9 @@ void UMLWidget::resize(QGraphicsSceneMouseEvent *me)
 
     constrain(newW, newH);
     resizeWidget(newW, newH);
-    DEBUG(DBG_SRC) << "event=" << me->scenePos() << "/ pos=" << pos() << " / newW=" << newW << " / newH=" << newH;
+    DEBUG() << "event=" << me->scenePos() << "/ pos=" << pos() << " / newW=" << newW << " / newH=" << newH;
     QPointF delta = me->scenePos() - me->lastScenePos();
     adjustAssocs(delta.x(), delta.y());
-
-    m_scene->resizeSceneToItems();
 }
 
 /**
@@ -1602,6 +1638,9 @@ void UMLWidget::setSelected(bool _select)
 
     WidgetBase::setSelected(_select);
 
+    logDebug1("UMLWidget::setSelected(%1) : Prevent obscuring", _select);
+    Widget_Utils::ensureNestedVisible(this, umlScene()->widgetList());
+
     update();
 
     // selection changed, we have to make sure the copy and paste items
@@ -1725,7 +1764,10 @@ QPointF UMLWidget::getPos() const
  */
 void UMLWidget::setX(qreal x)
 {
-    QGraphicsObjectWrapper::setX(x);
+    if (x < -umlScene()->maxCanvasSize() || x > umlScene()->maxCanvasSize())
+        logError1("UMLWidget::setX refusing to set X to %1", x);
+    else
+        QGraphicsObjectWrapper::setX(x);
 }
 
 /**
@@ -1737,7 +1779,10 @@ void UMLWidget::setX(qreal x)
  */
 void UMLWidget::setY(qreal y)
 {
-    QGraphicsObjectWrapper::setY(y);
+    if (y < -umlScene()->maxCanvasSize() || y > umlScene()->maxCanvasSize())
+        logError1("UMLWidget::setY refusing to set Y to %1", y);
+    else
+        QGraphicsObjectWrapper::setY(y);
 }
 
 /**
@@ -1799,6 +1844,7 @@ void UMLWidget::setSize(qreal width, qreal height)
     }
 
     const QRectF newRect(rect().x(), rect().y(), width, height);
+    logDebug3("UMLWidget::setSize(%1): setting w=%2, h=%3", name(), newRect.width(), newRect.height());
     setRect(newRect);
     foreach(QGraphicsItem* child, childItems()) {
         UMLWidget* umlChild = static_cast<UMLWidget*>(child);
@@ -1832,6 +1878,8 @@ void UMLWidget::updateGeometry(bool withAssocs)
     qreal clipWidth = size.width();
     qreal clipHeight = size.height();
     constrain(clipWidth, clipHeight);
+    logDebug5("UMLWidget::updateGeometry(%1) : oldW=%2, oldH=%3, clipWidth=%4, clipHeight=%5",
+             name(), oldW, oldH, clipWidth, clipHeight);
     setSize(clipWidth, clipHeight);
     slotSnapToGrid();
     if (withAssocs)
@@ -2137,15 +2185,15 @@ void UMLWidget::moveEvent(QGraphicsSceneMouseEvent* me)
   Q_UNUSED(me)
 }
 
-void UMLWidget::saveToXMI1(QXmlStreamWriter& writer)
+void UMLWidget::saveToXMI(QXmlStreamWriter& writer)
 {
     /*
       When calling this from child classes bear in mind that the call
       must precede terminated XML subelements.
       Type must be set in the child class.
     */
-    WidgetBase::saveToXMI1(writer);
-    DiagramProxyWidget::saveToXMI1(writer);
+    WidgetBase::saveToXMI(writer);
+    DiagramProxyWidget::saveToXMI(writer);
 
     qreal dpiScale = UMLApp::app()->document()->dpiScale();
     writer.writeAttribute(QLatin1String("x"), QString::number(x() / dpiScale));
@@ -2156,23 +2204,41 @@ void UMLWidget::saveToXMI1(QXmlStreamWriter& writer)
     writer.writeAttribute(QLatin1String("isinstance"), QString::number(m_isInstance));
     if (!m_instanceName.isEmpty())
         writer.writeAttribute(QLatin1String("instancename"), m_instanceName);
-    if (m_showStereotype)
-        writer.writeAttribute(QLatin1String("showstereotype"), QString::number(m_showStereotype));
+    writer.writeAttribute(QLatin1String("showstereotype"), QString::number(m_showStereotype));
 }
 
-bool UMLWidget::loadFromXMI1(QDomElement & qElement)
+bool UMLWidget::loadFromXMI(QDomElement & qElement)
 {
-    WidgetBase::loadFromXMI1(qElement);
-    DiagramProxyWidget::loadFromXMI1(qElement);
+    WidgetBase::loadFromXMI(qElement);
+    DiagramProxyWidget::loadFromXMI(qElement);
     QString x = qElement.attribute(QLatin1String("x"), QLatin1String("0"));
     QString y = qElement.attribute(QLatin1String("y"), QLatin1String("0"));
     QString h = qElement.attribute(QLatin1String("height"), QLatin1String("0"));
     QString w = qElement.attribute(QLatin1String("width"), QLatin1String("0"));
-    qreal dpiScale = UMLApp::app()->document()->dpiScale();
-    setSize(toDoubleFromAnyLocale(w) * dpiScale,
-            toDoubleFromAnyLocale(h) * dpiScale);
-    setX(toDoubleFromAnyLocale(x) * dpiScale);
-    setY(toDoubleFromAnyLocale(y) * dpiScale);
+    const qreal dpiScale = UMLApp::app()->document()->dpiScale();
+    const qreal scaledW = toDoubleFromAnyLocale(w) * dpiScale;
+    const qreal scaledH = toDoubleFromAnyLocale(h) * dpiScale;
+    setSize(scaledW, scaledH);
+    const qreal nX = toDoubleFromAnyLocale(x);
+    const qreal nY = toDoubleFromAnyLocale(y);
+    qreal fixedX = nX;
+    qreal fixedY = nY;
+    bool usesRelativeCoords = (baseType() == wt_Pin || baseType() == wt_Port);
+    if (!usesRelativeCoords && baseType() == wt_Text) {
+        UMLWidget *parent = dynamic_cast<UMLWidget*>(parentItem());
+        usesRelativeCoords = (parent != 0);
+    }
+    if (!usesRelativeCoords) {
+        fixedX += umlScene()->fixX();  // bug 449622
+        fixedY += umlScene()->fixY();
+    }
+    const qreal scaledX = fixedX * dpiScale;
+    const qreal scaledY = fixedY * dpiScale;
+    if (!usesRelativeCoords) {
+        umlScene()->updateCanvasSizeEstimate(scaledX, scaledY, scaledW, scaledH);
+    }
+    setX(scaledX);
+    setY(scaledY);
 
     QString isinstance = qElement.attribute(QLatin1String("isinstance"), QLatin1String("0"));
     m_isInstance = (bool)isinstance.toInt();
